<?php

if ( !class_exists('Suround_Admin') && interface_exists('ConfigurableInterface') ) {

	class Suround_Admin implements ConfigurableInterface {

		public function __construct(ConfigurableInterface $configurator) {
			$this->configurator = $configurator;

			add_action( 'admin_init', array( $this, 'admin_init' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts', ), 1 );
		}

		/**
		 * Returns an option value.
		 *
		 * @param string $name - the option name
		 * @param mixed $fallback - fallback value
		 * @param array $data - additional data for getting the option
		 * @access public
		 * @return mixed
		 */
		public function getOption( $name, $fallback = '', array $data = array() ) {
			return $this->configurator->getOption($name, $fallback, $data);
		}

		/**
		 * Sets an option value programmatically.
		 *
		 * @param string $name - the option name
		 * @param mixed $value - value of the option
		 * @access public
		 * @return void
		 */
		public function setOption($name, $value) {
			return $this->configurator->setOption($name, $value);
		}

		/**
		 * Enqueues CSS and JS assets.
		 */
		public function admin_enqueue_scripts() {
			$screen = get_current_screen();

			global $pagenow;
			wp_enqueue_style( 'suround-admin', get_theme_file_uri('css/admin.css'), false );

			if ( in_array( $screen->id, array('page'), true ) ) {

				wp_enqueue_script('suround-admin-core', get_theme_file_uri('js/admin.core' . ( WP_DEBUG ? '' : '.min' ) . '.js'), array('jquery'), '1.0.0', true);

			} elseif ( in_array( $screen->id, array('post'), true ) ) {

				/* Register Mapbox Scripts */
				wp_enqueue_script( 'mapbox', 'https://api.tiles.mapbox.com/mapbox-gl-js/v0.53.1/mapbox-gl.js', array(), null, true );
				wp_enqueue_script( 'mapbox-geocoder', 'https://api.mapbox.com/mapbox-gl-js/plugins/mapbox-gl-geocoder/v4.0.0/mapbox-gl-geocoder.min.js', array( 'mapbox' ), null, true );

				wp_enqueue_style( 'mapbox-css', 'https://api.tiles.mapbox.com/mapbox-gl-js/v0.53.1/mapbox-gl.css' );
				wp_enqueue_style( 'mapbox-geocoder', 'https://api.mapbox.com/mapbox-gl-js/plugins/mapbox-gl-geocoder/v4.0.0/mapbox-gl-geocoder.css' );

				/* Mapify CSS */
				wp_register_style( 'mapify', get_theme_file_uri('js/libs/mapify/mapify.css'), array(), null );

				/* Mapify JS */
				wp_register_script( 'mapify', get_theme_file_uri('js/libs/mapify/jquery.mapify.js'), array( 'jquery', 'mapbox' ), null, false );
				wp_localize_script( 'mapify', 'mapifyl10n', array(
					'locked'    => esc_html__( 'Lock Pin Location', 'surround' ),
					'unlocked'  => esc_html__( 'Unlock Pin Location', 'surround' ),
				) );

				wp_enqueue_style( 'suround_post_admin_css', get_theme_file_uri('css/post-admin.css'), array( 'mapify' ) );
				wp_register_script( 'jquery-tiptip', get_theme_file_uri('js/libs/jquery-tiptip/jquery.tipTip' . ( WP_DEBUG ? '' : '.min' ) . '.js'), array( 'jquery' ), null, true );
				wp_enqueue_script( 'suround_post_admin_js', get_theme_file_uri('js/post-admin.js'), array( 'jquery', 'jquery-tiptip', 'mapify' ), null, true );

				$post_id = get_the_ID();

				$options = array(
					'input'       => '.map-post-location input[type="hidden"]',
					'lat'         => 40.712784,
					'lng'         => -74.005941,
					'lock'        => 'unlock',
					'lock_input'  => 'geo_map_lock_status',
					'mapbox_token' => suround_get_option('mapbox-token'),
					'placeholder' => esc_html__('Search', 'surround')
				);
				$lat = get_post_meta( $post_id, 'geolocation_lat', true );
				$lng = get_post_meta( $post_id, 'geolocation_long', true );

				if ( $lat || $lng ) {
					$options['lat'] = $lat;
					$options['lng'] = $lng;
				}
				$address = get_post_meta( $post_id, 'suround_single_post_location', true );
				if ( '' != $address ) {
					$options['placeholder'] = $address;
				}

				$lock_status = get_post_meta( $post_id, 'geolocation_map_lock_status', true );
				$options['lock'] = 'lock' == $lock_status ? $lock_status : $options['lock'];

				wp_localize_script( 'suround_post_admin_js', 'suround_post_admin_localize', $options );

			} elseif ( in_array( $screen->id, array('nav-menus'), true ) ) {

				wp_enqueue_script('suround-menus-core', get_theme_file_uri('js/menu.admin.core.js'), array('jquery'), '1.0.0', true);

			} elseif ( in_array( $pagenow, array('edit-tags.php', 'term.php') ) && isset( $_GET['taxonomy'] ) && in_array( $_GET['taxonomy'], array( 'category', 'series' ) ) ) {

				global $post;

				wp_enqueue_media(array(
					'post' => $post->ID,
				));

				wp_enqueue_script( 'suround_category', get_theme_file_uri('js/metaboxes-category' . (WP_DEBUG ? '' : '.min') . '.js'), array( 'jquery' ) );

			}

			wp_localize_script( 'jquery', 'suround_admin_global_vars', array(
				'installing_text' => esc_html__( 'Installing', 'surround' ),
				'import_theme_options_text' => esc_html__( 'Importing theme options', 'surround' ),
				'finished_text' => esc_html__( 'Finished! Please visit your site.', 'surround' ),
				'default_text' => esc_html__('Default', 'surround')
			) );

		}

		public function admin_init() {

			if ( current_user_can( 'edit_theme_options' ) )  {

				if ( isset($_GET['theme_settings_export'] ) ) {

					// Widget settings
					$widget_settings = json_encode($this->export_widgets());

					// Sidebar settings
					$sidebar_settings = json_encode($this->export_sidebars());

					// Meta settings
					$meta_settings = json_encode($this->export_metadata());

					echo '<pre>'."\n"; echo '$widget_settings = "'; print_r($widget_settings); echo '";</pre>';
					echo '<pre>'."\n"; echo '$sidebar_settings = "'; print_r($sidebar_settings); echo '";</pre>'."\n\n";
					echo '<pre>'."\n"; echo '$meta_settings = "'; print_r($meta_settings); echo '";</pre>'."\n\n";
					exit();

				}

			}

		}

		public function export_widgets() {

			global $wp_registered_widgets;
			$saved_widgets = $options = array();

			foreach ($wp_registered_widgets as $registered) {
				if ( isset($registered['callback'][0]) && isset($registered['callback'][0]->option_name)) {
					$options[] = $registered['callback'][0]->option_name;
				}
			}

			foreach ($options as $key) {
				$widget = get_option($key, array());
				$treshhold = 1;
				if (array_key_exists("_multiwidget", $widget)) $treshhold = 2;

				if ($treshhold <= count($widget)) {
					$saved_widgets[$key] = $widget;
				}
			}

			$saved_widgets['sidebars_widgets'] = get_option('sidebars_widgets');
			return $saved_widgets;
		}

		function export_sidebars() {
			$custom_sidebars = get_option('suround_registered_sidebars');

			if ( !empty($custom_sidebars) ) {
				return $custom_sidebars;
			}
			return '';
		}

		public function export_metadata() {
			global $wpdb;

			$meta_settings = $wpdb->get_results("SELECT * FROM {$wpdb->prefix}product_catmeta", ARRAY_A);
			return $meta_settings;
		}

	}

}