<?php

function suround_check_theme_options() {
	global $suround_settings;

	ob_start();
	include( get_theme_file_path('admin/theme-options/default-options.php') );
	$options = ob_get_clean();
	$default_settings = json_decode($options, true);

	foreach ( $default_settings as $key => $value ) {
		if ( is_array($value) ) {
			foreach ( $value as $key1 => $value1 ) {
				if ((!isset($suround_settings[$key][$key1]) || !$suround_settings[$key][$key1])) {
					$suround_settings[$key][$key1] = $default_settings[$key][$key1];
				}
			}
		} else {
			if ( !isset($suround_settings[$key]) ) {
				$suround_settings[$key] = $default_settings[$key];
			}
		}
	}

	return $suround_settings;
}

if ( !function_exists('suround_options_header_types') ) {
	function suround_options_header_types() {
		return array(
			'style-1' => array( 'title' => esc_html__('Header Style 1', 'surround' ), 'title' => esc_html__('Header Style 1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/headers/header_1.jpg'), ),
			'style-2' => array( 'title' => esc_html__('Header Style 2', 'surround' ), 'title' => esc_html__('Header Style 2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/headers/header_2.jpg')),
			'style-3' => array( 'title' => esc_html__('Header Style 3', 'surround' ), 'title' => esc_html__('Header Style 3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/headers/header_3.jpg')),
			'style-4' => array( 'title' => esc_html__('Header Style 4', 'surround' ), 'title' => esc_html__('Header Style 4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/headers/header_4.jpg')),
			'style-5' => array( 'title' => esc_html__('Header Style 5', 'surround' ), 'title' => esc_html__('Header Style 5', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/headers/header_5.jpg')),
			'style-6' => array( 'title' => esc_html__('Header Style 6', 'surround' ), 'title' => esc_html__('Header Style 6', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/headers/header_6.jpg')),
		);
	}
}

if ( !function_exists( 'suround_sidebar_position' ) ) {
	function suround_sidebar_position( $narrow = false ) {

		$sidebar_position = array(
			'no-sidebar' => array( 'title' => esc_html__('Without Sidebar', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout-no-sidebar.jpg') ),
			'left-sidebar' => array( 'title' => esc_html__('Left Sidebar', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout-left-sidebar.jpg') ),
			'right-sidebar' => array( 'title' => esc_html__('Right Sidebar', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout-right-sidebar.jpg') )
		);

		if ( $narrow ) {
			$sidebar_position['narrow-left-sidebar'] = array( 'title' => esc_html__('Narrow Left Sidebar', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout-left-narrow-sidebar.jpg') );
			$sidebar_position['narrow-right-sidebar'] = array( 'title' => esc_html__('Narrow Right Sidebar', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout-right-narrow-sidebar.jpg') );
		}

		return $sidebar_position;
	}
}


if ( !function_exists('suround_options_sidebars') ) {
	function suround_options_sidebars() {
		return array(
			'left-sidebar',
			'right-sidebar'
		);
	}
}

if ( !function_exists('suround_options_all_sidebars') ) {
	function suround_options_all_sidebars() {
		return array(
			'left-sidebar',
			'right-sidebar',
			'narrow-left-sidebar',
			'narrow-right-sidebar'
		);
	}
}

if ( !function_exists('suround_categories_orderby') ) {
	function suround_categories_orderby() {
		return array(
			"id" => esc_html__("ID", 'surround' ),
			"name" => esc_html__("Name", 'surround' ),
			"slug" => esc_html__("Slug", 'surround' ),
			"count" => esc_html__("Count", 'surround' )
		);
	}
}

if ( !function_exists('suround_product_columns') ) {
	function suround_product_columns() {
		return array(
			2 => 2,
			3 => 3,
			4 => 4
		);
	}
}

if ( !function_exists('suround_blog_columns') ) {
	function suround_blog_columns() {
		return array(
			1 => 1,
			2 => 2,
			3 => 3
		);
	}
}

/**
 * Get meta options
 *
 * @param   array $default Enable defaults i.e. array('date', 'comments')
 * @return array List of available options
 * @since  1.0
 */

if ( !function_exists( 'suround_get_meta_opts' ) ):
	function suround_get_meta_opts( $default = array() ) {

		$options = array();

		$options['date'] = esc_html__( 'Date', 'surround' );
		$options['views'] = esc_html__( 'Views', 'surround' );
		$options['vote'] = esc_html__( 'Vote', 'surround' );
		$options['comments'] = esc_html__( 'Comments', 'surround' );

		if ( !empty($default) ) {
			foreach($options as $key => $option) {
				if( in_array( $key, $default) ) {
					$options[$key] = 1;
				} else {
					$options[$key] = 0;
				}
			}
		}

		$options = apply_filters('suround_modify_meta_opts', $options );
		return $options;
	}
endif;

/**
 * Get the list of available pagination types
 *
 */

if ( !function_exists( 'suround_get_pagination_layouts' ) ):
	function suround_get_pagination_layouts() {

		$layouts = array();
		$layouts['scroll-down'] = esc_html__( 'Scroll down', 'surround' );
		$layouts['numeric'] = esc_html__( 'Numeric pagination links', 'surround' );
		$layouts['prev-next'] = esc_html__( 'Prev/Next page links', 'surround' );
		$layouts['bottom-fixed'] = esc_html__( 'Bottom fixed', 'surround' );

		$layouts = apply_filters('suround_modify_pagination_layouts', $layouts );
		return $layouts;
	}
endif;


if ( !function_exists( 'suround_get_archive_layouts' ) ):
	function suround_get_archive_layouts( $inherit = false, $none = false, $exclude = array() ) {

		if ( $inherit ) {
			$layouts['inherit'] = array( 'title' => esc_html__( 'Inherit', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/inherit.png') );
		}

		if ( $none ) {
			$layouts['none'] = array( 'title' => esc_html__( 'None', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/none.png') );
		}

		$layouts['classic'] = array( 'title' => esc_html__( 'Classic', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_a1.png'), 'col' => 7 );
		$layouts['list'] = array( 'title' => esc_html__( 'List', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_a2.png'), 'col' => 7 );
		$layouts['grid'] = array( 'title' => esc_html__( 'Grid', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_e3.png'), 'col' => 4 );

		if( !empty( $exclude ) ){
			foreach( $exclude as $layout ){
				if( array_key_exists($layout, $layouts) ) {
					unset($layouts[$layout]);
				}
			}
		}

		$layouts = apply_filters( 'suround_archive_layouts', $layouts );

		return $layouts;
	}
endif;


if ( !function_exists( 'suround_get_category_layouts' ) ):
	function suround_get_category_layouts( $exclude = array() ) {

		$layouts['classic'] = esc_html__( 'Classic', 'surround' );
		$layouts['list'] = esc_html__( 'List', 'surround' );
		$layouts['grid'] = esc_html__( 'Grid', 'surround' );
		$layouts['side-map'] = esc_html__( 'Side Map', 'surround' );

		if ( !empty( $exclude ) ) {
			foreach( $exclude as $layout ){
				if ( array_key_exists($layout, $layouts) ) {
					unset($layouts[$layout]);
				}
			}
		}

		$layouts = apply_filters( 'suround_category_layouts', $layouts );

		return $layouts;
	}
endif;

if ( !function_exists( 'suround_get_post_cover_layouts' ) ):
	function suround_get_post_cover_layouts( $inherit = false, $none = true, $exclude = array() ) {

		if ( $inherit ) {
			$layouts['inherit'] = esc_html__( 'Inherit', 'surround' );
		}

		if ( $none ) {
			$layouts['none'] =  esc_html__( 'None', 'surround' );
		}

		$layouts['cover-map'] = esc_html__( 'Cover Map', 'surround' );
		$layouts['cover-street-view'] = esc_html__( 'Cover Street View', 'surround' );
		$layouts['cover-image'] = esc_html__( 'Cover Image', 'surround' );
		$layouts['cover-carousel'] = esc_html__( 'Cover Carousel', 'surround' );
		$layouts['cover-slider'] = esc_html__( 'Cover Slider', 'surround' );
		$layouts['cover-video'] = esc_html__( 'Cover Video', 'surround' );

		if ( !empty( $exclude ) ) {
			foreach( $exclude as $layout ){
				if ( array_key_exists($layout, $layouts) ) {
					unset($layouts[$layout]);
				}
			}
		}

		return $layouts;
	}
endif;


if ( !function_exists( 'suround_get_main_layouts' ) ):
	function suround_get_main_layouts( $inherit = false, $none = false, $exclude = array() ) {

		if ( $inherit ) {
			$layouts['inherit'] = array( 'title' => esc_html__( 'Inherit', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/inherit.png') );
		}

		if ( $none ) {
			$layouts['none'] = array( 'title' => esc_html__( 'None', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/none.png') );
		}

		$layouts['a1'] = array( 'title' => esc_html__( 'Layout A1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_a1.png'), 'col' => 7 );
		$layouts['a2'] = array( 'title' => esc_html__( 'Layout A2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_a2.png'), 'col' => 7 );
		$layouts['a3'] = array( 'title' => esc_html__( 'Layout A3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_a3.png'), 'col' => 7 );
		$layouts['a4'] = array( 'title' => esc_html__( 'Layout A4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_a4.png'), 'col' => 7 );
		$layouts['a5'] = array( 'title' => esc_html__( 'Layout A5', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_a5.png'), 'col' => 7 );
		$layouts['a6'] = array( 'title' => esc_html__( 'Layout A6', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_a6.png'), 'col' => 7 );
		$layouts['a7'] = array( 'title' => esc_html__( 'Layout A7', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_a7.png'), 'col' => 7 );

		$layouts['b1'] = array( 'title' => esc_html__( 'Layout B1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_b1.png'), 'col' => 6 );
		$layouts['b2'] = array( 'title' => esc_html__( 'Layout B2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_b2.png'), 'col' => 6 );
		$layouts['b3'] = array( 'title' => esc_html__( 'Layout B3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_b3.png'), 'col' => 6 );
		$layouts['b4'] = array( 'title' => esc_html__( 'Layout B4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_b4.png'), 'col' => 6 );
		$layouts['b5'] = array( 'title' => esc_html__( 'Layout B5', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_b5.png'), 'col' => 6 );
		$layouts['b6'] = array( 'title' => esc_html__( 'Layout B6', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_b6.png'), 'col' => 6 );

		$layouts['c1'] = array( 'title' => esc_html__( 'Layout C1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_c1.png'), 'col' => 4 );
		$layouts['c2'] = array( 'title' => esc_html__( 'Layout C2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_c2.png'), 'col' => 4 );
		$layouts['c3'] = array( 'title' => esc_html__( 'Layout C3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_c3.png'), 'col' => 4 );
		$layouts['c4'] = array( 'title' => esc_html__( 'Layout C4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_c4.png'), 'col' => 4 );

		$layouts['d1'] = array( 'title' => esc_html__( 'Layout D1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_d1.png'), 'col' => 4 );
		$layouts['d2'] = array( 'title' => esc_html__( 'Layout D2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_d2.png'), 'col' => 4 );
		$layouts['d3'] = array( 'title' => esc_html__( 'Layout D3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_d3.png'), 'col' => 4 );
		$layouts['d4'] = array( 'title' => esc_html__( 'Layout D4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_d4.png'), 'col' => 4 );

		$layouts['e1'] = array( 'title' => esc_html__( 'Layout E1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_e1.png'), 'col' => 4 );
		$layouts['e2'] = array( 'title' => esc_html__( 'Layout E2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_e2.png'), 'col' => 4 );
		$layouts['e3'] = array( 'title' => esc_html__( 'Layout E3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_e3.png'), 'col' => 4 );
		$layouts['e4'] = array( 'title' => esc_html__( 'Layout E4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_e4.png'), 'col' => 4 );

		$layouts['f1'] = array( 'title' => esc_html__( 'Layout F1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_f1.png'), 'col' => 2 );
		$layouts['f2'] = array( 'title' => esc_html__( 'Layout F2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_f2.png'), 'col' => 2 );

		if( !empty( $exclude ) ){
			foreach( $exclude as $layout ){
				if( array_key_exists($layout, $layouts) ) {
					unset($layouts[$layout]);
				}
			}
		}

		$layouts = apply_filters( 'suround_main_layouts', $layouts );

		return $layouts;
	}
endif;

if ( !function_exists( 'suround_get_carousel_layouts' ) ):
	function suround_get_carousel_layouts( $inherit = false, $none = false, $exclude = array() ) {

		if ( $inherit ) {
			$layouts['inherit'] = array( 'title' => esc_html__( 'Inherit', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/inherit.png') );
		}

		if ( $none ) {
			$layouts['none'] = array( 'title' => esc_html__( 'None', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/none.png') );
		}

		$layouts['g1'] = array( 'title' => esc_html__( 'Layout G1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_g1.png') );
		$layouts['g2'] = array( 'title' => esc_html__( 'Layout G2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_g2.png') );
		$layouts['g3'] = array( 'title' => esc_html__( 'Layout G3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_g3.png') );
		$layouts['g4'] = array( 'title' => esc_html__( 'Layout G4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_g4.png') );

		$layouts['h1'] = array( 'title' => esc_html__( 'Layout H1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_h1.png') );
		$layouts['h2'] = array( 'title' => esc_html__( 'Layout H2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_h2.png') );
		$layouts['h3'] = array( 'title' => esc_html__( 'Layout H3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_h3.png') );
		$layouts['h4'] = array( 'title' => esc_html__( 'Layout H4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_h4.png') );

		$layouts['i1'] = array( 'title' => esc_html__( 'Layout I1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_i1.png') );
		$layouts['i2'] = array( 'title' => esc_html__( 'Layout I2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_i2.png') );
		$layouts['i3'] = array( 'title' => esc_html__( 'Layout I3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_i3.png') );
		$layouts['i3b'] = array( 'title' => esc_html__( 'Layout I3 Big', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_i3.png') );
		$layouts['i4'] = array( 'title' => esc_html__( 'Layout I4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_i4.png') );
		$layouts['i4b'] = array( 'title' => esc_html__( 'Layout I4 Big', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_i4.png') );

		$layouts['j1'] = array( 'title' => esc_html__( 'Layout J1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_j1.png') );
		$layouts['j2'] = array( 'title' => esc_html__( 'Layout J2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_j2.png') );
		$layouts['j3'] = array( 'title' => esc_html__( 'Layout J3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_j3.png') );
		$layouts['j4'] = array( 'title' => esc_html__( 'Layout J4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_j4.png') );

		$layouts['k1'] = array( 'title' => esc_html__( 'Layout K1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_k1.png') );
		$layouts['k2'] = array( 'title' => esc_html__( 'Layout K2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_k2.png') );
		$layouts['k3'] = array( 'title' => esc_html__( 'Layout K3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_k3.png') );
		$layouts['k4'] = array( 'title' => esc_html__( 'Layout K4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_k4.png') );

		$layouts['l1'] = array( 'title' => esc_html__( 'Layout L1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_l1.png') );
		$layouts['l2'] = array( 'title' => esc_html__( 'Layout L2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_l2.png') );
		$layouts['l3'] = array( 'title' => esc_html__( 'Layout L3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_l3.png') );
		$layouts['l4'] = array( 'title' => esc_html__( 'Layout L4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_l4.png') );

		$layouts['m1'] = array( 'title' => esc_html__( 'Layout M1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_m1.png') );
		$layouts['m2'] = array( 'title' => esc_html__( 'Layout M2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_m2.png') );
		$layouts['m3'] = array( 'title' => esc_html__( 'Layout M3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_m3.png') );
		$layouts['m4'] = array( 'title' => esc_html__( 'Layout M4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_m4.png') );

		$layouts['n1'] = array( 'title' => esc_html__( 'Layout N1', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_n1.png') );
		$layouts['n2'] = array( 'title' => esc_html__( 'Layout N2', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_n2.png') );
		$layouts['n3'] = array( 'title' => esc_html__( 'Layout N3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_n3.png') );
		$layouts['n4'] = array( 'title' => esc_html__( 'Layout N4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_n4.png') );

		if ( !empty( $exclude ) ) {
			foreach( $exclude as $layout ) {
				if( array_key_exists($layout, $layouts) ) {
					unset($layouts[$layout]);
				}
			}
		}

		$layouts = apply_filters( 'suround_carousel_layouts', $layouts );

		return $layouts;
	}
endif;

