<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * e.g., it puts together the home page when no home.php file exists.
 *
 * Learn more: {@link https://codex.wordpress.org/Template_Hierarchy}
 *
 * @package WordPress
 * @subpackage Suround
 */

get_header(); ?>

<?php if ( have_posts() ) : ?>

	<?php
	global $SuroundLayout;
	$term = get_queried_object();
	$meta = suround_get_category_meta($term->term_id);
	$layout = $meta['layout']['main'];
	$meta_map = $meta['layout']['map'];
	$meta_filter = $meta['layout']['filter'];
	$button_map = ( $meta_map == 'show' || $meta_map == 'hide' ) ? true : false;
	?>

	<?php if ( in_array($layout, array('classic', 'list', 'grid')) ): ?>

		<?php $breadcrumb = $SuroundLayout->getBreadcrumb(); ?>

		<?php if ( isset($breadcrumb['page-title-state']) && $breadcrumb['page-title-state'] !== 'on' ) : ?>

			<?php if ( $meta['layout']['position_breadcrumb'] == 'after' ): ?>
				<h2 class="single-cat-title"><?php single_cat_title( '', true ); ?></h2>
			<?php endif; ?>

		<?php endif; ?>

		<?php if ( $meta['layout']['position_breadcrumb'] == 'before' ): ?>

			<?php
			global $wp_query;

			if ( $meta['layout']['breadcrumb'] && $meta['layout']['position_breadcrumb'] == 'before' ) {
				get_template_part( 'template-parts/breadcrumb', 'category' );
			}

			if ( $meta['layout']['map'] != 'no' && $meta['layout']['position_breadcrumb'] == 'before' ) {
				get_template_part( 'template-parts/map' );
			}

			if ( $meta['layout']['filter'] && $meta['layout']['position_breadcrumb'] == 'before' ) {
				echo suround_output_sort_links( $wp_query->posts, 'grid' );
			}

			?>

		<?php endif; ?>

		<?php if ( in_array($layout, array( 'classic', 'list') ) ): ?>

			<?php echo suround_sort_header( $layout, true, array('classic', 'list'), $meta_map ); ?>

			<div id="filter-section" class="view-<?php echo sanitize_html_class($layout) ?>">

				<div class="entry-holder type-classic entry-layout-a1">
					<div class="entry-box"
						<?php if ( $meta_filter ): ?>
							data-isotope-layout="grid"
							data-isotope-filter="#grid-filter"
						<?php endif; ?>
					>
						<?php while ( have_posts() ) : the_post(); ?>
							<div class="grid-item <?php echo suround_get_sort_class( get_the_ID() ) ?>">
								<?php get_template_part( 'template-parts/post/layout', 'a1' ); ?>
							</div>
						<?php endwhile; ?>
					</div>
				</div>

				<div class="entry-holder type-list without-border entry-layout-e3">
					<div class="entry-box <?php if ( $meta_filter ): ?>grid--isotope item-col-1<?php endif; ?>"
						<?php if ( $meta_filter ): ?>
							data-isotope-layout="grid"
							data-isotope-filter="#grid-filter"
						<?php endif; ?>
					>
						<?php while ( have_posts() ) : the_post(); ?>
							<div class="grid-item <?php echo suround_get_sort_class( get_the_ID() ) ?>">
								<?php get_template_part( 'template-parts/post/layout', 'e3' ); ?>
							</div>
						<?php endwhile; ?>
					</div>
				</div>

				<?php echo suround_paging_nav(); ?>

			</div>

		<?php elseif ( in_array($layout, array('grid')) ): ?>

			<?php $columns = $meta['layout']['columns']; ?>

			<?php if ( $columns == 2 ): ?>

				<?php echo suround_sort_header( $layout, true, array('classic', 'list', 'grid'), $meta_map ); ?>

				<div id="filter-section" class="view-grid">

					<div class="entry-holder type-classic entry-layout-a1">
						<div class="entry-box"
							<?php if ( $meta_filter ): ?>
								data-isotope-layout="grid"
								data-isotope-filter="#grid-filter"
							<?php endif; ?>
						>
							<?php while ( have_posts() ) : the_post(); ?>
								<div class="grid-item <?php echo suround_get_sort_class( get_the_ID() ) ?>">
									<?php get_template_part( 'template-parts/post/layout', 'a1' ); ?>
								</div>
							<?php endwhile; ?>
						</div>
					</div>

					<div class="entry-holder type-list without-border entry-layout-e3">
						<div class="entry-box"
							<?php if ( $meta_filter ): ?>
								data-isotope-layout="grid"
								data-isotope-filter="#grid-filter"
							<?php endif; ?>
						>
							<?php while ( have_posts() ) : the_post(); ?>
								<div class="grid-item <?php echo suround_get_sort_class( get_the_ID() ) ?>">
									<?php get_template_part( 'template-parts/post/layout', 'e3' ); ?>
								</div>
							<?php endwhile; ?>
						</div>
					</div>

					<div class="entry-holder type-grid entry-layout-a2">
						<div class="entry-box <?php if ( $meta_filter ): ?>grid--isotope item-col-2<?php endif; ?>"
							<?php if ( $meta_filter ): ?>
								data-isotope-layout="grid"
								data-isotope-filter="#grid-filter"
							<?php endif; ?>
						>
							<?php while ( have_posts() ) : the_post(); ?>
								<div class="grid-item <?php echo suround_get_sort_class( get_the_ID() ) ?>">
									<?php get_template_part( 'template-parts/post/layout', 'a2' ); ?>
								</div>
							<?php endwhile; ?>
						</div>
					</div>

					<?php echo suround_paging_nav(); ?>

				</div>

			<?php elseif ( $columns == 3 ): ?>

				<?php
				if ( $meta['layout']['filter'] && $meta['layout']['position_breadcrumb'] == 'after' ) {
					echo suround_output_sort_links( $wp_query->posts );
				}
				?>

				<?php echo suround_post_count( $button_map, $meta_map ) ?>

				<div class="entry-holder entry-layout-a3">
					<div class="entry-box <?php if ( $meta_filter ): ?>grid--isotope item-col-3<?php endif; ?>"
						<?php if ( $meta_filter ): ?>
							data-isotope-layout="grid"
							data-isotope-filter="#grid-filter"
						<?php endif; ?>
					>
						<?php while ( have_posts() ) : the_post(); ?>
							<div class="grid-item <?php echo suround_get_sort_class( get_the_ID() ) ?>">
								<?php get_template_part( 'template-parts/post/layout', 'a3' ); ?>
							</div>
						<?php endwhile; ?>
					</div>
				</div>

				<?php echo suround_paging_nav(); ?>

			<?php elseif ( $columns == 4 ): ?>

				<?php
				if ( $meta['layout']['filter'] && $meta['layout']['position_breadcrumb'] == 'after' ) {
					echo suround_output_sort_links( $wp_query->posts );
				}
				?>

				<?php echo suround_post_count( $button_map, $meta_map ) ?>

				<div class="entry-holder entry-layout-c4">
					<div class="entry-box <?php if ( $meta_filter ): ?>grid--isotope item-col-4<?php endif; ?>"
						<?php if ( $meta_filter ): ?>
							data-isotope-layout="grid"
							data-isotope-filter="#grid-filter"
						<?php endif; ?>
					>
						<?php while ( have_posts() ) : the_post(); ?>
							<div class="grid-item <?php echo suround_get_sort_class( get_the_ID() ) ?>">
								<?php get_template_part( 'template-parts/post/layout', 'c4' ); ?>
							</div>
						<?php endwhile; ?>
					</div>
				</div>

				<?php echo suround_paging_nav(); ?>

			<?php endif; ?>

		<?php endif; ?>

	<?php elseif ( in_array($layout, array('side-map'))): ?>

		<div class="side-map-container">

			<main id="side-map-content">
				<?php get_template_part( 'template-parts/map' ); ?>
			</main>

			<sidebar id="side-map-sidebar">

				<div class="entry-holder entry-layout-a5">
					<div class="entry-box <?php if ( $meta_filter ): ?>grid--isotope item-col-1<?php endif; ?>"
						<?php if ( $meta_filter ): ?>
							data-isotope-layout="grid"
							data-isotope-filter="#grid-filter"
						<?php endif; ?>
					>
						<?php while ( have_posts() ) : the_post(); ?>
							<div id="grid-item-<?php echo get_the_ID() ?>" class="grid-item <?php echo suround_get_sort_class(get_the_ID()) ?>">
								<?php get_template_part( 'template-parts/post/layout', 'a5' ); ?>
							</div>
						<?php endwhile; ?>
					</div>
				</div>

			</sidebar>

		</div>

	<?php endif; ?>

<?php else : ?>

	<?php get_template_part( 'template-parts/post/content', 'none' ); ?>

<?php endif; ?>

<?php get_footer(); ?>