<?php
/**
 * Surround functions and definitions
 */

//f

// Do not allow directly accessing this file.
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}

define('SUROUND_TEMPLATE_DIRECTORY', get_template_directory());
define('SUROUND_TEMPLATE_DIRECTORY_URI', get_template_directory_uri());
define('SUROUND_STYLESHEET_DIRECTORY', get_stylesheet_directory());

class Suround_Includes {

	/**
	 * The one, true instance of the Suround object.
	 *
	 * @static
	 * @access public
	 * @var null|object
	 */
	public static $instance = null;

	/**
	 * Contains default fonts settings of the theme.
	 *
	 * @access protected
	 * @var array
	 */
	protected $google_fonts = array(
		'Frank Ruhl Libre' => array('400', '400italic', '500', '500italic', '600', '600italic', '700', '700italic', '800', '800italic'),
		'Montserrat' =>array('400', '400italic', '500', '500italic', '600', '600italic', '700', '700italic', '800', '800italic'),
	);

	/**
	 * Contains default charsets for the fonts of the theme.
	 *
	 * @access protected
	 * @var array
	 */
	protected $google_fonts_charsets = array( 'latin', 'latin-ext' );

	/**
	 * Access the single instance of this class.
	 *
	 * @return Suround
	 */
	public static function get_instance() {
		if ( null === self::$instance ) {
			self::$instance = new Suround_Includes();
		}
		return self::$instance;
	}

	public function get( $integration ) {
		return $this->integrations->get( $integration );
	}

	/**
	 * The class constructor
	 */
	private function __construct() {
		$this->includes();
		$this->setup();
		$this->register_sidebars();
	}

	private function includes() {
		$this->files = array(

			'admin/domain/interfaces/ConfigurableInterface.php',
			'admin/domain/interfaces/LayoutInterface.php',
			'admin/domain/configurator.php',
			'admin/domain/layout.php',
			'admin/domain/admin.php',
			'admin/domain/suround.php',
			'admin/domain/helper.php',
			'admin/domain/mapbox.php',

			'includes/integrations/class-integrations.php',
			'includes/integrations/class-integration.php',

			'includes/functions-core.php',

			'includes/ajax.php',

			'includes/class-walker.php',
			'includes/class-walker-nav-menu.php',
			'includes/nav-menu-template.php',
			'includes/menu.php',

			'includes/class-media-grabber.php',
			'includes/template-functions.php',
			'includes/metaboxes/metaboxes.php',

			'includes/setup/class-tgm-plugin-activation.php',
			'includes/setup/plugin-bundle.php',

			'includes/admin/class-post-admin.php',
		);

		foreach ( $this->files as $file ) {
			require_once( get_theme_file_path( $file ));
		}
	}

	private function setup() {

		add_action( 'wp_enqueue_scripts', [ $this, 'registerAssets' ] );
		add_action( 'wp_head', [ $this, 'print_head_content' ] );

		$this->integrations = new Suround_Integrations();
	}


	public function registerAssets() {

		// order is important
		return $this->registerStyles()
		            ->registerFonts()
		            ->registerInlineStyles()
		            ->registerScripts()
		            ->registerInlineScripts();
	}

	/**
	 * Registers necessary styles.
	 *
	 * @access protected
	 */
	protected function registerStyles()
	{
		/* Vendor CSS */
		wp_enqueue_style( 'jquery-owl-carousel', get_theme_file_uri('css/jquery.owl.carousel' . ( WP_DEBUG ? '' : '.min' ) . '.css') );
		wp_enqueue_style( 'jquery-fancybox', get_theme_file_uri('js/libs/fancybox/jquery.fancybox.css') );

		/* Theme CSS */
		wp_enqueue_style( 'bootstrap', get_theme_file_uri('css/bootstrap-grid.min.css'), array() );
		wp_enqueue_style( 'linearicons', get_theme_file_uri('css/linear-icons.css'), array() );
		wp_enqueue_style( 'fontello', get_theme_file_uri('css/fontello.css'), array() );

		wp_enqueue_style( 'suround-icon-font', get_theme_file_uri('css/suround-icon-font.css'), array() );
		wp_enqueue_style( 'suround-style', get_stylesheet_uri() );

		if ( is_rtl() ) {
			wp_enqueue_style( 'suround-rtl',  get_theme_file_uri( 'css/rtl.css' ), array( 'suround-style' ), '1' );
		}

		// Skin Styles
		wp_deregister_style( 'suround-skin' );
		$prefix_name = 'skin_' . suround_get_blog_id() . '.css';
		$wp_upload_dir = wp_upload_dir();
		$stylesheet_dynamic_dir = $wp_upload_dir['basedir'] . '/dynamic_suround_dir';
		$stylesheet_dynamic_dir = str_replace('\\', '/', $stylesheet_dynamic_dir);
		$filename = trailingslashit($stylesheet_dynamic_dir) . $prefix_name;

		$version = get_option( 'suround_stylesheet_version' . $prefix_name );
		if ( empty($version) ) $version = '1';

		$demo = get_option( 'suround_demo' );
		if ( empty($demo) ) $demo = '1';

		if ( file_exists($filename) ) {
			if ( is_ssl() ) {
				$wp_upload_dir['baseurl'] = str_replace("http://", "https://", $wp_upload_dir['baseurl']);
			}
			wp_register_style( 'suround-skin', $wp_upload_dir['baseurl'] . '/dynamic_suround_dir/' . $prefix_name, null, $version );
		} else {
			wp_register_style( 'suround-skin', get_theme_file_uri( "css/skin-{$demo}.css" ), null, $version );
		}
		wp_enqueue_style( 'suround-skin' );

		if (is_home() || is_archive() || is_single() || is_page() ) {
			wp_enqueue_style('media-element');
		}

		return $this;
	}


	/**
	 * Registers theme fonts.
	 *
	 * @access protected
	 */
	protected function registerFonts() {

		global $suround_settings;

		// Load Google Fonts
		$elements = array( 'body', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'menu', 'sub-menu', 'vr-menu', 'vr-sub-menu' );

		foreach( $elements as $element ) {

			$option_name = sprintf('%s-font', $element);

			if ( isset($suround_settings[$option_name]['google']) && $suround_settings[$option_name]['google'] !== 'false' ) {
				$font_data = $suround_settings[$option_name];
				$font = $suround_settings[$option_name]['font-family'];

				if ( !isset($this->google_fonts[$font]) ) {
					$this->google_fonts[$font] = array();
				}

				$font_weight = isset($font_data['font-weight']) ? $font_data['font-weight'] : '400';
				$font_style = isset($font_data['font-style']) && $font_data['font-style'] == 'italic' ? 'italic' : '';
				$font_weight_final = $font_weight . $font_style;

				if ( !in_array($font_weight_final, $this->google_fonts[$font]) ) {
					$this->google_fonts[$font][] = $font_weight_final;
				}
			}

		}

		$fonts_charsets_state = is_array($suround_settings) && isset($suround_settings['select-google-charset']) && $suround_settings['select-google-charset'];
		$fonts_charsets = boolval($fonts_charsets_state) && isset($suround_settings['google-charsets']) && !empty($suround_settings['google-charsets']) ? $suround_settings['google-charsets'] : $this->google_fonts_charsets;

		wp_enqueue_style('suround-google-fonts', suround_google_fonts_url($this->google_fonts, $fonts_charsets), null, null);

		return $this;
	}

	protected function registerInlineStyles() {
		$post_id = suround_post_id();

		if ( $post_id ) {

			$page_vertical_padding = array();
			$page_vertical_padding['padding-top'] = suround_add_px_unit(suround_get_meta_option('suround_page_top_padding_individual', 91));
			$page_vertical_padding['padding-bottom'] =  suround_add_px_unit(suround_get_meta_option('suround_page_bottom_padding_individual', 91));

			$custom_css = array();

			if ( !empty($page_vertical_padding) ) {
				$custom_css['.page-content-wrap.no-sidebar'] = $page_vertical_padding;
			}

			wp_add_inline_style( 'suround-style', suround_generate_css_properties($custom_css) );

		}

		return $this;
	}

	/**
	 * Registers necessary scripts.
	 *
	 * @access protected
	 */
	protected function registerScripts()
	{

		global $suround_settings;

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		$scripts_deps = array( 'jquery', 'jquery-ui-tabs' );

		/* Register Google Maps Scripts */
		wp_register_script( 'google-maps', suround_get_google_maps_api_url(), array(), '3.exp', false );
		$scripts_deps[] = 'google-maps';

		/* Include Libs & Plugins */
		wp_enqueue_script( 'modernizr', get_theme_file_uri('js/libs/jquery.modernizr.min.js'), array(), '3.6.0' );

		wp_enqueue_script( 'jquery-fancybox', get_theme_file_uri('js/libs/fancybox/jquery.fancybox.js'), $scripts_deps, '', true );
		wp_enqueue_script( 'jquery-owl-carousel', get_theme_file_uri('js/libs/owl.carousel.min.js'), $scripts_deps, '', true);
		wp_enqueue_script( 'jquery-isotope', get_theme_file_uri('js/libs/isotope.pkgd.min.js'), $scripts_deps, '', true);

		/* Theme files */
		wp_enqueue_script( 'suround-countdown', get_theme_file_uri('js/libs/countdown.min.js'), $scripts_deps, '', true);
		wp_enqueue_script( 'suround-menu', get_theme_file_uri('js/libs/menu' . ( WP_DEBUG ? '' : '.min' ) . '.js'), $scripts_deps, '', true);
		wp_enqueue_script( 'suround-isotope-wrapper', get_theme_file_uri('js/modules/suround.isotope' . ( WP_DEBUG ? '' : '.min') . '.js' ), $scripts_deps, '1.0.0', true );
		wp_enqueue_script( 'suround-map', get_theme_file_uri( 'js/suround-map.js' ), $scripts_deps, '', true );
		wp_enqueue_script( 'suround-global', get_theme_file_uri( 'js/suround-global' . ( WP_DEBUG ? '' : '.min' ) . '.js' ), $scripts_deps, '', true );

		if ( isset($suround_settings['js-code-head']) && $suround_settings['js-code-head']) {
			wp_add_inline_script( 'suround-global', $suround_settings['js-code-head'] );
		}

		return $this;
	}

	/**
	 * Register necessary inline scripts.
	 *
	 * @access protected
	 */
	protected function registerInlineScripts()
	{
		wp_localize_script( 'suround-global', 'suround_global_vars', $this->get_js_settings() );

		return $this;
	}

	function get_js_settings() {

		$js_settings = array();
		$js_settings['ajaxurl'] = admin_url( 'admin-ajax.php' );
		$js_settings['ajax_nonce'] = wp_create_nonce( 'ajax-nonce' );
		$js_settings['template_base_uri'] = get_template_directory_uri() . '/';
		$js_settings['rtl'] = is_rtl() ? 1 : 0;
		$js_settings['map_pin_color'] = suround_get_option('map-pin-color');
		$js_settings['show_text'] = esc_html__('Show', 'surround');
		$js_settings['hide_text'] = esc_html__('Hide', 'surround');
		$js_settings['default_text'] = esc_html__('Default', 'surround');
		$js_settings['header_sticky'] = suround_get_option( 'header-sticky-menu' ) ? true : false;
		$js_settings['header_sticky_offset'] = absint( suround_get_option( 'header_sticky_offset' ) );

		return apply_filters('suround-gs-settings', $js_settings);
	}

	public function print_head_content() {

		$data = apply_filters( 'suround/functions/localize-data', [
			'Helpers' => new \stdClass,
		]  );

		foreach ( (array) $data as $key => $value ) {
			if ( ! is_scalar( $value ) ) {
				continue;
			}
			$data[ $key ] = html_entity_decode( (string) $value, ENT_QUOTES, 'UTF-8' );
		}

		printf( '<script type="text/javascript">var SuroundMap = %s;</script>', wp_json_encode( (object) $data ) );
	}

	function register_sidebars() {
		add_action( 'widgets_init', array( $this, 'register_sidebars_areas' ), 1);
	}

	function register_sidebars_areas() {

		$widget_args = array(
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h6 class="widget-title">',
			'after_title' => '</h6>'
		);

		// General Widget Area
		register_sidebar(array(
			'name' => esc_html__('General Widget Area', 'surround' ),
			'id' => 'general-widget-area',
			'description'   => esc_html__('For all pages and posts.', 'surround' ),
			'before_widget' => $widget_args['before_widget'],
			'after_widget' => $widget_args['after_widget'],
			'before_title' => $widget_args['before_title'],
			'after_title' => $widget_args['after_title']
		));

		register_sidebar(array(
			'name' => esc_html__('Archive Widget Area', 'surround' ),
			'id' => 'archive-widget-area',
			'description'   => esc_html__('For archive.', 'surround' ),
			'before_widget' => $widget_args['before_widget'],
			'after_widget' => $widget_args['after_widget'],
			'before_title' => $widget_args['before_title'],
			'after_title' => $widget_args['after_title']
		));

		register_sidebar(array(
			'name' => esc_html__('Category Widget Area', 'surround' ),
			'id' => 'category-widget-area',
			'description'   => esc_html__('For category archive.', 'surround' ),
			'before_widget' => $widget_args['before_widget'],
			'after_widget' => $widget_args['after_widget'],
			'before_title' => $widget_args['before_title'],
			'after_title' => $widget_args['after_title']
		));

		register_sidebar(array(
			'name' => esc_html__('Post Widget Area', 'surround' ),
			'id' => 'post-widget-area',
			'description'   => esc_html__('For post single.', 'surround' ),
			'before_widget' => $widget_args['before_widget'],
			'after_widget' => $widget_args['after_widget'],
			'before_title' => $widget_args['before_title'],
			'after_title' => $widget_args['after_title']
		));

		register_sidebar(array(
			'name' => esc_html__('Search Widget Area', 'surround' ),
			'id' => 'search-widget-area',
			'description'   => esc_html__('For search.', 'surround' ),
			'before_widget' => $widget_args['before_widget'],
			'after_widget' => $widget_args['after_widget'],
			'before_title' => $widget_args['before_title'],
			'after_title' => $widget_args['after_title']
		));

		register_sidebar(array(
			'name' => esc_html__('Side Panel Widget Area', 'surround' ),
			'id' => 'side-widget-area',
			'description'   => esc_html__('Side panel widget area for header 1.', 'surround' ),
			'before_widget' => $widget_args['before_widget'],
			'after_widget' => $widget_args['after_widget'],
			'before_title' => $widget_args['before_title'],
			'after_title' => $widget_args['after_title']
		));

	}

}

/**
 * Helper function for accessing the main `Suround` class.
 *
 * @since 3.0.0
 *
 * @return object Suround The single instance of the `Suround` class.
 */
function suround() {
	return Suround_Includes::get_instance();
}
suround();

/*  Theme support & Theme setup
/* ---------------------------------------------------------------------- */

if ( ! function_exists( 'suround_setup' ) ) {
	function suround_setup() {

		global $Suround, $SuroundMap, $SuroundLayout, $content_width;

		define('ALLOW_UNFILTERED_UPLOADS', true);

		$content_width = apply_filters( 'suround_content_width', 1380 );

		// Load theme textdomain
		load_theme_textdomain( 'surround', get_template_directory() . '/lang' );
		load_child_theme_textdomain( 'surround', get_stylesheet_directory() . '/lang' );

		// Post Formats Support
		add_theme_support( 'post-formats', array( 'image', 'gallery', 'video', 'audio' ) );

		add_theme_support( 'align-wide' );

		// Post Thumbnails Support
		add_theme_support( 'post-thumbnails' );

		// Add default posts and comments RSS feed links to head
		add_theme_support( 'automatic-feed-links' );

		add_theme_support( 'title-tag' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menu( 'primary', 'Primary Menu' );
		register_nav_menu( 'secondary', 'Secondary Menu' );

		/* Add image sizes */
		$image_sizes = suround_get_image_sizes();

		if ( ! empty( $image_sizes ) ) {
			foreach ( $image_sizes as $id => $size ) {
				add_image_size( $id, $size['args']['w'], $size['args']['h'], $size['args']['crop'] );
			}
		}

		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		add_editor_style( array( 'editor-style.css' ) );

		// This theme uses its own gallery styles.
		add_filter( 'use_default_gallery_style', '__return_false' );

		require_once( get_theme_file_path('admin/theme-options/functions.php') );

		$SuroundConfigurator = new Suround_Configurator();
		$Suround = new Suround( new Suround_Admin( $SuroundConfigurator ), new Suround_Helper() );
		$SuroundLayout = new Suround_Layout( $SuroundConfigurator );

		$SuroundMap = new Suround_Mapbox();
		/**
		 * Suround admin options
		 */
		require_once( get_theme_file_path('admin/theme-options/save-settings.php') );
	}
}

add_action( 'after_setup_theme', 'suround_setup', 1 );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function suround_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}

add_action( 'wp_head', 'suround_pingback_header' );

// Disables the block editor from managing widgets in the Gutenberg plugin.
add_filter( 'gutenberg_use_widgets_block_editor', '__return_false' );

// Disables the block editor from managing widgets.
add_filter( 'use_widgets_block_editor', '__return_false' );

// Disables the block editor from managing widgets in the Gutenberg plugin.
add_filter( 'gutenberg_use_widgets_block_editor', '__return_false' );

// Disables the block editor from managing widgets.
add_filter( 'use_widgets_block_editor', '__return_false' );