<?php
/**
 * User profile social links for wp-admin
 *
 */
if ( !class_exists( 'suround_admin_user_profile' ) ) {

	class suround_admin_user_profile {

		public function __construct() {

			if ( is_admin() ) {
				add_action( 'show_user_profile', array( $this, 'add_meta_fields' ), 20 );
				add_action( 'edit_user_profile', array( $this, 'add_meta_fields' ), 20 );

				add_action( 'personal_options_update', array( $this, 'save_meta_fields' ) );
				add_action( 'edit_user_profile_update', array( $this, 'save_meta_fields' ) );
			}

		}

		function get_store_info( $seller_id ) {
			$info = get_user_meta( $seller_id, 'suround_profile_settings', true );
			$info = is_array($info) ? $info : array();

			$info = wp_parse_args( $info, array( 'social' => array(), 'position' => '' ) );
			return $info;
		}

		function get_social_profile_fields() {
			$fields = array(
				'twitter' => array(
					'title' => esc_html__('Twitter', 'surround'),
				),
				'instagram' => array(
					'title' => esc_html__('Instagram', 'surround'),
				)
			);

			return apply_filters('suround_profile_social_fields', $fields);

		}

		/**
		 * Add fields to user profile
		 *
		 * @param WP_User $user
		 *
		 * @return void|false
		 */
		function add_meta_fields($user)
		{
			$store_settings = $this->get_store_info($user->ID);
			$social_fields = $this->get_social_profile_fields();

			?>

			<table class="form-table">

				<tbody>

				<tr>
					<th><?php echo esc_html__('Position', 'surround'); ?></th>
					<td>
						<input type="text" name="suround_profile_settings[position]"
							   class="regular-text"
							   value="<?php echo isset($store_settings['position']) ? wp_kses_post($store_settings['position']) : ''; ?>">
					</td>
				</tr>

				<?php foreach ( $social_fields as $key => $value ) : ?>

					<tr>
						<th><?php echo esc_html($value['title']); ?></th>
						<td>
							<input type="text" name="suround_profile_settings[social][<?php echo esc_attr($key); ?>]"
								   class="regular-text"
								   value="<?php echo isset($store_settings['social'][$key]) ? wp_kses_post($store_settings['social'][$key]) : ''; ?>">
						</td>
					</tr>

				<?php endforeach; ?>

				</tbody>

			</table>
			<?php
		}

		public function output_position($userId) {
			$id = get_the_author_meta( 'ID', $userId );
			$profile_info = $this->get_store_info($id);
			?>

			<?php if ( !empty($profile_info['position']) ): ?>
				<div class="member-position"><?php echo wp_kses_post($profile_info['position']) ?></div>
			<?php endif; ?>

			<?php

		}

		public function output_social_links($userId) {
			$id = get_the_author_meta( 'ID', $userId );
			$social_fields = $this->get_social_profile_fields();
			$profile_info = $this->get_store_info($id);
			?>

			<ul class="member-social-list">

				<?php foreach ( $social_fields as $key => $field ) : ?>
					<?php if ( isset($profile_info['social'][$key]) && !empty($profile_info['social'][$key]) ) : ?>
						<li>
							<?php echo wp_kses_post($field['title']) ?>
							<a target="_blank"
							   href="<?php echo isset($profile_info['social'][$key]) ? esc_url($profile_info['social'][$key]) : '' ?>">
								<?php echo wp_kses_post($profile_info['social'][$key]) ?>
							</a>
						</li>
					<?php endif; ?>
				<?php endforeach; ?>

			</ul>

			<?php
		}

		/**
		 * Save user data
		 *
		 * @param int $user_id
		 *
		 * @return void
		 */
		function save_meta_fields($user_id) {

			if ( current_user_can('edit_user',$user_id) ) {
				update_user_meta($user_id, 'suround_profile_settings', $_POST['suround_profile_settings']);
			}

		}
	}
}

