<?php
/**
 * Custom functions of the theme templates.
 *
 * @subpackage Suround
 */

/* Generate list of additional image sizes
 *
 * @return array List of image size parameters
 * @since  1.0
 */

if ( !function_exists( 'suround_get_image_sizes' ) ):
	function suround_get_image_sizes() {

		$sizes = array(
			'suround-112x112-center-center' => array( 'args' => array( 'w' => 112, 'h' => 112, 'crop' => 1 ) ),
			'suround-250x150-center-center' => array( 'args' => array( 'w' => 250, 'h' => 150, 'crop' => 1 ) ),
			'suround-315x210-center-center' => array( 'args' => array( 'w' => 315, 'h' => 210, 'crop' => 1 ) ),
			'suround-315x335-center-center' => array( 'args' => array( 'w' => 315, 'h' => 335, 'crop' => 1 ) ),
			'suround-315x350-center-center' => array( 'args' => array( 'w' => 315, 'h' => 350, 'crop' => 1 ) ),
			'suround-450x115-center-center' => array( 'args' => array( 'w' => 450, 'h' => 115, 'crop' => 1 ) ),
			'suround-450x280-center-center' => array( 'args' => array( 'w' => 450, 'h' => 280, 'crop' => 1 ) ),
			'suround-440x335-center-center' => array( 'args' => array( 'w' => 440, 'h' => 335, 'crop' => 1 ) ),
			'suround-450x475-center-center' => array( 'args' => array( 'w' => 450, 'h' => 475, 'crop' => 1 ) ),
			'suround-460x560-center-center' => array( 'args' => array( 'w' => 460, 'h' => 560, 'crop' => 1 ) ),
			'suround-440x698-center-center' => array( 'args' => array( 'w' => 440, 'h' => 698, 'crop' => 1 ) ),
			'suround-545x350-center-center' => array( 'args' => array( 'w' => 545, 'h' => 350, 'crop' => 1 ) ),
			'suround-615x700-center-center' => array( 'args' => array( 'w' => 615, 'h' => 700, 'crop' => 1 ) ),
			'suround-680x560-center-center' => array( 'args' => array( 'w' => 680, 'h' => 560, 'crop' => 1 ) ),
			'suround-680x600-center-center' => array( 'args' => array( 'w' => 680, 'h' => 600, 'crop' => 1 ) ),
			'suround-910x530-center-center' => array( 'args' => array( 'w' => 910, 'h' => 530, 'crop' => 1 ) ),
			'suround-920x585-center-center' => array( 'args' => array( 'w' => 920, 'h' => 585, 'crop' => 1 ) ),
			'suround-910x915-center-center' => array( 'args' => array( 'w' => 910, 'h' => 915, 'crop' => 1 ) ),
			'suround-908x335-center-center' => array( 'args' => array( 'w' => 908, 'h' => 335, 'crop' => 1 ) ),
			'suround-1040x600-center-center' => array( 'args' => array( 'w' => 1040, 'h' => 600, 'crop' => 1 ) ),
			'suround-1040x780-center-center' => array( 'args' => array( 'w' => 1040, 'h' => 780, 'crop' => 1 ) ),
			'suround-1640x780-center-center' => array( 'args' => array( 'w' => 1640, 'h' => 780, 'crop' => 1 ) ),
		);

		$sizes = apply_filters( 'suround_modify_image_sizes', $sizes );

		return $sizes;
	}
endif;
/* 	Google fonts url
/* --------------------------------------------------------------------- */
if( !function_exists('suround_google_fonts_url') ) {

	function suround_google_fonts_url( array $fonts_data = array(), array $charsets = array() ) {
		$fonts_url = '';
		$font_family = array();

		if ( $fonts_data ) {
			foreach( $fonts_data as $font => $font_weights ) {
				$font_state = sprintf( _x( 'on', '%s font: on or off', 'surround' ), $font );

				if ( 'off' !== $font_state ) {
					$font_family[] = sprintf('%s:%s', $font, implode(',', $font_weights));
				}
			}
		}

		if ( $font_family ) {
			$fonts_url = add_query_arg(array(
				'family' => urlencode(implode('|', $font_family)),
				'subset' => urlencode(implode(',', $charsets))
			), 'https://fonts.googleapis.com/css');
		}

		return esc_url_raw($fonts_url);
	}

}

if ( !function_exists('suround_get_google_maps_api_url') ) {
	function suround_get_google_maps_api_url() {

		/* Google Maps JS URL */
		$url = add_query_arg( array(
			'libraries' => 'places',
			'language'  => get_locale() ? substr( get_locale(), 0, 2 ) : '',
			'region'    => get_locale() ? substr( get_locale(), 3, 2 ) : ''
		), '//maps.googleapis.com/maps/api/js' );

		/* Add Google Map Key */
		$key = strip_tags( trim(suround_get_option('gmap-api')) );
		$url = $key ? add_query_arg( 'key', urlencode( $key ), $url ) : $url;

		return apply_filters( 'suround_google_maps_api_url', $url, $key );
	}
}

/*	Post ID
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_post_id') ) {

	function suround_post_id() {
		$object_id = get_queried_object_id();

		$post_id = false;

		if ( get_option( 'show_on_front' ) && get_option( 'page_for_posts' ) && is_home() ) {
			$post_id = get_option( 'page_for_posts' );
		} else {
			// Use the $object_id if available.
			if ( isset( $object_id ) ) {
				$post_id = $object_id;
			}
			// If we're not on a singular post, set to false.
			if ( ! is_singular() ) {
				$post_id = false;
			}
			// Front page is the posts page.
			if ( isset( $object_id ) && 'posts' == get_option( 'show_on_front' ) && is_home() ) {
				$post_id = $object_id;
			}
			// The woocommerce shop page.
			if ( class_exists( 'WooCommerce' ) && ( is_shop() || is_tax( 'product_cat' ) || is_tax( 'product_tag' ) ) ) {
				$post_id = get_option( 'woocommerce_shop_page_id' );
			}
		}

		return $post_id;
	}
}


/*  Is shop installed
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_is_shop_installed') ) {
	function suround_is_shop_installed() {
		global $woocommerce;
		if ( isset( $woocommerce ) ) {
			return true;
		} else {
			return false;
		}
	}
}

/*  Is product
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_is_product') ) {
	function suround_is_product() {
		return is_singular( array( 'product' ) );
	}
}

/*  Get WC page id
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_wc_get_page_id') ) {
	function suround_wc_get_page_id($page ) {

		if ( $page == 'pay' || $page == 'thanks' ) {
			_deprecated_argument( __FUNCTION__, '2.1', 'The "pay" and "thanks" pages are no-longer used - an endpoint is added to the checkout instead. To get a valid link use the WC_Order::get_checkout_payment_url() or WC_Order::get_checkout_order_received_url() methods instead.' );

			$page = 'checkout';
		}
		if ( $page == 'change_password' || $page == 'edit_address' || $page == 'lost_password' ) {
			_deprecated_argument( __FUNCTION__, '2.1', 'The "change_password", "edit_address" and "lost_password" pages are no-longer used - an endpoint is added to the my-account instead. To get a valid link use the wc_customer_edit_account_url() function instead.' );

			$page = 'myaccount';
		}

		$page = apply_filters( 'woocommerce_get_' . $page . '_page_id', get_option('woocommerce_' . $page . '_page_id' ) );

		return $page ? absint( $page ) : -1;
	}
}


/*  Is shop
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_is_shop_archive') ) {
	function suround_is_shop_archive() {
		return is_post_type_archive( 'product' );
	}
}

/*  Is product tax
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_is_product_tax') ) {
	function suround_is_product_tax() {
		return is_tax( get_object_taxonomies( 'product' ) );
	}
}

/*  Is product category
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_is_product_category') ) {
	function suround_is_product_category($term = '' ) {
		return is_tax( 'product_cat', $term );
	}
}

/*  Is product tag
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_is_product_tag') ) {
	function suround_is_product_tag($term = '' ) {
		return is_tax( 'product_tag', $term );
	}
}

/*  Is really woocommerce pages
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_is_realy_woocommerce_page') ) {
	function suround_is_realy_woocommerce_page( $shop_archive = true ) {

		if ( $shop_archive ) {
			if ( suround_is_shop_archive() || suround_is_product_tax() || suround_is_product() ) {
				return true;
			}
		}

		$woocommerce_keys = array( 'suround_woocommerce_shop_page_id',
			"woocommerce_terms_page_id",
			"woocommerce_cart_page_id",
			"woocommerce_checkout_page_id",
			"woocommerce_pay_page_id",
			"woocommerce_thanks_page_id",
			"woocommerce_myaccount_page_id",
			"woocommerce_edit_address_page_id",
			"woocommerce_view_order_page_id",
			"woocommerce_change_password_page_id",
			"woocommerce_logout_page_id",
			"woocommerce_lost_password_page_id"
		);

		foreach ( $woocommerce_keys as $wc_page_id ) {

			if ( $wc_page_id == 0 ) continue;

			if ( get_the_ID() == get_option($wc_page_id, 0 ) ) {
				return true;
			}
		}
		return false;
	}
}

/*	Debug function print_r
/* ---------------------------------------------------------------------- */

if ( !function_exists('t_print_r') ) {
	function t_print_r( $arr ) {
		echo "<pre>";
		print_r($arr);
		echo "</pre>";
	}
}

/*	Oembed html filter
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_oembed_html') ) {

	function suround_oembed_html($return) {

		$findme = 'https://twitter.com';

		$pos = strpos($return, $findme);

		if ( $pos ) {
			return $return;
		}

		return '<div class="responsive-iframe">' . $return . '</div>';
	}
	add_filter('embed_oembed_html', 'suround_oembed_html');
}


/*  Get Blog ID
/* ---------------------------------------------------------------------- */

if ( ! function_exists('suround_get_blog_id') ) {
	function suround_get_blog_id() {
		return apply_filters( 'suround_get_blog_id', get_current_blog_id() );
	}
}

/*	String Truncate
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_string_truncate') ) {
	function suround_string_truncate($string, $limit, $break=".", $pad="...", $stripClean = false, $excludetags = '<strong><em><span>', $safe_truncate = false) {
		if ( empty($limit) ) return $string;

		if ( $stripClean ) {
			$string = strip_shortcodes(strip_tags($string, $excludetags));
		}

		if ( strlen($string) <= $limit ) return $string;

		if ( false !== ($breakpoint = strpos($string, $break, $limit)) ) {
			if ($breakpoint < strlen($string) - 1) {
				if ($safe_truncate || is_rtl()) {
					$string = mb_strimwidth($string, 0, $breakpoint) . $pad;
				} else {
					$string = substr($string, 0, $breakpoint) . $pad;
				}
			}
		}

		// if there is no breakpoint an no tags we could accidentaly split split inside a word
		if ( !$breakpoint && strlen(strip_tags($string)) == strlen($string) ) {
			if ( $safe_truncate || is_rtl() ) {
				$string = mb_strimwidth($string, 0, $limit) . $pad;
			} else {
				$string = substr($string, 0, $limit) . $pad;
			}
		}

		return $string;
	}
}


/*	Get Site Icon
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_get_site_icon_url') ) {

	function suround_get_site_icon_url($size = 512, $url = '' ) {

		global $suround_settings;

		$site_icon_id = '';
		$favicon_url = $suround_settings['favicon']['url'];
		if ( isset($suround_settings['favicon']['id']) ) {
			$site_icon_id = $suround_settings['favicon']['id'];
		}

		if ( $site_icon_id ) {
			if ( $size >= 512 ) {
				$size_data = 'full';
			} else {
				$size_data = array( $size, $size );
			}

			$url_data = wp_get_attachment_image_src( $site_icon_id, $size_data );
			if ( $url_data ) {
				$url = $url_data[0];
			}
		} elseif( $favicon_url ) {
			return $favicon_url;
		}

		return $url;
	}
}

/*	Site Icon
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_wp_site_icon') ) {

	function suround_wp_site_icon() {

		if ( !has_site_icon() ) {

			global $suround_settings;

			$favicon = $suround_settings['favicon'];

			if ( ! $favicon ) { return; }

			$meta_tags = array(
				sprintf( '<link rel="icon" href="%s" sizes="32x32" />', esc_url( suround_get_site_icon_url( 32 ) ) ),
				sprintf( '<link rel="icon" href="%s" sizes="192x192" />', esc_url( suround_get_site_icon_url( 192 ) ) ),
				sprintf( '<link rel="apple-touch-icon-precomposed" href="%s">', esc_url( suround_get_site_icon_url( 180 ) ) ),
				sprintf( '<meta name="msapplication-TileImage" content="%s">', esc_url( suround_get_site_icon_url( 270 ) ) ),
			);

			$meta_tags = array_filter( $meta_tags );

			foreach ( $meta_tags as $meta_tag ) {
				echo "$meta_tag\n";
			}

		}

	}
}
add_action( 'wp_head', 'suround_wp_site_icon', 99 );

/*	Tag Archive Page
/* ---------------------------------------------------------------------- */

add_action( 'pre_get_posts', 'suround_pre_get_posts' );

if ( !function_exists( 'suround_pre_get_posts' ) ):
	function suround_pre_get_posts( $query ) {

		if ( !is_admin() && $query->is_main_query() ) {

			$template = suround_detect_template();
			$obj = get_queried_object();
			$ppp = suround_get_option( $template . '_ppp' );

			if ( $ppp == 'custom' ) {
				$ppp_num = absint( suround_get_option( $template . '_ppp_num' ) );
				$query->set( 'posts_per_page', $ppp_num );
			}

			if ( $template == 'category' ) {

				$meta = suround_get_category_meta( $obj->term_id );
				$args = array();

				if ( $meta['layout']['type'] == 'custom' ) {
					$args['orderby'] = $meta['layout']['order'];
					$query->set( 'posts_per_page', $meta['layout']['ppp'] );
					$query->set( 'orderby', $args['orderby'] );
				} else {
					$args['orderby'] = suround_get_option( 'category_order' );
					$query->set( 'posts_per_page', suround_get_option('category_ppp_num') );
					$query->set( 'orderby', $args['orderby'] );
				}

				if ( $args['orderby'] == 'views' && function_exists( 'ev_get_meta_key' ) ) {
					$args['orderby'] = 'meta_value_num';
					$args['meta_key'] = ev_get_meta_key();

					$query->set( 'orderby', $args['orderby'] );
					$query->set( 'meta_key', $args['meta_key'] );
				}

			}

		}

	}
endif;

/* 	Filter Hook for Comments
/* --------------------------------------------------------------------- */

if ( !function_exists('suround_output_comments') ) {

	function suround_output_comments($comment, $args, $depth) {
		$GLOBALS['comment'] = $comment; ?>

		<li class="comment" id="comment-<?php echo comment_ID() ?>">

			<article>

				<!-- - - - - - - - - - - - - - Avatar - - - - - - - - - - - - - - - - -->

				<div class="gravatar">
					<?php echo get_avatar( $comment, 84, '', esc_html( get_comment_author() ) ); ?>
				</div>

				<!-- - - - - - - - - - - - - - End of avatar - - - - - - - - - - - - - - - - -->

				<!-- - - - - - - - - - - - - - Comment body - - - - - - - - - - - - - - - - -->

				<div class="comment-body">

					<header class="comment-meta">

						<?php
						$author = '<h6 class="comment-author">'. get_comment_author() .'</h6>';
						$link = get_comment_author_url();
						if ( !empty($link) ) {
							$author = '<h6 class="comment-author"><a href="' . esc_url($link) . '">' . $author . '</a></h6>';
						}
						echo sprintf( '%s', $author );
						?>

						<div class="comment-info">
							<div class="entry-meta">

								<?php
								echo sprintf( '<time class="entry-date" datetime="%1$s">%2$s</time>',
									esc_attr( get_the_date( 'c' ) ),
									esc_attr( get_the_date( 'F j, Y, h:i A' ) )
								);
								?>

								<?php edit_comment_link( esc_html__( 'Edit', 'surround' ), '[', ']' ); ?>

							</div><!--/ .entry-meta-->
						</div><!--/ .comment-info-->

					</header><!--/ .comment-meta-->

					<?php comment_text(); ?>

					<?php
					echo get_comment_reply_link(array_merge(
						array( 'reply_text' => esc_html__('Reply', 'surround' ) ),
						array( 'depth' => $depth, 'max_depth' => $args['max_depth'] )
					));
					?>

				</div><!--/ .comment-body-->

				<!-- - - - - - - - - - - - - - End of comment body - - - - - - - - - - - - - - - - -->

			</article>

		<?php
	}
}

/* 	Breadcrumbs
/* --------------------------------------------------------------------- */

if ( !function_exists('suround_breadcrumbs') ) {
	function suround_breadcrumbs() {
		if ( function_exists( 'bcn_display' ) ) {
			echo '<nav class="breadcrumb-path">';

			if ( is_author() ) {
			} else {
				bcn_display();
			}

			echo '</nav>';
		}
	}
}

/*	Comments fields
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_comments_form_fields') ) {

	function suround_comments_form_fields($comment_fields) {
		$a = $comment_fields;
		$a = array_reverse($a);
		$b = array_pop($a);
		$a = array_reverse($a);
		$a['comment'] = $b;

		return $a;
	}

	add_filter('comment_form_fields', 'suround_comments_form_fields');

}

/*	Array to data string
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_create_data_string') ) {
	function suround_create_data_string($data = array() ) {
		$data_string = "";

		if ( empty($data) ) return;

		foreach ( $data as $key => $value ) {
			if ( is_array($value) ) $value = implode(", ", $value);
			$data_string .= " data-$key='$value' ";
		}
		return $data_string;
	}
}

function suround_add_px_unit($value) {
	return sprintf('%spx', $value);
}

/**
 * Converts a multidimensional array of CSS rules into a CSS string.
 *
 * @param array $rules
 *   An array of CSS rules in the form of:
 *   array('selector'=>array('property' => 'value')). Also supports selector
 *   nesting, e.g.,
 *   array('selector' => array('selector'=>array('property' => 'value'))).
 *
 * @return string
 *   A CSS string of rules. This is not wrapped in <style> tags.
 */
function suround_generate_css_properties($rules, $indent = 0) {
	$css = '';
	$prefix = str_repeat('  ', $indent);

	foreach ($rules as $key => $value) {
		if (is_array($value)) {
			$selector = $key;
			$properties = $value;

			$css .= $prefix . "$selector {\n";
			$css .= $prefix .suround_generate_css_properties($properties, $indent + 1);
			$css .= $prefix . "}\n";
		}
		else {
			$property = $key;
			$css .= $prefix . "$property: $value;\n";
		}
	}
	return $css;
}

/*	Title
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_page_title') ) {

	function suround_page_title($args = false, $id = false ) {

		if ( empty($id) ) $id = suround_post_id();

		$defaults = array(
			'title' 	  => get_the_title($id),
			'subtitle'    => "",
			'output_html' => "<{heading} {attributes} class='page-title {class}'>{title}</{heading}>{additions}",
			'attributes'  => '',
			'class'		  => '',
			'heading'	  => 'h1',
			'additions'	  => ""
		);

		$args = wp_parse_args($args, $defaults);
		extract( $args, EXTR_SKIP );

		if ( !empty($subtitle) ) {
			$class .= ' with-subtitle';
			$additions .= "<div class='title-meta'>" . do_shortcode(wpautop($subtitle)) . "</div>";
		}

		$output_html = str_replace('{class}', $class, $output_html);
		$output_html = str_replace('{attributes}', $attributes, $output_html);
		$output_html = str_replace('{heading}', $heading, $output_html);
		$output_html = str_replace('{title}', $title, $output_html);
		$output_html = str_replace('{additions}', $additions, $output_html);
		return $output_html;
	}
}

/*	Which Archive
/* ---------------------------------------------------------------------- */

if ( !function_exists('suround_which_archive') ) {

	function suround_which_archive() {

		ob_start(); ?>

		<?php if ( is_category() ): ?>

			<?php echo esc_html__('Archive for Category:', 'surround' ) . " " . single_cat_title('', false); ?>

		<?php elseif ( is_day() ): ?>

			<?php echo esc_html__('Daily Archives:', 'surround' ) . " " . get_the_time( esc_html__('F jS, Y', 'surround' )); ?>

		<?php elseif ( is_month() ): ?>

			<?php echo esc_html__('Monthly Archives:', 'surround' ) . " " . get_the_time( esc_html__('F, Y', 'surround' )); ?>

		<?php elseif ( is_year() ): ?>

			<?php echo esc_html__('Yearly Archives:', 'surround' ) . " " . get_the_time( esc_html__('Y', 'surround' )); ?>

		<?php elseif ( is_search() ): global $wp_query; ?>

			<?php if ( !empty($wp_query->found_posts) ): ?>

				<?php if ( $wp_query->found_posts > 1 ): ?>

					<?php echo esc_html__('Search results for:', 'surround' ) . " " . esc_attr(get_search_query()) . " (" . $wp_query->found_posts . ")"; ?>

				<?php else: ?>

					<?php echo esc_html__('Search result for:', 'surround' ) . " " . esc_attr(get_search_query()) . " (" . $wp_query->found_posts . ")"; ?>

				<?php endif; ?>

			<?php else: ?>

				<?php if ( !empty($_GET['s']) ): ?>

					<?php echo esc_html__('Search results for:', 'surround' ) . " " . esc_attr(get_search_query()); ?>

				<?php else: ?>

					<?php echo esc_html__('To search the site please enter a valid term', 'surround' ); ?>

				<?php endif; ?>

			<?php endif; ?>

		<?php elseif ( is_author() ): ?>

			<?php $auth = ( get_query_var('author_name') ) ? get_user_by('slug', get_query_var('author_name')) : get_userdata(get_query_var('author')); ?>

			<?php if ( isset($auth->nickname) && isset($auth->ID) ): ?>

				<?php $name = $auth->nickname; ?>

				<?php echo esc_html__('Author Archive', 'surround' ); ?>
				<?php echo esc_html__('for:', 'surround' ) . " " . $name; ?>

			<?php endif; ?>

		<?php elseif ( is_tag() ): ?>

			<?php echo esc_html__('Posts tagged &ldquo;', 'surround' ) . " " . single_tag_title('', false) . '&rdquo;'; ?>

			<?php
			$term_description = term_description();
			if ( ! empty( $term_description ) ) {
				printf( '<div class="taxonomy-description">%s</div>', $term_description );
			}
			?>

		<?php elseif ( is_tax() ): ?>

			<?php $term = get_term_by('slug', get_query_var('term'), get_query_var('taxonomy')); ?>

			<?php echo esc_html__('Archive for:', 'surround' ) . " " . $term->name; ?>

		<?php else: ?>

			<?php if ( is_post_type_archive() ): ?>
				<?php echo sprintf(__('Archive %s', 'surround' ), get_query_var('post_type')); ?>
			<?php else: ?>
				<?php echo esc_html__('Archive', 'surround' ); ?>
			<?php endif; ?>

		<?php endif; ?>

		<?php return ob_get_clean();
	}
}

if ( !function_exists('suround_popup_video') ) {

	function suround_popup_video() {

		if ( empty($_POST['id']) ) return;

		echo suround_media_grabber(array(
			'post_id' => absint($_POST['id'])
		));

		wp_die();
	}

	add_action( 'wp_ajax_suround_popup_video', 'suround_popup_video' );
	add_action( 'wp_ajax_nopriv_suround_popup_video', 'suround_popup_video' );

}

if ( !function_exists('suround_page_title_get_value') ) {

	function suround_page_title_get_value( $meta_key = false ) {
		$value = false;
		$page_title = get_post_meta( suround_post_id(), 'suround_page_title', true );

		if ( $meta_key ) {
			if ( isset($page_title[$meta_key]) ) {
				$value = $page_title[$meta_key];
			}
		}

		return $value;
	}

}

if ( !function_exists('suround_footer_get_widget_settings')) {
	function suround_footer_get_widget_settings( $post_id ) {
		$results = array();
		$results['footer_row_show'] = get_post_meta($post_id, 'footer_row_show', true);
		$results['get_sidebars_widgets'] = get_post_meta($post_id, 'get_sidebars_widgets', true);
		$results['footer_row_columns_variations'] = get_post_meta($post_id, 'footer_row_columns_variations', true);
		$results['footer_row_full_width'] = get_post_meta($post_id, 'footer_row_full_width', true);

		if ( $results['footer_row_show'] == null ) {
			$results['footer_row_show'] = 1;
		}

		if ( $results['footer_row_columns_variations'] == null ) {
			$results['footer_row_columns_variations'] = '{"4":[["3","3","3","3"]]}';
		}

		if ( $results['get_sidebars_widgets'] == null ) {
			$results['get_sidebars_widgets'] = array(
				'footer-row-1',
				'footer-row-2',
				'footer-row-3',
				'footer-row-4',
				'footer-row-5'
			);
		}

		return $results;
	}
}