<?php

class Suround_Composer_Add_Field {

	public function __construct($url) {

		WpbakeryShortcodeParams::addField( 'dropdown_multi', array( $this, 'dropdown_multi_settings_field') );
		WpbakeryShortcodeParams::addField( 'image_select', array( $this, 'image_select_settings_field'), $url . 'js/js_image_select.js' );
		WpbakeryShortcodeParams::addField( 'choose_icons', array( $this, 'param_icon_field'), $url . 'js/js_shortcode_param_icon.js' );
		WpbakeryShortcodeParams::addField( 'table_number', array( $this, 'param_table_number_field'), $url . 'js/js_shortcode_tables.js' );
		WpbakeryShortcodeParams::addField( 'table_hidden', array( $this, 'param_hidden_field') );
		WpbakeryShortcodeParams::addField( 'datetimepicker', array( $this, 'param_datetimepicker'), $url . 'js/bootstrap-datetimepicker.min.js' );
		WpbakeryShortcodeParams::addField( 'number', array( $this, 'param_number_field') );
		WpbakeryShortcodeParams::addField( 'get_terms', array( $this, 'param_woocommerce_terms'), $url . 'js/js_shortcode_products.js' );
		WpbakeryShortcodeParams::addField( 'get_by_id', array( $this, 'param_woocommerce_get_by_id'), $url . 'js/js_shortcode_products.js' );

		vc_remove_param( 'vc_column', 'css_animation' );

		$vc_row_settings = [
			array (
				'type' => 'colorpicker',
				'heading' => esc_html__( 'Overlay background color', 'surround' ),
				'param_name' => 'overlay_color',
				'description' => esc_html__( 'Select custom overlay color for background. ( For mobile devices )', 'surround' ),
				'dependency' => array(
					'element' => 'parallax',
					'not_empty' => true,
				),
				'group' => esc_html__( 'Parallax', 'surround' )
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Background Blend Mode', 'surround' ),
				'param_name' => 'blend_mode',
				'value' => array(
					esc_html__('None', 'surround' ) => 'none',
					esc_html__('Multiply', 'surround' ) => 'multiply'
				),
				'group' => esc_html__( 'Design Options', 'surround' )
			)
		];

		vc_add_params( 'vc_row', $vc_row_settings );

		$vc_custom_heading_settings = array (
			'type' => 'textfield',
			'heading' => esc_html__( 'Letter Spacing', 'surround' ),
			'param_name' => 'letter_spacing',
		);
		vc_add_param( 'vc_custom_heading', $vc_custom_heading_settings );

	}


	function image_select_settings_field( $param, $value ) {

		$param_name = isset($param['param_name']) ? $param['param_name'] : '';

		ob_start(); ?>

		<div class="img-wrap-container">

			<ul class="img-select-wrap">

				<?php foreach( $param['value'] as $text_val => $val ): ?>

					<?php $selected_class = suround_compare( $text_val, $value ) ? ' selected': ''; ?>

					<li data-col="<?php echo esc_attr($val['col']) ?>" class="<?php echo esc_attr($selected_class) ?>" data-value="<?php echo esc_attr($text_val) ?>">
						<img src="<?php echo esc_url($val['img']) ?>" title="<?php echo esc_attr($val['title']) ?>" alt="<?php echo esc_attr($val['title']) ?>" class="img-select" />
						<span><?php echo esc_html($val['title']) ?></span>
					</li>

				<?php endforeach; ?>

			</ul>

			<input type="hidden" class="wpb_vc_param_value" name="<?php echo esc_attr( $param_name ) ?>" value="<?php echo esc_attr($value) ?>" />

		</div>

		<?php return ob_get_clean();
	}

	function dropdown_multi_settings_field( $param, $value ) {
		$param_line = '';
		$param_line .= '<select multiple name="'. esc_attr( $param['param_name'] ).'" class="wpb_vc_param_value wpb-input wpb-select '. esc_attr( $param['param_name'] ).' '. esc_attr($param['type']).'">';
		foreach ( $param['value'] as $text_val => $val ) {
			if ( is_numeric($text_val) && (is_string($val) || is_numeric($val)) ) {
				$text_val = $val;
			}
			$selected = '';

			if(!is_array($value)) {
				$param_value_arr = explode(',',$value);
			} else {
				$param_value_arr = $value;
			}

			if ($value!=='' && in_array($val, $param_value_arr)) {
				$selected = ' selected="selected"';
			}
			$param_line .= '<option class="'.$val.'" value="'.$val.'"'.$selected.'>'.$text_val.'</option>';
		}
		$param_line .= '</select>';

		return  $param_line;
	}

	public function param_icon_field($settings, $value) {
		$param_name = isset($settings['param_name']) ? $settings['param_name'] : '';
		$type = isset($settings['type']) ? $settings['type'] : '';
		$class = isset($settings['class']) ? $settings['class'] : '';
		$icons = apply_filters( 'suround_param_icons', array( ' ', 'licon-map-marker-check', 'licon-chevron-right', 'licon-download', 'licon-download2', 'licon-upload', 'licon-arrow-right', 'licon-check', 'cicon-eye', 'cicon-tickets', 'cicon-hotel', 'cicon-passanger', 'cicon-coliseum', 'licon-plus', 'licon-plus-circle', 'licon-pointer-right', 'licon-chevron-right-circle', 'cicon-globe2', 'cicon-location', 'cicon-traveler2', 'cicon-pictures' ) );

		ob_start(); ?>

		<div id="mad-param-icon">
			<input type="hidden" name="<?php echo esc_attr($param_name) ?>" class="wpb_vc_param_value <?php echo esc_attr($param_name) . ' ' . esc_attr($type) . ' ' . esc_attr($class) ?> " value="<?php echo esc_attr($value) ?>" id="mad-trace" />
			<div class="mad-icon-preview"><i class="<?php echo esc_attr($value) ?>"></i></div>
			<input class="mad-search" type="text" placeholder="<?php esc_attr_e( 'Search icon', 'surround' ) ?>" />
			<div id="mad-icon-dropdown">
				<ul class="mad-icon-list">

					<?php foreach ( $icons as $icon ): ?>

						<?php if ( !empty($icon) ): ?>

							<?php $selected = ( $icon == $value ) ? 'class="selected"' : ''; ?>

							<li <?php echo sprintf('%s', $selected) ?> data-icon="<?php echo esc_attr($icon) ?>">

								<?php if ( substr($icon, 0, 5) == 'licon' || substr($icon, 0, 5) == 'cicon' ): ?>
									<span class="<?php echo esc_attr($icon) ?>"></span>
								<?php endif; ?>

							</li>

						<?php endif; ?>

					<?php endforeach; ?>

				</ul><!--/ .mad-icon-list-->

			</div><!--/ #mad-icon-dropdown-->

		</div>

		<?php return ob_get_clean();
	}

	function param_table_number_field($settings, $value) {
		ob_start(); ?>
		<div class="mad_number_block">
			<input id="<?php echo esc_attr($settings['param_name']) ?>" name="<?php echo esc_attr($settings['param_name']) ?>" class="wpb_vc_param_value wpb-number <?php echo esc_attr($settings['param_name']) . ' ' . esc_attr($settings['type']) . '_field'  ?>" type="number" value="<?php echo esc_attr($value) ?>"/>
		</div><!--/ .mad_number_block-->
		<?php return ob_get_clean();
	}

	function param_hidden_field($settings, $value) {
		$param_name = isset($settings['param_name']) ? $settings['param_name'] : '';
		$type = isset($settings['type']) ? $settings['type'] : '';
		$class = isset($settings['class']) ? $settings['class'] : '';
		ob_start(); ?>
		<input type="hidden" name="<?php echo esc_attr($param_name) ?>" class="wpb_vc_param_value wpb_el_type_table_hidden <?php echo sanitize_html_class($param_name) . ' ' . $type . ' ' . $class ?>" value="<?php echo trim($value) ?>" />
		<?php return ob_get_clean();
	}

	function param_datetimepicker($settings, $value) {
		$dependency = '';
		$param_name = isset($settings['param_name']) ? $settings['param_name'] : '';
		$type = isset($settings['type']) ? $settings['type'] : '';
		$class = isset($settings['class']) ? $settings['class'] : '';
		$uni = uniqid('datetimepicker-'.rand());
		$output = '<div id="ult-date-time' . $uni . '" class="ult-datetime"><input data-format="yyyy/MM/dd hh:mm:ss" readonly class="wpb_vc_param_value ' . $param_name . ' ' . $type . ' ' . $class . '" name="' . $param_name . '" style="width:258px;" value="'.$value.'" '.$dependency.'/><div class="add-on"></div></div>';
		return $output;
	}

	function param_number_field($settings, $value) {
		ob_start(); ?>
		<div class="mad_number_block">
			<input id="<?php echo esc_attr($settings['param_name']) ?>" name="<?php echo esc_attr($settings['param_name']) ?>" class="wpb_vc_param_value wpb-number <?php echo esc_attr($settings['param_name']) . ' ' . esc_attr($settings['type']) . '_field'  ?>" type="number" value="<?php echo esc_attr($value) ?>"/>
		</div><!--/ .mad_number_block-->
		<?php return ob_get_clean();
	}

	function get_product_terms( $term_id, $tax, $inserted_vals ) {
		$html = $selected = '';
		$args = array( 'taxonomy' => $tax, 'hide_empty' => 0, 'parent' => $term_id );
		$terms = get_terms($args);

		foreach ($terms as $term) {
			$html .= '<li><a ';

			if ( in_array($term->slug, $inserted_vals) ) {
				$html .= ' class="selected"';
			}

			$html .= 'data-val="'. $term->slug .'" title="'. $term->term_id .'" href="javascript:void(0);">' . $term->name . '</a>';

			if ( $list = $this->get_product_terms( $term->term_id, $tax, $inserted_vals )) {
				$html .= '<ul class="second_level">'. $list .'</ul>';
			}

			$html .= '</li>';
		}
		return $html;
	}

	function param_woocommerce_terms($settings, $value) {

		$html = '';
		$terms = get_terms(
			array(
				'taxonomy' => $settings['term'],
				'hide_empty' => 0,
				'parent' => 0
			)
		);
		$inserted_vals = explode(',', $value);

		ob_start(); ?>

		<input type="text" value="<?php echo esc_attr($value) ?>" name="<?php echo esc_attr($settings['param_name']) ?>" class="wpb_vc_param_value wpb-input mad-custom-val <?php echo esc_attr($settings['param_name']) . ' ' . esc_attr($settings['type']) ?>" id="<?php echo esc_attr($settings['param_name']); ?>">

		<div class="mad-custom-wrapper">

			<ul class="mad-custom">

				<?php

				foreach ($terms as $term) {
					$html .= '<li class="top_li">';

					$html .= '<a ';

					if ( in_array($term->slug, $inserted_vals) ) {
						$html .= ' class="selected"';
					}

					$html .= 'data-val="'. $term->slug .'" title="'. $term->term_id .'" href="javascript:void(0);">' . $term->name . '</a>';

					if ( $list = $this->get_product_terms( $term->term_id, $settings['term'], $inserted_vals )) {
						$html .= '<ul class="second_level">'. $list .'</ul>';
					}

					$html .= '</li>';
				}
				echo sprintf('%s', $html);
				?>

			</ul><!--/ .mad-custom-->

		</div><!--/ .mad-custom-wrapper-->

		<?php return ob_get_clean();
	}

	public function param_woocommerce_get_by_id($settings, $value) {

		$html = '';
		$inserted_vals = explode(',', $value);

		$args = array(
			'post_type' => $settings["post_type"],
			'numberposts' => -1
		);

		$posts = get_posts( $args );

		ob_start(); ?>

		<input type="text" value="<?php echo esc_attr($value) ?>" name="<?php echo esc_attr($settings['param_name']) ?>" class="wpb_vc_param_value wpb-input mad-custom-val <?php echo esc_attr($settings['param_name']) . ' ' . esc_attr($settings['type']) ?>" id="<?php echo esc_attr($settings['param_name']); ?>">

		<div class="mad-custom-wrapper">

			<ul class="mad-custom">

				<?php

				foreach ($posts as $post) {
					$html .= '<li class="top_li">';

					$html .= '<a ';

					if ( in_array($post->ID, $inserted_vals) ) {
						$html .= ' class="selected"';
					}

					$html .= 'data-val="'. $post->ID .'" title="'. $post->ID .'" href="javascript:void(0);">' . $post->post_title . '</a>';

					$html .= '</li>';
				}

				if ($html != '') { echo sprintf('%s', $html); }
				?>

			</ul><!--/ .mad-custom-->

		</div><!--/ .mad-custom-wrapper-->

		<?php return ob_get_clean();
	}

}