<?php

use MailPoet\Form\FormsRepository as FormsRepository;
use MailPoet\DI\ContainerWrapper;

$target_arr = array(
	esc_html__( 'Same window', 'surround' ) => '_self',
	esc_html__( 'New window', 'surround' )  => '_blank',
);

/* Default Custom Shortcodes
/* --------------------------------------------------------------------- */

/* Custom Heading element
----------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Custom Heading', 'surround' ),
	'base' => 'vc_custom_heading',
	'icon' => 'icon-wpb-ui-custom_heading',
	'show_settings_on_create' => true,
	'category' => esc_html__( 'Content', 'surround' ),
	'description' => esc_html__( 'Text with Google fonts', 'surround' ),
	'params' => array(
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Text source', 'surround' ),
			'param_name' => 'source',
			'value' => array(
				esc_html__( 'Custom text', 'surround' )        => '',
				esc_html__( 'Post or Page Title', 'surround' ) => 'post_title',
			),
			'std' => '',
			'description' => esc_html__( 'Select text source.', 'surround' ),
		),
		array(
			'type' => 'textarea',
			'heading' => esc_html__( 'Text', 'surround' ),
			'param_name' => 'text',
			'admin_label' => true,
			'value' => esc_html__( 'This is custom heading element', 'surround' ),
			'description' => esc_html__( 'Note: If you are using non-latin characters be sure to activate them under Settings/Visual Composer/General Settings.', 'surround' ),
			'dependency' => array(
				'element' => 'source',
				'is_empty' => true,
			),
		),
		array(
			'type' => 'vc_link',
			'heading' => esc_html__( 'URL (Link)', 'surround' ),
			'param_name' => 'link',
			'description' => esc_html__( 'Add link to custom heading.', 'surround' ),
		),
		array(
			'type' => 'font_container',
			'param_name' => 'font_container',
			'value' => 'tag:h2|text_align:left',
			'settings' => array(
				'fields' => array(
					'tag' => 'h2',
					'text_align',
					'font_size',
					'line_height',
					'color',
					'tag_description' => esc_html__( 'Select element tag.', 'surround' ),
					'text_align_description' => esc_html__( 'Select text alignment.', 'surround' ),
					'font_size_description' => esc_html__( 'Enter font size.', 'surround' ),
					'line_height_description' => esc_html__( 'Enter line height.', 'surround' ),
					'color_description' => esc_html__( 'Select heading color.', 'surround' ),
				),
			),
		),
		array(
			'type' => 'checkbox',
			'heading' => esc_html__( 'Use theme default font family?', 'surround' ),
			'param_name' => 'use_theme_fonts',
			'value' => array( esc_html__( 'Yes', 'surround' ) => 'yes' ),
			'description' => esc_html__( 'Use font family from the theme.', 'surround' ),
			'std' => 'yes'
		),
		array(
			'type' => 'google_fonts',
			'param_name' => 'google_fonts',
			'value' => 'font_family:Lora:200,200italic,300,300italic,regular',
			'settings' => array(
				'fields' => array(
					'font_family_description' => esc_html__( 'Select font family.', 'surround' ),
					'font_style_description' => esc_html__( 'Select font styling.', 'surround' ),
				),
			),
			'dependency' => array(
				'element' => 'use_theme_fonts',
				'value_not_equal_to' => 'yes',
			),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Extra class name', 'surround' ),
			'param_name' => 'el_class',
			'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'surround' ),
		),
		array(
			'type' => 'css_editor',
			'heading' => esc_html__( 'CSS box', 'surround' ),
			'param_name' => 'css',
			'group' => esc_html__( 'Design Options', 'surround' ),
		),
		vc_map_add_css_animation()
	),
) );

/* Theme Shortcodes
/* ---------------------------------------------------------------- */


/*  Authors
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Authors', 'surround' ),
	'base' => 'vc_mad_authors',
	'icon' => 'icon-wpb-authors',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Get authors', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Items', 'surround'),
			'param_name' => 'items',
			'value' => '',
			'std' => 8,
			'description' => esc_html__( 'How many items should be displayed per page?', 'surround')
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Pagination', 'surround' ),
			'param_name' => 'paginate',
			'value' => array(
				esc_html__( 'Display Pagination', 'surround' )                   => 'pagination',
				esc_html__( 'No option to view additional entries', 'surround' ) => 'none'
			),
			'std' => 'none',
			'description' => esc_html__( 'Should a pagination be displayed?', 'surround' )
		),
	)
) );

/*  Social Links
---------------------------------------------------------- */


vc_map( array(
	'name' => esc_html__( 'Social Links', 'surround' ),
	'base' => 'vc_mad_social_links',
	'icon' => 'icon-wpb-map-contact',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Social links', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Title', 'surround' ),
			'param_name' => 'title',
			'admin_label' => true,
			'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' )
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Facebook Link', 'surround' ),
			'param_name' => 'facebook_link',
			'std' => ''
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Twitter Link', 'surround' ),
			'param_name' => 'twitter_link',
			'std' => ''
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Google+ Link', 'surround' ),
			'param_name' => 'gplus_link',
			'std' => ''
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Instagram Link', 'surround' ),
			'param_name' => 'instagram_link',
			'std' => ''
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Youtube Link', 'surround' ),
			'param_name' => 'youtube_link',
			'std' => ''
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Pinterest Link', 'surround' ),
			'param_name' => 'pinterest_link',
			'std' => ''
		),
	)
) );


/* Contact Information
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Contact Information', 'surround' ),
	'base' => 'vc_mad_contact_info',
	'icon' => 'icon-wpb-map-contact',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Contact Information', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Title', 'surround' ),
			'param_name' => 'title',
			'admin_label' => true,
			'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' )
		),
		array(
			'type' => 'textarea',
			'heading' => esc_html__( 'Address', 'surround' ),
			'param_name' => 'info_location',
			'admin_label' => true,
			'validate' => 'html_custom',
			'allowed_html' => array(
				'a' => array(
					'href' => array(),
					'title' => array()
				),
				'br' => array(),
				'em' => array(),
				'strong' => array()
			),
			'description' => esc_html__( 'Enter address.', 'surround' )
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Phone', 'surround' ),
			'param_name' => 'info_phone',
			'admin_label' => true,
			'description' => esc_html__( 'Enter phone.', 'surround' )
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Fax', 'surround' ),
			'param_name' => 'info_fax',
			'admin_label' => true,
			'description' => esc_html__( 'Enter fax.', 'surround' )
		),
		array(
			"type" => "textfield",
			"param_name" => "info_email",
			"heading" => esc_html__( 'Editorial inquiries', 'surround' ),
			'admin_label' => true,
			'description' => esc_html__( 'Email', 'surround' )
		),
		array(
			"type" => "textfield",
			"param_name" => "info_email_2",
			"heading" => esc_html__( 'Advertising inquiries', 'surround' ),
			'admin_label' => true,
			'description' => esc_html__( 'Email', 'surround' )
		),
		array(
			"type" => "textfield",
			"param_name" => "info_email_3",
			"heading" => esc_html__( 'Media inquiries', 'surround' ),
			'admin_label' => true,
			'description' => esc_html__( 'Email', 'surround' )
		),
	)
) );

/* Blockquotes
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Blockquotes', 'surround'),
	'base' => 'vc_mad_blockquotes',
	'icon' => 'icon-wpb-mad-blockquotes',
	'category' => esc_html__( 'Suround', 'surround'),
	'description' => esc_html__( 'Blockquotes', 'surround'),
	'params' => array(
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Style', 'surround'),
			'param_name' => 'style',
			'value' => array(
				esc_html__('Black', 'surround') => 'style-1',
				esc_html__('Blue', 'surround') => 'style-2'
			),
			'std' => 'style-1',
			'description' => esc_html__('Choose layout style.', 'surround')
		),
		array(
			'type' => 'textarea_html',
			'holder' => 'div',
			'heading' => esc_html__( 'Text', 'surround'),
			'param_name' => 'content',
			'value' => esc_html__( 'I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', 'surround'),
		),
		array(
			'type' => 'textarea',
			'heading' => esc_html__( 'Author', 'surround' ),
			'param_name' => 'author',
			'value' => ''
		),
		array(
			'type' => 'textarea',
			'heading' => esc_html__( 'Address', 'surround' ),
			'param_name' => 'Address',
			'value' => ''
		),

	)
));

/* Button
---------------------------------------------------------- */

vc_map(array(
	'name' => esc_html__( 'Button', 'surround' ),
	'base' => 'vc_mad_btn',
	'icon' => 'icon-wpb-mad-button',
	'category' => array( esc_html__( 'Suround', 'surround' ) ),
	'description' => esc_html__( 'Eye catching button', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Text', 'surround' ),
			'param_name' => 'title',
			'value' => esc_html__( 'Text on the button', 'surround' ),
		),
		array(
			'type' => 'vc_link',
			'heading' => esc_html__( 'URL (Link)', 'surround' ),
			'param_name' => 'link',
			'description' => esc_html__( 'Add link to button.', 'surround' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Style', 'surround' ),
			'param_name' => 'style',
			'description' => esc_html__( 'Select button display style.', 'surround' ),
			'value' => array(
				esc_html__( 'Filled Black', 'surround' ) => 'btn-style-1',
				esc_html__( 'Filled Space Grey', 'surround' ) => 'btn-style-2',
				esc_html__( 'Filled Grey', 'surround' ) => 'btn-style-3',
				esc_html__( 'Filled Grey Reverse', 'surround' ) => 'btn-style-7',
				esc_html__( 'Filled Blue', 'surround' ) => 'btn-style-4',
				esc_html__( 'Outline Black', 'surround' ) => 'btn-style-5',
				esc_html__( 'Outline Blue', 'surround' ) => 'btn-style-6',
				esc_html__( 'Outline Hover Grey', 'surround' ) => 'btn-style-8',
				esc_html__( 'Outline Space Grey', 'surround' ) => 'btn-style-9',
				esc_html__( 'Yellow', 'surround' ) => 'btn-style-10',
				esc_html__( 'Outline Yellow', 'surround' ) => 'btn-style-11',
			),
			'std' => 'btn-style-1'
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Size', 'surround' ),
			'param_name' => 'size',
			'description' => esc_html__( 'Select button display size.', 'surround' ),
			'std' => 'btn-medium',
			'value' => array(
				esc_html__('Small', 'surround' )  => 'btn-small',
				esc_html__('Medium', 'surround' ) => 'btn-medium',
				esc_html__('Big', 'surround' )    => 'btn-big'
			),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Alignment', 'surround' ),
			'param_name' => 'align',
			'description' => esc_html__( 'Select button alignment.', 'surround' ),
			'value' => array(
				esc_html__( 'Inline', 'surround' ) => 'align-inline',
				esc_html__( 'Left', 'surround' )   => 'align-left',
				esc_html__( 'Right', 'surround' )  => 'align-right',
				esc_html__( 'Center', 'surround' ) => 'align-center',
			),
		),
		array(
			"type" => "choose_icons",
			"heading" => esc_html__("Icon", 'surround' ),
			"param_name" => "icon",
			"value" => 'none',
			"description" => esc_html__('Select icon from library.', 'surround' )
		),
	),
));

/* Message
---------------------------------------------------------- */

vc_map(array(
	'name' => esc_html__( 'List of the post type', 'surround' ),
	'base' => 'vc_mad_list_post_type',
	'icon' => 'icon-wpb-mad-list-post-type',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'List of the post type', 'surround' ),
	'params' => array(
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Post Type', 'surround' ),
			'param_name' => 'post_type',
			'value' => array(
				esc_html__('Post', 'surround' )         => 'post',
				esc_html__('Page', 'surround' )         => 'page',
				esc_html__('Testimonials', 'surround' ) => 'testimonials',
				esc_html__('Team Members', 'surround' ) => 'team-members',
				esc_html__('Services', 'surround' )     => 'services',
				esc_html__('Portfolio', 'surround' )    => 'portfolio',
			),
			'description' => esc_html__( 'Choose post type', 'surround' ),
		),
	),
));

/* Message
---------------------------------------------------------- */

vc_map(array(
	'name' => esc_html__( 'Message Box', 'surround' ),
	'base' => 'vc_mad_message',
	'icon' => 'icon-wpb-mad-message-box',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Notification boxes', 'surround' ),
	'params' => array(
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Style', 'surround' ),
			'param_name' => 'message_box_style',
			'value' => array(
				esc_html__('Success', 'surround' ) => 'alert-success',
				esc_html__('Warning', 'surround' ) => 'alert-warning',
				esc_html__('Info', 'surround' )    => 'alert-info',
				esc_html__('Error', 'surround' )   => 'alert-error',
			),
			'description' => esc_html__( 'Select message box style.', 'surround' ),
		),
		array(
			'type' => 'textarea_html',
			'holder' => 'div',
			'class' => 'messagebox_text',
			'heading' => esc_html__( 'Message text', 'surround' ),
			'param_name' => 'content',
			'value' => esc_html__( 'I am message box. Click edit button to change this text.', 'surround' ),
		)
	),
));

/* List Styles
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'List Styles', 'surround' ),
	'base' => 'vc_mad_list_styles',
	'icon' => 'icon-wpb-mad-list-styles',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'List styles', 'surround' ),
	'params' => array(
		array(
			'type' => 'param_group',
			'heading' => esc_html__( 'Values', 'surround' ),
			'param_name' => 'values',
			'description' => esc_html__( 'Enter values - value and title.', 'surround' ),
			'value' => urlencode( json_encode( array(
				array(
					'label' => esc_html__( 'Sed laoreet aliquam leo', 'surround' ),
					'icon'  => 'licon-map-marker-check'
				),
				array(
					'label' => esc_html__( 'Ut tellus dolor dapibus', 'surround' ),
					'icon'  => 'licon-map-marker-check'
				),
				array(
					'label' => esc_html__( 'Eget elementum vel', 'surround' ),
					'icon'  => 'licon-map-marker-check'
				)
			) ) ),
			'params' => array(
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Label', 'surround' ),
					'param_name' => 'label',
					'description' => esc_html__( 'Enter text used as title.', 'surround' ),
					'admin_label' => true,
				),
				array(
					"type" => "choose_icons",
					"heading" => esc_html__("Icon", 'surround' ),
					"param_name" => "icon",
					"value" => 'none',
					"description" => esc_html__( 'Select icon from library.', 'surround' )
				)
			)
		),
	)
) );

/* Call to Action
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Call to Action', 'surround'),
	'base' => 'vc_mad_cta',
	'icon' => 'icon-wpb-mad-cta',
	'category' => array( esc_html__( 'Suround', 'surround') ),
	'description' => esc_html__( 'Catch visitors attention with CTA block', 'surround'),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Heading', 'surround'),
			'admin_label' => true,
			'param_name' => 'h2',
			'value' => '',
			'description' => esc_html__( 'Enter text for heading line. \n = LF (Line Feed) - Used as a new line character', 'surround'),
			'edit_field_class' => 'vc_col-sm-9',
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Subheading', 'surround'),
			'param_name' => 'p',
			'value' => '',
			'description' => esc_html__( 'Enter text for subheading line.', 'surround'),
			'edit_field_class' => 'vc_col-sm-9',
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Style', 'surround'),
			'param_name' => 'style',
			'value' => array(
				esc_html__( 'Default', 'surround') => 'style-1',
				esc_html__( 'Image Left', 'surround') => 'half-bg-col'
			),
			'description' => esc_html__( 'Choose a style.', 'surround'),
		),
		array(
			'type' => 'attach_image',
			'heading' => esc_html__( 'Image', 'surround'),
			'param_name' => 'image',
			'value' => '',
			'description' => esc_html__( 'Select image from media library.', 'surround'),
			'dependency' => array(
				'element' => 'style',
				'value' => array( 'half-bg-col' )
			),
		),
		array(
			'type' => 'textarea_html',
			'holder' => 'div',
			'heading' => esc_html__( 'Text', 'surround'),
			'param_name' => 'content',
			'dependency' => array(
				'element' => 'style',
				'value' => array('half-bg-col' )
			),
			'value' => esc_html__( '<p>I am text block. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.</p>', 'surround'),
		),
		array(
			'type' => 'vc_link',
			'heading' => esc_html__( 'URL (Link)', 'surround'),
			'param_name' => 'link',
			'description' => esc_html__( 'Add link to button.', 'surround'),
			'group' => esc_html__( 'Button', 'surround'),
		),
	),
	'js_view' => 'VcCallToActionView3',
));

/* MailPoet
---------------------------------------------------------- */

if ( defined('MAILPOET_VERSION') ) {

    $mailpoet_forms = array();

    $formsRepository = ContainerWrapper::getInstance()->get(FormsRepository::class);
    $forms = $formsRepository->findBy(['deletedAt' => null], ['name' => 'asc']);

    if ( $forms ) {
        foreach( $forms as $form ) {
            $mailpoet_forms[$form->getName() ? $form->getName() : 'no name'] = $form->getId();
        }
    }

	vc_map( array(
		'name' => esc_html__( 'MailPoet Subscription Form', 'surround'),
		'base' => 'vc_mad_mailpoet',
		'icon' => 'icon-wpb-mad-mailpoet',
		'category' => array( esc_html__( 'Suround', 'surround') ),
		'description' => esc_html__( 'Subscription form for your newsletters.', 'surround'),
		'params' => array(
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Title', 'surround'),
				'param_name' => 'title',
				'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround'),
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Subheading', 'surround'),
				'param_name' => 'subheading',
				'value' => '',
				'description' => esc_html__( 'Enter text for subheading line.', 'surround'),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Style', 'surround' ),
				'param_name' => 'style',
				'value' => array(
					esc_html__( 'Style 1', 'surround' ) => 'style-1',
					esc_html__( 'Style 2', 'surround' ) => 'style-2',
				),
				'description' => esc_html__( 'Style?', 'surround' )
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Select a form', 'surround'),
				'param_name' => 'select_form',
				'value' => $mailpoet_forms,
				'description' => esc_html__( 'Select a form.', 'surround'),
			),
		)
	));

}

/* Tabs Categories
---------------------------------------------------------- */

$pages_array = array();
$pages = get_pages();

foreach( $pages as $page ){
	$pages_array[$page->post_title] = $page->ID;
}


vc_map( array(
	'name' => esc_html__( 'Tabs Post Categories', 'surround' ),
	'base' => 'vc_mad_tabs_post_categories',
	'icon' => 'icon-wpb-mad-blog-posts',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Display a list of post categories based on different criteria.', 'surround' ),
	'params' => array(
		array(
			'type' => 'number',
			'heading' => esc_html__( 'Number of items to show', 'surround' ),
			'param_name' => 'number_of_items',
			'description' => '',
			'std' => 10,
			'group' => esc_html__( 'Category Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order by', 'surround' ),
			'param_name' => 'orderby',
			'value' => array(
				esc_html__('Name', 'surround' )               => 'name',
				esc_html__('ID', 'surround' )                 => 'id',
				esc_html__('Slug', 'surround' )               => 'slug',
				esc_html__('Number of Listings', 'surround' ) => 'count',
				esc_html__('Random', 'surround' )             => 'rand'
			),
			'group' => esc_html__( 'Category Data Settings', 'surround' ),
			'std' => 'name',
			'description' => ''
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order', 'surround' ),
			'param_name' => 'order',
			'value' => array(
				esc_html__( 'DESC', 'surround' ) => 'DESC',
				esc_html__( 'ASC', 'surround' )  => 'ASC',
			),
			'std' => '',
			'description' => esc_html__( 'Direction Order', 'surround' ),
			'group' => esc_html__( 'Category Data Settings', 'surround' )
		),
		array(
			'type' => 'get_terms',
			'term' => 'category',
			'heading' => esc_html__( 'Which categories should be used?', 'surround' ),
			'param_name' => 'categories',
			'description' => esc_html__('The Page will then show categories from only those categories.', 'surround' ),
			'group' => esc_html__( 'Category Data Settings', 'surround' )
		),
		array(
			'type' => 'image_select',
			'heading' => esc_html__( 'Layout', 'surround' ),
			'param_name' => 'layout',
			'value' => array(
				'a4' => array( 'title' => esc_html__( 'Layout A4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_a4.png'), 'col' => 4 ),
				'd3' => array( 'title' => esc_html__( 'Layout D3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_d3.png'), 'col' => 4 )
			),
			'std' => 'd3',
			'description' => esc_html__( 'Choose the default layout here.', 'surround' ),
			'group' => esc_html__( 'Category Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Page Archive', 'surround' ),
			'param_name' => 'page_archive',
			'value' => $pages_array,
			'std' => '',
			'description' => esc_html__('For button View All', 'surround'),
			'group' => esc_html__( 'Category Data Settings', 'surround' )
		),

	)
) );

/* Post Category
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Post Categories', 'surround' ),
	'base' => 'vc_mad_post_categories',
	'icon' => 'icon-wpb-mad-blog-posts',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Display a list of post categories based on different criteria.', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Title', 'surround' ),
			'param_name' => 'title',
			'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Title Alignment', 'surround' ),
			'param_name' => 'align_title',
			'description' => esc_html__( 'Select title alignment.', 'surround' ),
			'value' => array(
				esc_html__( 'Left', 'surround' )   => 'align-left',
				esc_html__( 'Right', 'surround' )  => 'align-right',
				esc_html__( 'Center', 'surround' ) => 'align-center'
			)
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__('Tag', 'surround' ),
			'param_name' => 'heading',
			'value' => array(
				'h2' => 'h2',
				'h3' => 'h3',
				'h4' => 'h4',
				'h5' => 'h5',
				'h6' => 'h6'
			),
			'std' => 'h6',
			'description' => esc_html__('Choose tag for heading', 'surround' ),
			'param_holder_class' => ''
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Style', 'surround' ),
			'param_name' => 'style',
			'value' => array(
				esc_html__( 'Style 1', 'surround' ) => 'style-1',
				esc_html__( 'Style 2', 'surround' ) => 'style-2',
				esc_html__( 'Masonry', 'surround' ) => 'style-3',
			),
			'description' => esc_html__( 'Style?', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Columns', 'surround' ),
			'param_name' => 'columns',
			'value' => array(
				esc_html__( '3 Columns', 'surround' ) => 3,
				esc_html__( '4 Columns', 'surround' ) => 4,
				esc_html__( '5 Columns', 'surround' ) => 5,
			),
			'std' => 4,
			'description' => esc_html__( 'How many columns should be displayed?', 'surround' )
		),
		array(
			'type' => 'number',
			'heading' => esc_html__( 'Number of items to show', 'surround' ),
			'param_name' => 'number_of_items',
			'description' => '',
			'std' => 10,
			'group' => esc_html__( 'Category Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order by', 'surround' ),
			'param_name' => 'orderby',
			'value' => array(
				esc_html__('Name', 'surround' )               => 'name',
				esc_html__('ID', 'surround' )                 => 'id',
				esc_html__('Slug', 'surround' )               => 'slug',
				esc_html__('Number of Listings', 'surround' ) => 'count',
				esc_html__('Random', 'surround' )             => 'rand'
			),
			'group' => esc_html__( 'Category Data Settings', 'surround' ),
			'std' => 'name',
			'description' => ''
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order', 'surround' ),
			'param_name' => 'order',
			'value' => array(
				esc_html__( 'DESC', 'surround' ) => 'DESC',
				esc_html__( 'ASC', 'surround' )  => 'ASC',
			),
			'std' => '',
			'description' => esc_html__( 'Direction Order', 'surround' ),
			'group' => esc_html__( 'Category Data Settings', 'surround' )
		),
		array(
			'type' => 'get_terms',
			'term' => 'category',
			'heading' => esc_html__( 'Which categories should be used?', 'surround' ),
			'param_name' => 'categories',
			'description' => esc_html__('The Page will then show categories from only those categories.', 'surround' ),
			'group' => esc_html__( 'Category Data Settings', 'surround' )
		),
	)
) );

/* Post Map
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Post Map', 'surround' ),
	'base' => 'vc_mad_post_map',
	'icon' => 'icon-wpb-mad-blog-posts',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Display a map of listing based on different criteria.', 'surround' ),
	'params' => array(
		array(
			'type' => 'number',
			'heading' => esc_html__( 'Number of items to show', 'surround' ),
			'param_name' => 'per_page',
			'std' => 10
		),
	)
) );


/* Blog Posts Slider
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Blog Posts Slider', 'surround' ),
	'base' => 'vc_mad_blog_posts_slider',
	'icon' => 'icon-wpb-mad-blog-posts',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Blog posts slider', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Title', 'surround' ),
			'param_name' => 'title',
			'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Title Alignment', 'surround' ),
			'param_name' => 'align_title',
			'description' => esc_html__( 'Select title alignment.', 'surround' ),
			'value' => array(
				esc_html__( 'Left', 'surround' )   => 'align-left',
				esc_html__( 'Right', 'surround' )  => 'align-right',
				esc_html__( 'Center', 'surround' ) => 'align-center'
			)
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__('Tag', 'surround' ),
			'param_name' => 'heading',
			'value' => array(
				'h2' => 'h2',
				'h3' => 'h3',
				'h4' => 'h4',
				'h5' => 'h5',
				'h6' => 'h6'
			),
			'std' => 'h6',
			'description' => esc_html__('Choose tag for heading', 'surround' ),
			'param_holder_class' => ''
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Layout', 'surround' ),
			'param_name' => 'layout',
			'value' => array(
				esc_html__('Style 1', 'surround') => 'sl1',
				esc_html__('Style 2', 'surround') => 'sl2',
			),
			'std' => 'style-1',
			'description' => esc_html__( 'Choose the default blog layout here.', 'surround' )
		),
		array(
			'type' => 'get_terms',
			'term' => 'category',
			'heading' => esc_html__( 'Which categories should be used for the blog?', 'surround' ),
			'param_name' => 'categories',
			'description' => esc_html__('The Page will then show entries from only those categories.', 'surround' ),
			'group' => esc_html__( 'Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order By', 'surround' ),
			'param_name' => 'orderby',
			'value' => array(
				esc_html__( 'Date', 'surround' )          => 'date',
				esc_html__( 'ID', 'surround' )            => 'ID',
				esc_html__( 'Author', 'surround' )        => 'author',
				esc_html__( 'Title', 'surround' )         => 'title',
				esc_html__( 'Modified', 'surround' )      => 'modified',
				esc_html__( 'Random', 'surround' )        => 'rand',
				esc_html__( 'Comment count', 'surround' ) => 'comment_count',
				esc_html__( 'Menu order', 'surround' )    => 'menu_order'
			),
			'std' => 'date',
			'description' => esc_html__( 'Sort retrieved posts by parameter', 'surround' ),
			'group' => esc_html__( 'Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order', 'surround' ),
			'param_name' => 'order',
			'value' => array(
				esc_html__( 'DESC', 'surround' ) => 'DESC',
				esc_html__( 'ASC', 'surround' )  => 'ASC'
			),
			'description' => esc_html__( 'In what direction order?', 'surround' ),
			'group' => esc_html__( 'Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Posts Count', 'surround' ),
			'param_name' => 'items',
			'value' => suround_array_number(1, 50, 1, array('-1' => 'All')),
			'std' => 10,
			'description' => esc_html__( 'How many items should be displayed per page?', 'surround' ),
			'edit_field_class' => 'vc_col-sm-6 vc_column'
		),
	)
) );

/* Blog Posts Carousel
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Blog Posts Carousel', 'surround' ),
	'base' => 'vc_mad_blog_posts_carousel',
	'icon' => 'icon-wpb-mad-blog-posts',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Blog posts carousel', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Title', 'surround' ),
			'param_name' => 'title',
			'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Title Alignment', 'surround' ),
			'param_name' => 'align_title',
			'description' => esc_html__( 'Select title alignment.', 'surround' ),
			'value' => array(
				esc_html__( 'Left', 'surround' )   => 'align-left',
				esc_html__( 'Right', 'surround' )  => 'align-right',
				esc_html__( 'Center', 'surround' ) => 'align-center'
			)
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__('Tag', 'surround' ),
			'param_name' => 'heading',
			'value' => array(
				'h2' => 'h2',
				'h3' => 'h3',
				'h4' => 'h4',
				'h5' => 'h5',
				'h6' => 'h6'
			),
			'std' => 'h6',
			'description' => esc_html__('Choose tag for heading', 'surround' ),
			'param_holder_class' => ''
		),
		array(
			'type' => 'image_select',
			'heading' => esc_html__( 'Layout', 'surround' ),
			'param_name' => 'layout',
			'value' => suround_get_carousel_layouts(),
			'std' => 'k1',
			'description' => esc_html__( 'Choose the default blog layout here.', 'surround' )
		),
		array(
			'type' => 'get_terms',
			'term' => 'category',
			'heading' => esc_html__( 'Which categories should be used for the blog?', 'surround' ),
			'param_name' => 'categories',
			'description' => esc_html__('The Page will then show entries from only those categories.', 'surround' ),
			'group' => esc_html__( 'Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order By', 'surround' ),
			'param_name' => 'orderby',
			'value' => array(
				esc_html__( 'Date', 'surround' )          => 'date',
				esc_html__( 'ID', 'surround' )            => 'ID',
				esc_html__( 'Author', 'surround' )        => 'author',
				esc_html__( 'Title', 'surround' )         => 'title',
				esc_html__( 'Modified', 'surround' )      => 'modified',
				esc_html__( 'Random', 'surround' )        => 'rand',
				esc_html__( 'Comment count', 'surround' ) => 'comment_count',
				esc_html__( 'Menu order', 'surround' )    => 'menu_order'
			),
			'std' => 'date',
			'description' => esc_html__( 'Sort retrieved posts by parameter', 'surround' ),
			'group' => esc_html__( 'Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order', 'surround' ),
			'param_name' => 'order',
			'value' => array(
				esc_html__( 'DESC', 'surround' ) => 'DESC',
				esc_html__( 'ASC', 'surround' )  => 'ASC'
			),
			'description' => esc_html__( 'In what direction order?', 'surround' ),
			'group' => esc_html__( 'Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Posts Count', 'surround' ),
			'param_name' => 'items',
			'value' => suround_array_number(1, 50, 1, array('-1' => 'All')),
			'std' => 10,
			'description' => esc_html__( 'How many items should be displayed per page?', 'surround' ),
			'edit_field_class' => 'vc_col-sm-6 vc_column'
		),
	)
) );

/* Series
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Series', 'surround' ),
	'base' => 'vc_mad_series',
	'icon' => 'icon-wpb-mad-blog-posts',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'That shortcode allows you to collect posts in a series.', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Title', 'surround' ),
			'param_name' => 'title',
			'validate' => 'html_custom',
			'allowed_html' => array(
				'a' => array(
					'href' => array(),
					'title' => array()
				),
				'br' => array(),
				'em' => array(),
				'strong' => array()
			),
			'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Title Alignment', 'surround' ),
			'param_name' => 'align_title',
			'description' => esc_html__( 'Select title alignment.', 'surround' ),
			'value' => array(
				esc_html__( 'Left', 'surround' )   => 'align-left',
				esc_html__( 'Right', 'surround' )  => 'align-right',
				esc_html__( 'Center', 'surround' ) => 'align-center'
			),
			'std' => 'align-left'
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__('Tag', 'surround' ),
			'param_name' => 'heading',
			'value' => array(
				'h2' => 'h2',
				'h3' => 'h3',
				'h4' => 'h4',
				'h5' => 'h5',
				'h6' => 'h6'
			),
			'std' => 'h6',
			'description' => esc_html__('Choose tag for heading', 'surround' ),
			'param_holder_class' => ''
		),
		array(
			'type' => 'get_terms',
			'term' => 'series',
			'heading' => esc_html__( 'Which series should be used for the blog?', 'surround' ),
			'param_name' => 'series',
			'description' => esc_html__('The Page will then show entries from only those series.', 'surround' ),
			'group' => esc_html__( 'Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Posts Count', 'surround' ),
			'param_name' => 'items',
			'value' => suround_array_number(1, 50, 1, array('-1' => 'All')),
			'std' => 10,
			'description' => esc_html__( 'How many items should be displayed per page?', 'surround' ),
			'edit_field_class' => 'vc_col-sm-6 vc_column'
		),
		array(
			"type" => "vc_link",
			"heading" => esc_html__( 'Add URL button to the series (optional)', 'surround' ),
			"param_name" => "link"
		)
	)
) );

/* Blog Posts
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Blog Posts', 'surround' ),
	'base' => 'vc_mad_blog_posts',
	'icon' => 'icon-wpb-mad-blog-posts',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Blog posts', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Title', 'surround' ),
			'param_name' => 'title',
			'validate' => 'html_custom',
			'allowed_html' => array(
				'a' => array(
					'href' => array(),
					'title' => array()
				),
				'br' => array(),
				'em' => array(),
				'strong' => array()
			),
			'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Title Alignment', 'surround' ),
			'param_name' => 'align_title',
			'description' => esc_html__( 'Select title alignment.', 'surround' ),
			'value' => array(
				esc_html__( 'Left', 'surround' )   => 'align-left',
				esc_html__( 'Right', 'surround' )  => 'align-right',
				esc_html__( 'Center', 'surround' ) => 'align-center'
			),
			'std' => 'align-left'
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__('Tag', 'surround' ),
			'param_name' => 'heading',
			'value' => array(
				'h2' => 'h2',
				'h3' => 'h3',
				'h4' => 'h4',
				'h5' => 'h5',
				'h6' => 'h6',
				'span' => 'span'
			),
			'std' => 'h6',
			'description' => esc_html__('Choose tag for heading', 'surround' ),
			'param_holder_class' => ''
		),
		array(
			'type' => 'image_select',
			'heading' => esc_html__( 'Layout', 'surround' ),
			'param_name' => 'layout',
			'value' => suround_get_main_layouts(),
			'std' => 'a1',
			'description' => esc_html__( 'Choose the default blog layout here.', 'surround' )
		),
		array(
			'type' => 'get_terms',
			'term' => 'category',
			'heading' => esc_html__( 'Which categories should be used for the blog?', 'surround' ),
			'param_name' => 'categories',
			'description' => esc_html__('The Page will then show entries from only those categories.', 'surround' ),
			'group' => esc_html__( 'Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order By', 'surround' ),
			'param_name' => 'orderby',
			'value' => array(
				esc_html__( 'Date', 'surround' )          => 'date',
				esc_html__( 'ID', 'surround' )            => 'ID',
				esc_html__( 'Author', 'surround' )        => 'author',
				esc_html__( 'Title', 'surround' )         => 'title',
				esc_html__( 'Modified', 'surround' )      => 'modified',
				esc_html__( 'Random', 'surround' )        => 'rand',
				esc_html__( 'Comment count', 'surround' ) => 'comment_count',
				esc_html__( 'Menu order', 'surround' )    => 'menu_order'
			),
			'std' => 'date',
			'description' => esc_html__( 'Sort retrieved posts by parameter', 'surround' ),
			'group' => esc_html__( 'Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order', 'surround' ),
			'param_name' => 'order',
			'value' => array(
				esc_html__( 'DESC', 'surround' ) => 'DESC',
				esc_html__( 'ASC', 'surround' )  => 'ASC'
			),
			'description' => esc_html__( 'In what direction order?', 'surround' ),
			'group' => esc_html__( 'Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Posts Count', 'surround' ),
			'param_name' => 'items',
			'value' => suround_array_number(1, 50, 1, array('-1' => 'All')),
			'std' => 10,
			'description' => esc_html__( 'How many items should be displayed per page?', 'surround' ),
			'edit_field_class' => 'vc_col-sm-6 vc_column'
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Pagination', 'surround' ),
			'param_name' => 'paginate',
			'value' => array(
				esc_html__( 'Display Pagination', 'surround' )                   => 'pagination',
				esc_html__( 'No option to view additional entries', 'surround' ) => 'none'
			),
			'std' => 'none',
			'description' => esc_html__( 'Should a pagination be displayed?', 'surround' )
		),
		array(
			"type" => "vc_link",
			"heading" => esc_html__( 'Add URL button to the blog (optional)', 'surround' ),
			"param_name" => "link"
		)
	)
) );

/* Countdown
---------------------------------------------------------- */

vc_map( array(
	"name" => esc_html__( 'Countdown', 'surround' ),
	"base" => "vc_mad_countdown",
	"icon" => "icon-wpb-mad-countdown",
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Countdown', 'surround' ),
	"params" => array(
		array(
			"type" => "datetimepicker",
			"class" => "",
			"heading" => esc_html__("Target Time For Countdown", 'surround' ),
			"param_name" => "datetime",
			"value" => "",
			"description" => esc_html__("Date and time format (yyyy/mm/dd hh:mm:ss).", 'surround' ),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Extra class name', 'surround' ),
			'param_name' => 'el_class',
			'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'surround' )
		)
	)
) );

/* Instagram Feed
---------------------------------------------------------- */

if ( defined('SBIVER') ) {

	$users = [ esc_html__('Choose a user', 'surround') => '' ];
	$return = array();
	$sbi_options = get_option( 'sb_instagram_settings' );
	$return['connected_accounts'] = isset( $sbi_options['connected_accounts'] ) ? $sbi_options['connected_accounts'] : array();
	$connected_accounts = $return['connected_accounts'];

	if ( empty ( $connected_accounts ) ) {
		$users[ esc_html__( 'No Instagram accounts connected.', 'surround' ) ] = '';
	} else {
		foreach ( $connected_accounts as $account ) {
			$username           = $account['username'] ? $account['username'] : $account['user_id'];
			$users[ $username ] = $username;
		}
	}

	vc_map( array(
		'name' => esc_html__( 'Instagram Feed', 'surround' ),
		'base' => 'vc_mad_instagram_feed',
		'icon' => 'icon-wpb-mad-instagram-gallery',
		'category' => esc_html__( 'Suround', 'surround' ),
		'description' => esc_html__( 'Instagram Gallery', 'surround' ),
		'params' => array(
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Title', 'surround' ),
				'param_name' => 'title',
				'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' ),
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Title Alignment', 'surround' ),
				'param_name' => 'align_title',
				'description' => esc_html__( 'Select title alignment.', 'surround' ),
				'value' => array(
					esc_html__( 'Left', 'surround' )   => 'align-left',
					esc_html__( 'Right', 'surround' )  => 'align-right',
					esc_html__( 'Center', 'surround' ) => 'align-center'
				)
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__('Tag', 'surround' ),
				'param_name' => 'heading',
				'value' => array(
					'h2' => 'h2',
					'h3' => 'h3',
					'h4' => 'h4',
					'h5' => 'h5',
					'h6' => 'h6'
				),
				'std' => 'h6',
				'description' => esc_html__('Choose tag for heading', 'surround' ),
				'param_holder_class' => ''
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'User', 'surround' ),
				'param_name' => 'user',
				'description' => esc_html__( 'Select user.', 'surround' ),
				'value' => $users
			),
			array(
				'type' => 'textfield',
				'heading' => esc_html__( 'Number of photos', 'surround' ),
				'param_name' => 'num',
				'description' => esc_html__( 'How many items should be displayed per page?', 'surround' ),
				'std' => 6
			),
			array(
				'type' => 'dropdown',
				'heading' => esc_html__( 'Columns', 'surround' ),
				'param_name' => 'cols',
				'value' => array(
					esc_html__( '4 Columns', 'surround' ) => 4,
					esc_html__( '5 Columns', 'surround' ) => 5,
					esc_html__( '6 Columns', 'surround' ) => 6,
				),
				'std' => 6,
				'description' => esc_html__( 'How many columns should be displayed?', 'surround' )
			),
		)
	) );

}

/* Brands Logo
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Banner', 'surround' ),
	'base' => 'vc_mad_banner',
	'icon' => 'icon-wpb-mad-banner-logo',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'banner', 'surround' ),
	'params' => array(
		array(
			'type' => 'attach_image',
			'heading' => esc_html__('Image', 'surround'),
			'param_name' => 'image',
			'admin_label' => false
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__('Cost', 'surround'),
			'param_name' => 'cost',
			'admin_label' => true
		),
		array(
			'type' => 'textarea',
			'heading' => esc_html__('Title', 'surround'),
			'param_name' => 'title',
			'allowed_html' => array(
				'a' => array(
					'href' => array(),
					'title' => array()
				),
				'br' => array(),
				'em' => array(),
				'span' => array(),
				'strong' => array()
			),
			'admin_label' => true
		),
		array(
			"type" => "vc_link",
			"heading" => esc_html__( 'Add URL button to the banner (optional)', 'surround' ),
			"param_name" => "link"
		)
	)
) );

/* Brands Logo
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Brands', 'surround' ),
	'base' => 'vc_mad_partners',
	'icon' => 'icon-wpb-mad-brands-logo',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Our partners logo', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Title', 'surround' ),
			'param_name' => 'title',
			'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__('Tag', 'surround' ),
			'param_name' => 'heading',
			'value' => array(
				'h2' => 'h2',
				'h3' => 'h3',
				'h4' => 'h4',
				'h5' => 'h5',
				'h6' => 'h6'
			),
			'std' => 'h6',
			'description' => esc_html__('Choose tag for heading', 'surround' ),
			'param_holder_class' => ''
		),
		array(
			'type' => 'attach_images',
			'heading' => esc_html__( 'Images', 'surround' ),
			'param_name' => 'images',
			'value' => '',
			'description' => esc_html__( 'Select images from media library.', 'surround' )
		),
		array(
			"type" => "textarea",
			"heading" => esc_html__( 'Links', 'surround' ),
			"param_name" => "links",
			"holder" => "span",
			"description" => esc_html__( 'Input links values. Divide values with linebreaks (|). Example: http://partner.com | http://partner2.com', 'surround' )
		),
	)
) );


if ( class_exists('WooCommerce') ) {

	$order_by_values = array(
		'',
		esc_html__( 'Date', 'surround' )          => 'date',
		esc_html__( 'ID', 'surround' )            => 'ID',
		esc_html__( 'Author', 'surround' )        => 'author',
		esc_html__( 'Title', 'surround' )         => 'title',
		esc_html__( 'Modified', 'surround' )      => 'modified',
		esc_html__( 'Random', 'surround' )        => 'rand',
		esc_html__( 'Comment count', 'surround' ) => 'comment_count',
		esc_html__( 'Menu order', 'surround' )    => 'menu_order',
	);

	$order_way_values = array(
		'',
		esc_html__( 'Descending', 'surround' ) => 'DESC',
		esc_html__( 'Ascending', 'surround' )  => 'ASC',
	);

	vc_map(
		array(
			'name' => esc_html__( 'Products Carousel', 'surround' ),
			'base' => 'vc_mad_products',
			'icon' => 'icon-wpb-mad-woocommerce',
			'category' => esc_html__( 'Suround', 'surround' ),
			'description' => esc_html__( 'Show products carousel', 'surround' ),
			'params' => array(
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Title', 'surround' ),
					'param_name' => 'title',
					'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' ),
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Title Alignment', 'surround' ),
					'param_name' => 'align_title',
					'description' => esc_html__( 'Select title alignment.', 'surround' ),
					'value' => array(
						esc_html__( 'Left', 'surround' )   => 'align-left',
						esc_html__( 'Right', 'surround' )  => 'align-right',
						esc_html__( 'Center', 'surround' ) => 'align-center'
					)
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__('Tag', 'surround' ),
					'param_name' => 'heading',
					'value' => array(
						'h2' => 'h2',
						'h3' => 'h3',
						'h4' => 'h4',
						'h5' => 'h5',
						'h6' => 'h6'
					),
					'std' => 'h6',
					'description' => esc_html__('Choose tag for heading', 'surround' ),
					'param_holder_class' => ''
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Per page', 'surround' ),
					'value' => 12,
					'save_always' => true,
					'param_name' => 'per_page',
					'description' => esc_html__( 'The "per_page" shortcode determines how many products to show on the page', 'surround' ),
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Columns', 'surround' ),
					'value' => 4,
					'param_name' => 'columns',
					'save_always' => true,
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Order by', 'surround' ),
					'param_name' => 'orderby',
					'value' => $order_by_values,
					'std' => 'title',
					'save_always' => true,
					'description' => sprintf( esc_html__( 'Select how to sort retrieved products. More at %s. Default by Title', 'surround' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
				),
				array(
					'type' => 'dropdown',
					'heading' => esc_html__( 'Sort order', 'surround' ),
					'param_name' => 'order',
					'value' => $order_way_values,
					'save_always' => true,
					'description' => sprintf( esc_html__( 'Designates the ascending or descending order. More at %s. Default by ASC', 'surround' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
				),
				array(
					"type" => 'get_terms',
					"term" => "product_cat",
					'heading' => esc_html__( 'Which categories should be used for the products?', 'surround' ),
					"param_name" => "category",
					'description' => esc_html__('The Page will then show products from only those categories.', 'surround' ),
					'group' => esc_html__( 'Data Settings', 'surround' )
				),
				array(
					"type" => "vc_link",
					"heading" => esc_html__( 'Add URL button to the products (optional)', 'surround' ),
					"param_name" => "link"
				)
			)
		)
	);

}

/* Progress Bar
---------------------------------------------------------- */

vc_map(array(
	'name' => esc_html__( 'Progress Bar', 'surround' ),
	'base' => 'vc_mad_progress_bar',
	'icon' => 'icon-wpb-mad-progress-bar',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Animated progress bar', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Title', 'surround' ),
			'param_name' => 'title',
			'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Style', 'surround' ),
			'param_name' => 'style',
			'value' => array(
				esc_html__('Blue', 'surround' ) => 'style-1',
				esc_html__('Black', 'surround' ) => 'style-2'
			),
			'std' => 'style-1',
			'description' => esc_html__('Choose layout style.', 'surround' )
		),
		array(
			'type' => 'param_group',
			'heading' => esc_html__( 'Values', 'surround' ),
			'param_name' => 'values',
			'description' => esc_html__( 'Enter values for graph - value, title and color.', 'surround' ),
			'value' => urlencode( json_encode( array(
				array(
					'label' => esc_html__( 'Central Location', 'surround' ),
					'value' => '75',
				),
				array(
					'label' => esc_html__( 'Experienced Staff', 'surround' ),
					'value' => '40',
				),
				array(
					'label' => esc_html__( 'Free Wi-Fi & More', 'surround' ),
					'value' => '90',
				),
				array(
					'label' => esc_html__( 'Pets Friendly', 'surround' ),
					'value' => '65',
				),
			) ) ),
			'params' => array(
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Label', 'surround' ),
					'param_name' => 'label',
					'description' => esc_html__( 'Enter text used as title of bar.', 'surround' ),
					'admin_label' => true,
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Value', 'surround' ),
					'param_name' => 'value',
					'description' => esc_html__( 'Enter value of bar.', 'surround' ),
					'admin_label' => true,
				),
			),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Units', 'surround' ),
			'param_name' => 'units',
			'description' => esc_html__( 'Enter measurement units (Example: %, px, points, etc. Note: graph value and units will be appended to graph title).', 'surround' ),
		),
	),
));

/* Counter Bar
---------------------------------------------------------- */

vc_map( array(
	"name" => esc_html__("Counter", 'surround' ),
	"base"=> 'vc_mad_counter',
	"icon" => 'icon-wpb-mad-counter',
	'category' => esc_html__( 'Suround', 'surround' ),
	"description" => esc_html__( 'Counter', 'surround' ),
	"params" => array(
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Style', 'surround' ),
			'param_name' => 'style',
			'value' => array(
				esc_html__('Style 1', 'surround' ) => 'style-1',
				esc_html__('Style 2', 'surround' ) => 'style-2'
			),
			'std' => 'style-1',
			'description' => esc_html__('Choose layout style.', 'surround' )
		),
		array(
			'type' => 'param_group',
			'heading' => esc_html__( 'Values', 'surround' ),
			'param_name' => 'values',
			'description' => esc_html__( 'Enter values - value and title.', 'surround' ),
			'value' => urlencode( json_encode( array(
				array(
					'value' => '4',
					'unit' => esc_html__( 'Continents', 'surround' ),
					'label' => esc_html__( 'Explored', 'surround' ),
					'icon'  => 'cicon-globe2'
				),
				array(
					'value' => '30',
					'unit' => esc_html__( 'Countries', 'surround' ),
					'label' => esc_html__( 'Visited', 'surround' ),
					'icon'  => 'cicon-location'
				),
				array(
					'value' => '250000',
					'unit' => esc_html__( 'KM', 'surround' ),
					'label' => esc_html__( 'Traveled', 'surround' ),
					'icon'  => 'cicon-traveler'
				),
				array(
					'value' => '15000',
					'unit' => esc_html__( 'Photos', 'surround' ),
					'label' => esc_html__( 'Taken', 'surround' ),
					'icon'  => 'cicon-pictures'
				),
			) ) ),
			'params' => array(
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Value', 'surround' ),
					'param_name' => 'value',
					'description' => esc_html__( 'Enter value.', 'surround' ),
					'admin_label' => true,
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Unit', 'surround' ),
					'param_name' => 'unit',
					'description' => esc_html__( 'Enter unit.', 'surround' ),
					'admin_label' => true,
				),
				array(
					'type' => 'textfield',
					'heading' => esc_html__( 'Label', 'surround' ),
					'param_name' => 'label',
					'description' => esc_html__( 'Enter text used as title.', 'surround' ),
					'admin_label' => true,
				),
				array(
					"type" => "choose_icons",
					"heading" => esc_html__("Icon", 'surround' ),
					"param_name" => "icon",
					"value" => 'none',
					"description" => esc_html__( 'Select icon from library.', 'surround' )
				)
			)
		),
	)
));

/* Team Members
---------------------------------------------------------- */

$team_array = array();
$team_members = get_posts( array(
	'post_type' => 'team-members',
	'numberposts' => -1
) );

foreach ( $team_members as $member ) {
	$team_array[$member->post_title] = $member->ID;
}

$image_select = suround_image_select();

vc_map( array(
	'name' => esc_html__( 'Team Members', 'surround' ),
	'base' => 'vc_mad_team_members',
	'icon' => 'icon-wpb-mad-team-members',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Team Members post type', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Title', 'surround' ),
			'param_name' => 'title',
			'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' ),
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Subtitle', 'surround' ),
			'param_name' => 'subtitle',
			'description' => esc_html__( 'Enter text which will be used as subtitle. Leave blank if no subtitle is needed.', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Title Alignment', 'surround' ),
			'param_name' => 'align_title',
			'description' => esc_html__( 'Select title alignment.', 'surround' ),
			'value' => array(
				esc_html__( 'Left', 'surround' )   => 'align-left',
				esc_html__( 'Right', 'surround' )  => 'align-right',
				esc_html__( 'Center', 'surround' ) => 'align-center'
			)
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__('Tag', 'surround' ),
			'param_name' => 'heading',
			'value' => array(
				'h2' => 'h2',
				'h3' => 'h3',
				'h4' => 'h4',
				'h5' => 'h5',
				'h6' => 'h6'
			),
			'std' => 'h6',
			'description' => esc_html__('Choose tag for heading', 'surround' ),
			'param_holder_class' => ''
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Style', 'surround' ),
			'param_name' => 'style',
			'description' => esc_html__( 'Select style.', 'surround' ),
			'value' => array(
				esc_html__( 'Default', 'surround' )  => 'style-1',
				esc_html__( 'Single', 'surround' )   => 'style-2',
				esc_html__( 'Carousel', 'surround' ) => 'style-3',
			),
		),
		array(
			'type' => 'image_select',
			'heading' => esc_html__( 'Choose Image Select', 'surround' ),
			'param_name' => 'multi_image_select',
			'value' => $image_select,
			'std' => ''
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Choose a member', 'surround' ),
			'param_name' => 'members',
			'value' => $team_array,
			'std' => '',
			'dependency' => array(
				'element' => 'style',
				'value' => array( 'style-2' ),
			),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Columns', 'surround' ),
			'param_name' => 'columns',
			'value' => array(
				esc_html__( '3 Columns', 'surround' ) => 3,
				esc_html__( '4 Columns', 'surround' ) => 4
			),
			'dependency' => array(
				'element' => 'style',
				'value' => array( 'style-1' ),
			),
			'description' => esc_html__( 'How many columns should be displayed?', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Count Items', 'surround' ),
			'param_name' => 'items',
			'value' => suround_array_number(1, 51, 1, array('All' => '-1')),
			'std' => -1,
			'description' => esc_html__( 'How many items should be displayed per page?', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order By', 'surround' ),
			'param_name' => 'orderby',
			'value' => array(
				esc_html__( 'Date', 'surround' )          => 'date',
				esc_html__( 'ID', 'surround' )            => 'ID',
				esc_html__( 'Author', 'surround' )        => 'author',
				esc_html__( 'Title', 'surround' )         => 'title',
				esc_html__( 'Modified', 'surround' )      => 'modified',
				esc_html__( 'Random', 'surround' )        => 'rand',
				esc_html__( 'Comment count', 'surround' ) => 'comment_count',
				esc_html__( 'Menu order', 'surround' )    => 'menu_order'
			),
			'description' => ''
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order', 'surround' ),
			'param_name' => 'order',
			'value' => array(
				esc_html__( 'DESC', 'surround' ) => 'DESC',
				esc_html__( 'ASC', 'surround' )  => 'ASC',
			),
			'description' => esc_html__( 'Direction Order', 'surround' )
		)
	)
) );

/* Testimonials
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__( 'Testimonials', 'surround' ),
	'base' => 'vc_mad_testimonials',
	'icon' => 'icon-wpb-mad-testimonials',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Testimonials post type', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Title', 'surround' ),
			'param_name' => 'title',
			'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' ),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__('Tag', 'surround' ),
			'param_name' => 'heading',
			'value' => array(
				'h2' => 'h2',
				'h3' => 'h3',
				'h4' => 'h4',
				'h5' => 'h5',
				'h6' => 'h6'
			),
			'std' => 'h6',
			'description' => esc_html__('Choose tag for heading', 'surround' ),
			'param_holder_class' => ''
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Testimonial Style', 'surround' ),
			'param_name' => 'style',
			'value' => array(
				esc_html__( 'Carousel', 'surround' )                => 'carousel-style',
				esc_html__( 'List Style', 'surround' )                      => 'list-style'
			),
			'description' => esc_html__( 'Here you can select how to display the testimonials.', 'surround' )
		),
		array(
			'type' => 'attach_image',
			'heading' => esc_html__( 'Image', 'surround' ),
			'param_name' => 'image',
			'value' => '',
			'description' => esc_html__( 'Select image from media library.', 'surround' ),
			'dependency' => array(
				'element' => 'style',
				'value' => array( 'style-3' )
			),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Count Items', 'surround' ),
			'param_name' => 'items',
			'value' => suround_array_number(1, 51, 1, array( esc_html__('All', 'surround' ) => '-1') ),
			'std' => -1,
			'description' => esc_html__( 'How many items should be displayed per page?', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order By', 'surround' ),
			'param_name' => 'orderby',
			'value' => array(
				esc_html__( 'Date', 'surround' )          => 'date',
				esc_html__( 'ID', 'surround' )            => 'ID',
				esc_html__( 'Author', 'surround' )        => 'author',
				esc_html__( 'Title', 'surround' )         => 'title',
				esc_html__( 'Modified', 'surround' )      => 'modified',
				esc_html__( 'Random', 'surround' )        => 'rand',
				esc_html__( 'Comment count', 'surround' ) => 'comment_count',
				esc_html__( 'Menu order', 'surround' )    => 'menu_order'
			),
			'description' => esc_html__( 'Sort retrieved items by parameter', 'surround' ),
			'edit_field_class' => 'vc_col-sm-6',
			'group' => esc_html__( 'Data Settings', 'surround' )
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Order', 'surround' ),
			'param_name' => 'order',
			'value' => array(
				esc_html__( 'DESC', 'surround' ) => 'DESC',
				esc_html__( 'ASC', 'surround' )  => 'ASC',
			),
			'description' => esc_html__( 'Direction Order', 'surround' ),
			'edit_field_class' => 'vc_col-sm-6',
			'group' => esc_html__( 'Data Settings', 'surround' )
		),
	)
) );

/* Tooltip
---------------------------------------------------------- */

vc_map( array(
	'name' => esc_html__('Tooltip', 'surround' ),
	'base' => 'vc_mad_tooltip',
	'category' => esc_html__( 'Suround', 'surround' ),
	'icon' => 'icon-wpb-mad-tooltip',
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__('Text', 'surround' ),
			'param_name' => 'text',
			'admin_label' => true,
		),
		array(
			"type" => "textfield",
			"heading" => esc_html__("Link", 'surround' ),
			"param_name" => "link",
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Link target', 'surround' ),
			'param_name' => 'target_link',
			'description' => esc_html__( 'Select where to open link.', 'surround' ),
			'value' => $target_arr,
		),
		array(
			'type' => 'textfield',
			'heading' => esc_html__('Tooltip Text', 'surround' ),
			'param_name' => 'tooltip_text',
			'admin_label' => true,
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Tooltip Position', 'surround' ),
			'param_name' => 'tooltip_position',
			'value' => array(
				esc_html__('Top', 'surround' )    => 'top',
				esc_html__('Right', 'surround' )  => 'right',
				esc_html__('Bottom', 'surround' ) => 'bottom',
				esc_html__('Left', 'surround' )   => 'left'
			)
		)
	)
) );

/* Dropcap
---------------------------------------------------------- */
vc_map( array(
	'name' => esc_html__( 'Dropcap', 'surround' ),
	'base' => 'vc_mad_dropcap',
	'icon' => 'icon-wpb-mad-dropcap',
	'category' => esc_html__( 'Suround', 'surround' ),
	'description' => esc_html__( 'Dropcap', 'surround' ),
	'params' => array(
		array(
			'type' => 'textfield',
			'heading' => esc_html__( 'Letter', 'surround' ),
			'param_name' => 'letter',
			'admin_label' => true,
			'description' => ''
		),
		array(
			'type' => 'colorpicker',
			'heading' => esc_html__( 'Color for dropcap', 'surround' ),
			'param_name' => 'dropcap_color',
			'description' => esc_html__( 'Select custom color for dropcap.', 'surround' ),
			'dependency' => array(
				'element' => 'style',
				'value' => array( 'type-1' ),
			),
		),
		array(
			'type' => 'dropdown',
			'heading' => esc_html__( 'Style', 'surround' ),
			'param_name' => 'type',
			'value' => array(
				esc_html__('Style 1', 'surround' ) => 'type-1',
				esc_html__('Style 2', 'surround' ) => 'type-2'
			),
			'std' => 'type-1',
			'description' => esc_html__('Choose style type.', 'surround' )
		),
		array(
			'type' => 'textarea_html',
			'holder' => 'div',
			'heading' => esc_html__( 'Text', 'surround' ),
			'param_name' => 'content',
			'value' => ''
		),
	)
));


/*** Visual Composer Content elements refresh ***/
class suroundVcSharedLibrary {
	// Here we will store plugin wise (shared) settings. Colors, Locations, Sizes, etc...
	/**
	 * @var array
	 */
	private static $colors = array(
		'Blue' => 'blue',
		'Turquoise' => 'turquoise',
		'Pink' => 'pink',
		'Violet' => 'violet',
		'Peacoc' => 'peacoc',
		'Chino' => 'chino',
		'Mulled Wine' => 'mulled_wine',
		'Vista Blue' => 'vista_blue',
		'Black' => 'black',
		'Grey' => 'grey',
		'Orange' => 'orange',
		'Sky' => 'sky',
		'Green' => 'green',
		'Juicy pink' => 'juicy_pink',
		'Sandy brown' => 'sandy_brown',
		'Purple' => 'purple',
		'White' => 'white'
	);

	/**
	 * @var array
	 */
	public static $icons = array(
		'Glass' => 'glass',
		'Music' => 'music',
		'Search' => 'search'
	);

	/**
	 * @var array
	 */
	public static $sizes = array(
		'Mini' => 'xs',
		'Small' => 'sm',
		'Normal' => 'md',
		'Large' => 'lg'
	);

	/**
	 * @var array
	 */
	public static $button_styles = array(
		'Rounded' => 'rounded',
		'Square' => 'square',
		'Round' => 'round',
		'Outlined' => 'outlined',
		'3D' => '3d',
		'Square Outlined' => 'square_outlined'
	);

	/**
	 * @var array
	 */
	public static $message_box_styles = array(
		'Standard' => 'standard',
		'Solid' => 'solid',
		'Solid icon' => 'solid-icon',
		'Outline' => 'outline',
		'3D' => '3d',
	);

	/**
	 * Toggle styles
	 * @var array
	 */
	public static $toggle_styles = array(
		'Default' => 'default',
		'Simple' => 'simple',
		'Round' => 'round',
		'Round Outline' => 'round_outline',
		'Rounded' => 'rounded',
		'Rounded Outline' => 'rounded_outline',
		'Square' => 'square',
		'Square Outline' => 'square_outline',
		'Arrow' => 'arrow',
		'Text Only' => 'text_only',
	);

	/**
	 * Animation styles
	 * @var array
	 */
	public static $animation_styles = array(
		'Bounce' => 'easeOutBounce',
		'Elastic' => 'easeOutElastic',
		'Back' => 'easeOutBack',
		'Cubic' => 'easeinOutCubic',
		'Quint' => 'easeinOutQuint',
		'Quart' => 'easeOutQuart',
		'Quad' => 'easeinQuad',
		'Sine' => 'easeOutSine'
	);

	/**
	 * @var array
	 */
	public static $cta_styles = array(
		'Rounded' => 'rounded',
		'Square' => 'square',
		'Round' => 'round',
		'Outlined' => 'outlined',
		'Square Outlined' => 'square_outlined'
	);

	/**
	 * @var array
	 */
	public static $txt_align = array(
		'Left' => 'left',
		'Right' => 'right',
		'Center' => 'center',
		'Justify' => 'justify'
	);

	/**
	 * @var array
	 */
	public static $el_widths = array(
		'100%' => '',
		'90%' => '90',
		'80%' => '80',
		'70%' => '70',
		'60%' => '60',
		'50%' => '50'
	);

	/**
	 * @var array
	 */
	public static $sep_widths = array(
		'1px' => '',
		'2px' => '2',
		'3px' => '3',
		'4px' => '4',
		'5px' => '5',
		'6px' => '6',
		'7px' => '7',
		'8px' => '8',
		'9px' => '9',
		'10px' => '10'
	);

	/**
	 * @var array
	 */
	public static $sep_styles = array(
		'Border' => '',
		'Dashed' => 'dashed',
		'Dotted' => 'dotted',
		'Double' => 'double'
	);

	/**
	 * @var array
	 */
	public static $box_styles = array(
		'Default' => '',
		'Rounded' => 'vc_box_rounded',
		'Border' => 'vc_box_border',
		'Outline' => 'vc_box_outline',
		'Shadow' => 'vc_box_shadow',
		'Bordered shadow' => 'vc_box_shadow_border',
		'3D Shadow' => 'vc_box_shadow_3d',
		'Round' => 'vc_box_circle', //new
		'Round Border' => 'vc_box_border_circle', //new
		'Round Outline' => 'vc_box_outline_circle', //new
		'Round Shadow' => 'vc_box_shadow_circle', //new
		'Round Border Shadow' => 'vc_box_shadow_border_circle', //new
		'Circle' => 'vc_box_circle_2', //new
		'Circle Border' => 'vc_box_border_circle_2', //new
		'Circle Outline' => 'vc_box_outline_circle_2', //new
		'Circle Shadow' => 'vc_box_shadow_circle_2', //new
		'Circle Border Shadow' => 'vc_box_shadow_border_circle_2' //new
	);

	/**
	 * @return array
	 */
	public static function getColors() {
		return self::$colors;
	}

	/**
	 * @return array
	 */
	public static function getIcons() {
		return self::$icons;
	}

	/**
	 * @return array
	 */
	public static function getSizes() {
		return self::$sizes;
	}

	/**
	 * @return array
	 */
	public static function getButtonStyles() {
		return self::$button_styles;
	}

	/**
	 * @return array
	 */
	public static function getMessageBoxStyles() {
		return self::$message_box_styles;
	}

	/**
	 * @return array
	 */
	public static function getToggleStyles() {
		return self::$toggle_styles;
	}

	/**
	 * @return array
	 */
	public static function getAnimationStyles() {
		return self::$animation_styles;
	}

	/**
	 * @return array
	 */
	public static function getCtaStyles() {
		return self::$cta_styles;
	}

	/**
	 * @return array
	 */
	public static function getTextAlign() {
		return self::$txt_align;
	}

	/**
	 * @return array
	 */
	public static function getBorderWidths() {
		return self::$sep_widths;
	}

	/**
	 * @return array
	 */
	public static function getElementWidths() {
		return self::$el_widths;
	}

	/**
	 * @return array
	 */
	public static function getSeparatorStyles() {
		return self::$sep_styles;
	}

	/**
	 * @return array
	 */
	public static function getBoxStyles() {
		return self::$box_styles;
	}

	public static function getColorsDashed() {
		$colors = array(
			esc_html__( 'Blue', 'surround' )        => 'blue',
			esc_html__( 'Turquoise', 'surround' )   => 'turquoise',
			esc_html__( 'Pink', 'surround' )        => 'pink',
			esc_html__( 'Violet', 'surround' )      => 'violet',
			esc_html__( 'Peacoc', 'surround' )      => 'peacoc',
			esc_html__( 'Chino', 'surround' )       => 'chino',
			esc_html__( 'Mulled Wine', 'surround' ) => 'mulled-wine',
			esc_html__( 'Vista Blue', 'surround' )  => 'vista-blue',
			esc_html__( 'Black', 'surround' )       => 'black',
			esc_html__( 'Grey', 'surround' )        => 'grey',
			esc_html__( 'Orange', 'surround' )      => 'orange',
			esc_html__( 'Sky', 'surround' )         => 'sky',
			esc_html__( 'Green', 'surround' )       => 'green',
			esc_html__( 'Juicy pink', 'surround' )  => 'juicy-pink',
			esc_html__( 'Sandy brown', 'surround' ) => 'sandy-brown',
			esc_html__( 'Purple', 'surround' )      => 'purple',
			esc_html__( 'White', 'surround' )       => 'white'
		);

		return $colors;
	}
}

/**
 * @param string $asset
 *
 * @return array
 */
function suroundGetVcShared($asset = '' ) {
	switch ( $asset ) {
		case 'colors':
			return suroundVcSharedLibrary::getColors();
			break;

		case 'colors-dashed':
			return suroundVcSharedLibrary::getColorsDashed();
			break;

		case 'icons':
			return suroundVcSharedLibrary::getIcons();
			break;

		case 'sizes':
			return suroundVcSharedLibrary::getSizes();
			break;

		case 'button styles':
		case 'alert styles':
			return suroundVcSharedLibrary::getButtonStyles();
			break;
		case 'message_box_styles':
			return suroundVcSharedLibrary::getMessageBoxStyles();
			break;
		case 'cta styles':
			return suroundVcSharedLibrary::getCtaStyles();
			break;

		case 'text align':
			return suroundVcSharedLibrary::getTextAlign();
			break;

		case 'cta widths':
		case 'separator widths':
			return suroundVcSharedLibrary::getElementWidths();
			break;

		case 'separator styles':
			return suroundVcSharedLibrary::getSeparatorStyles();
			break;

		case 'separator border widths':
			return suroundVcSharedLibrary::getBorderWidths();
			break;

		case 'single image styles':
			return suroundVcSharedLibrary::getBoxStyles();
			break;

		case 'toggle styles':
			return suroundVcSharedLibrary::getToggleStyles();
			break;

		case 'animation styles':
			return suroundVcSharedLibrary::getAnimationStyles();
			break;

		default:
			# code...
			break;
	}

	return '';
}