<?php

if ( !class_exists( 'suround_image_block' ) ) {

	class suround_image_block {

		function __construct()
		{
			add_action('vc_before_init', array($this, 'add_map'));
		}

		function add_map() {

			if ( function_exists('vc_map') ) {

				vc_map(
					array(
						"name" => esc_html__('Imageblock', 'surround' ),
						"base" => 'vc_mad_image_block',
						"class" => 'vc_mad_image_block',
						"icon" => "icon-wpb-mad-info-block",
						"category" => esc_html__( 'Suround', 'surround' ),
						"description" => esc_html__('Styled image blocks', 'surround' ),
						"as_parent" => array('only' => 'vc_mad_image_block_item'),
						"content_element" => true,
						"show_settings_on_create" => false,
						"params" => array(
							array(
								'type' => 'textfield',
								'heading' => esc_html__( 'Title', 'surround' ),
								'param_name' => 'title',
								'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' ),
							),
							array(
								'type' => 'dropdown',
								'heading' => esc_html__('Tag', 'surround' ),
								'param_name' => 'heading',
								'value' => array(
									'h2' => 'h2',
									'h3' => 'h3',
									'h4' => 'h4'
								),
								'std' => 'h2',
								'description' => esc_html__('Choose tag for heading', 'surround' ),
								'param_holder_class' => ''
							),
							array(
								'type' => 'textfield',
								'heading' => esc_html__( 'Subtitle', 'surround' ),
								'param_name' => 'subtitle',
								'description' => esc_html__( 'Enter text which will be used as subtitle. Leave blank if no subtitle is needed.', 'surround' )
							),
							array(
								'type' => 'dropdown',
								'heading' => esc_html__('Title Alignment', 'surround' ),
								'param_name' => 'align_title',
								'description' => esc_html__('Select title alignment.', 'surround' ),
								'value' => array(
									esc_html__('Left', 'surround' )   => 'align-left',
									esc_html__('Right', 'surround' )  => 'align-right',
									esc_html__('Center', 'surround' ) => 'align-center'
								),
							),
							array(
								"type" => "dropdown",
								"heading" => esc_html__( 'Select style', 'surround' ),
								"param_name" => 'style',
								"value" => array(
									esc_html__('Style 1', 'surround' ) => 'style-1',
									esc_html__('Style 2', 'surround' ) => 'style-2',
									esc_html__('Style 3', 'surround' ) => 'style-3'
								),
								"std" => 'style-1',
								"description" => esc_html__( 'Choose style for this info block.', 'surround' )
							),
							array(
								'type' => 'dropdown',
								'heading' => esc_html__( 'Columns', 'surround' ),
								'param_name' => 'columns',
								'value' => array(
									3 => 3,
									4 => 4,
									5 => 5,
								),
								'std' => 3,
								'description' => esc_html__('Choose count columns.', 'surround' )
							),
						),
						"js_view" => 'VcColumnView'
					));

				vc_map(
					array(
						"name" => esc_html__("Image Block Item", 'surround' ),
						"base" => "vc_mad_image_block_item",
						"class" => "vc_mad_image_block_item",
						"icon" => "icon-wpb-mad-info-block",
						"category" => esc_html__('Imageblock', 'surround' ),
						"content_element" => true,
						"as_child" => array('only' => 'vc_mad_image_block'),
						"is_container" => true,
						"params" => array(
							array(
								"type" => "textfield",
								"heading" => esc_html__('Title', 'surround' ),
								"param_name" => "title",
								"holder" => "h4",
								"description" => ''
							),
							array(
								'type' => 'attach_image',
								'heading' => esc_html__('Image', 'surround'),
								'param_name' => 'image',
								'value' => '',
								'description' => esc_html__('Select image from media library.', 'surround')
							),
							array(
								'type' => 'textarea_html',
								'holder' => 'div',
								'heading' => esc_html__('Text', 'surround' ),
								'param_name' => 'content',
								'value' => wp_kses(__('<p>Click edit button to change this text.</p>', 'surround' ), array( 'p' => array()))
							),
							array(
								'type' => 'vc_link',
								'heading' => esc_html__('URL (Link)', 'surround' ),
								'param_name' => 'link',
								'description' => esc_html__('Add link to info block.', 'surround' ),
							),
						)
					)
				);

			}
		}

	}

	if (class_exists('WPBakeryShortCodesContainer')) {

		class WPBakeryShortCode_vc_mad_image_block extends WPBakeryShortCodesContainer
		{

			protected function content( $atts, $content = null ) {

				$css_classes = array();
				$style = $layout = $columns = '';

				extract( shortcode_atts( array(
					'title' => '',
					'subtitle' => '',
					'heading' => 'h2',
					'align_title' => 'align-left',
					'columns' => 3,
					'style' => 'style-1'
				), $atts ) );

				$css_classes[] = 'image-box';
				$css_classes[] = $style;
				$css_classes[] = 'item-col-' . $columns;

				global $vc_mad_image_block_args;
				$vc_mad_image_block_args[] = array(
					'style' => $style,
					'content' => $content
				);

				ob_start(); ?>

				<div class="image-holder">

					<?php
					echo suround_get_title(
						array(
							'title' => $title,
							'subtitle' => $subtitle,
							'heading' => $heading,
							'align_title' => $align_title
						)
					);
					?>

					<div class="<?php echo esc_attr( implode(' ', $css_classes) ); ?>">
						<?php echo wpb_js_remove_wpautop( $content, false ) ?>
					</div>

				</div>

				<?php return ob_get_clean();

			}

		}

		class WPBakeryShortCode_vc_mad_image_block_item extends WPBakeryShortCode
		{

			protected function content( $atts, $content = null ) 	{

				$title = $link = $style_color = $image = $style = '';

				extract( shortcode_atts(array(
					'title' => '',
					'icon' => '',
					'image' => '',
					'link' => '',
				), $atts) );

				$link = ( '||' === $link ) ? '' : $link;
				$link = vc_build_link( $link );
				$use_link = false;
				if ( strlen( $link['url'] ) > 0 ) {
					$use_link = true;
					$a_href = $link['url'];
					$a_title = $link['title'];
					$a_target = $link['target'];
				}


				global $vc_mad_image_block_args;

				if ( isset($vc_mad_image_block_args) && is_array($vc_mad_image_block_args) ) {
					foreach ( $vc_mad_image_block_args as $image_block ) {
							if ( isset($image_block['style']) && !empty($image_block['style']) ) {
								$style = $image_block['style'];
							}
					}
				}

				if ( $content == null ) $content = '';

				ob_start(); ?>

				<?php if ( $style == 'style-1' ): ?>

					<div class="image-item-box">

						<?php if ( !empty($image) && absint($image)): ?>
							<div class="image-box-img">
								<?php echo wp_get_attachment_image( $image, 'suround-315x210-center-center' ) ?>
							</div>
						<?php endif; ?>


						<?php if ( $use_link ): ?>

							<h4 class="box-title">
								<a href="<?php echo esc_url($a_href) ?>">
									<?php if ( !empty($a_title) ): ?>
										<?php echo esc_html($a_title) ?>
									<?php else: ?>
										<?php echo esc_html($title) ?>
									<?php endif; ?>
								</a>
							</h4>

						<?php else: ?>

							<h4 class="box-title"><?php echo esc_html($title) ?></h4>

						<?php endif; ?>

						<?php if ( !empty($content) ): ?>
							<?php echo wpb_js_remove_wpautop( $content, true ) ?>
						<?php endif; ?>

					</div>

				<?php elseif ( $style == 'style-2' ): ?>

					<div class="grid-item">

						<div class="explore-item">

							<div class="explore-wrap">

								<?php echo wp_get_attachment_image( $image, 'suround-450x115-center-center' ) ?>

								<?php if ( $use_link || !empty($title) ): ?>

									<h4 class="explore-title">

										<?php if ( $use_link ): ?>
											<a href="<?php echo esc_url($a_href) ?>">
												<?php if ( !empty($a_title) ): ?>
													<?php echo esc_html($a_title) ?>
												<?php else: ?>
													<?php echo esc_html($title) ?>
												<?php endif; ?>
											</a>
										<?php else: ?>
											<?php echo esc_html($title) ?>
										<?php endif; ?>

										<i class="licon-chevron-right-circle"></i>

									</h4>

								<?php endif; ?>

							</div>

						</div>

					</div>

				<?php elseif ( $style == 'style-3' ): ?>

					<div class="grid-item">

						<div class="explore-item">

							<div class="explore-wrap">

								<?php echo wp_get_attachment_image( $image, 'suround-315x335-center-center' ) ?>

								<?php if ( $use_link || !empty($title) ): ?>

									<h4 class="explore-title">

										<?php if ( $use_link ): ?>
											<a href="<?php echo esc_url($a_href) ?>">
												<?php if ( !empty($a_title) ): ?>
													<?php echo esc_html($a_title) ?>
												<?php else: ?>
													<?php echo esc_html($title) ?>
												<?php endif; ?>
											</a>
										<?php else: ?>
											<?php echo esc_html($title) ?>
										<?php endif; ?>

										<i class="licon-chevron-right-circle"></i>

									</h4>

								<?php endif; ?>

							</div>

						</div>

					</div>

				<?php endif; ?>

				<?php return ob_get_clean();
			}

		}

	}

	new suround_image_block();
}