<?php

if ( !class_exists('suround_info_block') ) {

	class suround_info_block {

		function __construct() {
			add_action('vc_before_init', array( $this, 'add_map') );
		}

		function add_map() {

			if ( function_exists('vc_map') ) {

				vc_map(
					array(
						"name" => esc_html__('Infoblock', 'surround' ),
						"base" => 'vc_mad_info_block',
						"class" => 'vc_mad_info_block',
						"icon" => "icon-wpb-mad-info-block",
						"category" => esc_html__( 'Suround', 'surround' ),
						"description" => esc_html__('Styled info blocks', 'surround' ),
						"as_parent" => array('only' => 'vc_mad_info_block_item'),
						"content_element" => true,
						"show_settings_on_create" => false,
						"params" => array(
							array(
								'type' => 'textfield',
								'heading' => esc_html__( 'Title', 'surround' ),
								'param_name' => 'title',
								'description' => esc_html__( 'Enter text which will be used as title. Leave blank if no title is needed.', 'surround' ),
							),
							array(
								'type' => 'dropdown',
								'heading' => esc_html__('Tag', 'surround' ),
								'param_name' => 'heading',
								'value' => array(
									'h2' => 'h2',
									'h3' => 'h3',
									'h4' => 'h4'
								),
								'std' => 'h2',
								'description' => esc_html__('Choose tag for heading', 'surround' ),
								'param_holder_class' => ''
							),
							array(
								'type' => 'colorpicker',
								'heading' => esc_html__( 'Color for title', 'surround' ),
								'param_name' => 'title_color',
								'group' => esc_html__( 'Styling', 'surround' ),
								'description' => esc_html__( 'Select custom color for title.', 'surround' ),
							),
							array(
								'type' => 'textfield',
								'heading' => esc_html__( 'Subtitle', 'surround' ),
								'param_name' => 'subtitle',
								'description' => esc_html__( 'Enter text which will be used as subtitle. Leave blank if no subtitle is needed.', 'surround' )
							),
							array(
								'type' => 'dropdown',
								'heading' => esc_html__('Title Alignment', 'surround' ),
								'param_name' => 'align_title',
								'description' => esc_html__('Select title alignment.', 'surround' ),
								'value' => array(
									esc_html__('Left', 'surround' )   => 'align-left',
									esc_html__('Right', 'surround' )  => 'align-right',
									esc_html__('Center', 'surround' ) => 'align-center'
								),
							),
							array(
								"type" => "dropdown",
								"heading" => esc_html__( 'Select style', 'surround' ),
								"param_name" => 'style',
								"value" => array(
									esc_html__('Style 1', 'surround' ) => 'style-1',
									esc_html__('Style 2', 'surround' ) => 'style-2'
								),
								"std" => 'style-1',
								"description" => esc_html__( 'Choose style for this info block.', 'surround' )
							),
							array(
								'type' => 'dropdown',
								'heading' => esc_html__( 'Columns', 'surround' ),
								'param_name' => 'columns',
								'value' => array(
									3 => 3,
									4 => 4,
									5 => 5,
								),
								'std' => 3,
								'description' => esc_html__('Choose count columns.', 'surround' )
							),
						),
						"js_view" => 'VcColumnView'
					));

				vc_map(
					array(
						"name" => esc_html__("Info Block Item", 'surround' ),
						"base" => "vc_mad_info_block_item",
						"class" => "vc_mad_info_block_item",
						"icon" => "icon-wpb-mad-info-block",
						"category" => esc_html__('Infoblock', 'surround' ),
						"content_element" => true,
						"as_child" => array('only' => 'vc_mad_info_block'),
						"is_container" => true,
						"params" => array(
							array(
								"type" => "textfield",
								"heading" => esc_html__('Title', 'surround' ),
								"param_name" => "title",
								"holder" => "h4",
								"description" => ''
							),
							array(
								"type" => "choose_icons",
								"heading" => esc_html__("Icon", 'surround' ),
								"param_name" => "icon",
								"value" => 'none',
								"description" => esc_html__( 'Select icon from library.', 'surround' )
							),
							array(
								'type' => 'textarea_html',
								'holder' => 'div',
								'heading' => esc_html__('Text', 'surround' ),
								'param_name' => 'content',
								'value' => wp_kses(__('<p>Click edit button to change this text.</p>', 'surround' ), array( 'p' => array()))
							),
							array(
								'type' => 'vc_link',
								'heading' => esc_html__('URL (Link)', 'surround' ),
								'param_name' => 'link',
								'description' => esc_html__('Add link to info block.', 'surround' ),
							),
							array(
								'type' => 'colorpicker',
								'heading' => esc_html__( 'Color', 'surround' ),
								'param_name' => 'color',
								'group' => esc_html__( 'Styling', 'surround' ),
								'edit_field_class' => 'vc_col-sm-6',
								'description' => esc_html__( 'Select custom color for text.', 'surround' ),
							),
						)
					)
				);

			}
		}

	}

	if (class_exists('WPBakeryShortCodesContainer')) {

		class WPBakeryShortCode_vc_mad_info_block extends WPBakeryShortCodesContainer
		{

			protected function content( $atts, $content = null ) {

				$css_classes = array();
				$style = $layout = $columns = '';

				extract( shortcode_atts( array(
					'title' => '',
					'subtitle' => '',
					'title_color' => '',
					'heading' => 'h2',
					'align_title' => 'align-left',
					'columns' => 3,
					'style' => 'style-1'
				), $atts ) );

				$css_classes[] = 'icons-box';
				$css_classes[] = $style;
				$css_classes[] = 'item-col-' . $columns;

				global $vc_mad_info_block_args;
				$vc_mad_info_block_args[] = array(
					'style' => $style,
					'content' => $content
				);

				ob_start(); ?>

				<div class="info-holder">

					<?php
					echo suround_get_title(
						array(
							'title' => $title,
							'subtitle' => $subtitle,
							'heading' => $heading,
							'align_title' => $align_title,
							'title_color' => $title_color
						)
					);
					?>

					<div class="<?php echo esc_attr( implode(' ', $css_classes) ); ?>">
						<?php echo wpb_js_remove_wpautop( $content, false ) ?>
					</div>

				</div>

				<?php return ob_get_clean();

			}

		}

		class WPBakeryShortCode_vc_mad_info_block_item extends WPBakeryShortCode
		{

			protected function content( $atts, $content = null ) 	{

				$title = $link = $style_color = $image = $style = '';

				extract( shortcode_atts(array(
					'title' => '',
					'icon' => '',
					'image' => '',
					'link' => '',
					'color' => '',
					'title_instead_icon' => ''
				), $atts) );

				$link = ( '||' === $link ) ? '' : $link;
				$link = vc_build_link( $link );
				$use_link = false;
				if ( strlen( $link['url'] ) > 0 ) {
					$use_link = true;
					$a_href = $link['url'];
					$a_title = $link['title'];
					$a_target = $link['target'];
				}

				global $vc_mad_info_block_args;

				if ( isset($vc_mad_info_block_args) && is_array($vc_mad_info_block_args) ) {
					foreach ( $vc_mad_info_block_args as $info_block ) {
							if ( isset($info_block['style']) && !empty($info_block['style']) ) {
								$style = $info_block['style'];
							}
					}
				}

				if ( $content == null ) $content = '';

				ob_start(); ?>

				<?php if ( $style == 'style-1' ): ?>

					<div class="icons-wrap">

						<div class="icons-item">
							<div class="item-box">

								<?php if ( $icon != '' ): ?>
									<i class="<?php echo esc_attr( $icon ) ?>"><span></span></i>
								<?php endif; ?>

								<?php if ( $use_link ): ?>

									<h5 class="icons-box-title">
										<a href="<?php echo esc_url($a_href) ?>" target="<?php echo esc_attr($a_target) ?>">
											<?php if ( !empty($a_title) ): ?>
												<?php echo esc_html($a_title) ?>
											<?php else: ?>
												<?php echo esc_html( $title ) ?>
											<?php endif; ?>
										</a>
									</h5>

								<?php else: ?>

									<h5 class="icons-box-title"><?php echo esc_html( $title ) ?></h5>

								<?php endif; ?>

								<?php if ( ! empty( $content ) ): ?>
									<?php echo wpb_js_remove_wpautop( $content, true ) ?>
								<?php endif; ?>

							</div>
						</div>

					</div>

				<?php elseif ( $style == 'style-2' ): ?>

					<div class="icons-wrap">

						<div class="icons-item">
							<div class="item-box">

								<?php if ( $icon != '' ): ?>
									<i class="<?php echo esc_attr( $icon ) ?>"></i>
								<?php endif; ?>

								<div class="item-box-item">

									<?php if ( $use_link ): ?>

										<h5 class="icons-box-title">
											<a href="<?php echo esc_url($a_href) ?>" target="<?php echo esc_attr($a_target) ?>">
												<?php if ( !empty($a_title) ): ?>
													<?php echo esc_html($a_title) ?>
												<?php else: ?>
													<?php echo esc_html( $title ) ?>
												<?php endif; ?>
											</a>
										</h5>

									<?php else: ?>

										<h5 class="icons-box-title"><?php echo esc_html( $title ) ?></h5>

									<?php endif; ?>

									<?php if ( ! empty( $content ) ): ?>
										<?php echo wpb_js_remove_wpautop( $content, true ) ?>
									<?php endif; ?>

								</div>

							</div>
						</div>

					</div>

				<?php endif; ?>

				<?php return ob_get_clean();
			}

		}

	}

	new suround_info_block();
}