<?php

class WPBakeryShortCode_VC_mad_blog_posts_slider extends WPBakeryShortCode {

	public $atts = array();
	public $entries = '';
	public $loop = array();

	protected function content( $atts, $content = null ) {

		$this->atts = shortcode_atts( array(
			'title'       => '',
			'align_title' => 'align-center',
			'heading'     => 'h6',
			'layout'      => 'sl1',
			'columns'     => 3,
			'categories'  => array(),
			'orderby'     => 'date',
			'order'       => 'DESC',
			'items'       => 6
		), $atts, 'vc_mad_blog_posts_carousel' );

		$this->query_entries();
		$html = $this->html();

		return $html;
	}

	public function query_entries() {

		$params = $this->atts;

		$query = array(
			'post_type'      => 'post',
			'posts_per_page' => $params['items'],
			'orderby'        => $params['orderby'],
			'order'          => $params['order'],
			'post_status'    => array( 'publish' )
		);

		if ( ! empty( $params['categories'] ) ) {
			$query['category_name'] = $params['categories'];
		}

		$paged          = get_query_var( 'page' ) ? get_query_var( 'page' ) : ( get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1 );
		$query['paged'] = $paged;

		$this->entries = new WP_Query( $query );
	}

	public function html() {

		if ( empty( $this->entries ) || empty( $this->entries->posts ) ) {
			return;
		}
		$entries            = $this->entries;
		$atts               = $this->atts;
		$wrapper_attributes = array();

		extract( $atts );

		$css_classes          = array( 'layout-slider', 'layout-slider-' . $layout );
		$css_class            = preg_replace( '/\s+/', ' ', implode( ' ', array_filter( $css_classes ) ) );
		$wrapper_attributes[] = 'class="' . esc_attr( trim( $css_class ) ) . '"';

		ob_start(); ?>

		<?php if ( $entries->have_posts() ): ?>

			<div <?php echo implode( ' ', $wrapper_attributes ) ?>>

				<?php
				echo suround_get_title(
					array(
						'title'       => $title,
						'align_title' => $align_title,
						'heading'     => $heading
					)
				);
				?>

				<?php switch ( $layout ): case 'sl1'; ?>

					<div class="owl-carousel owl-nav__big--white" data-max-items="1" data-autoplay="false" data-nav="true">

						<?php while ( $entries->have_posts() ) : $entries->the_post(); ?>
							<?php get_template_part( 'template-parts/post/layout', 'sl1' ); ?>
						<?php endwhile; wp_reset_postdata(); ?>

					</div>

					<?php break; ?>

					<?php case 'sl2'; ?>

						<div class="owl-carousel owl-nav__big--white has-custom-dots" data-max-items="1" data-autoplay="false" data-nav="true">

							<?php while ( $entries->have_posts() ) : $entries->the_post(); ?>

								<?php get_template_part( 'template-parts/post/layout', 'sl2' ); ?>

							<?php endwhile; wp_reset_postdata(); ?>

						</div>

						<ul id="carousel-custom-dots" class="custom-dots">

							<?php $i = 0; ?>

							<?php while ( $entries->have_posts() ) : $entries->the_post(); ?>

								<li class="custom-dot entry <?php if ( $i == 0 ): ?>active<?php endif; ?>">

									<div class="entry-body">

										<?php echo suround_get_category_list() ?>

										<h3 class="entry-title">
											<?php if ( is_sticky() ): ?>
												<span class="sticky-label"><?php esc_html_e('Featured', 'surround' ) ?></span>
											<?php endif; ?>

											<a href="<?php echo esc_url( get_the_permalink() ) ?>"><?php echo get_the_title() ?></a>
										</h3>

										<?php if ( $meta = suround_blog_post_meta( false, array( 'date', 'views', 'vote' ) ) ) : ?>
											<div class="entry-meta"><?php echo wp_kses_post($meta); ?></div>
										<?php endif; ?>

									</div>

								</li>

								<?php $i++; ?>

							<?php endwhile; wp_reset_postdata(); ?>

						</ul><!--/ .custom-dots-->

					<?php break; ?>
				<?php endswitch; ?>

			</div>

		<?php else: ?>

			<?php get_template_part( 'template-parts/post/content', 'none' ); ?>

		<?php endif; ?>

		<?php return ob_get_clean();
	}

}