<?php

class WPBakeryShortCode_VC_mad_post_categories extends WPBakeryShortCode {

	public $atts = array();
	public $term_list_category = '';
	public $term_list_region = '';
	public $custom_category_labels = '';

	protected function content( $atts, $content = null ) {

		$this->atts = shortcode_atts(array(
			'title' => '',
			'align_title' => 'align-left',
			'heading' => 'h6',
			'style' => 'style-1',
			'columns' => 3,
			'number_of_items' => 6,
			'columns_per_page' => 3,
			'orderby' => 'name',
			'order' => 'DESC',
			'categories' => '',
		), $atts, 'vc_mad_post_categories');

		$this->query_entries_category();
		$this->prepare_entries();

		$html = $this->html();

		return $html;
	}

	public function query_entries_category( $params = array() ) {

		if ( empty($params) ) $params = $this->atts;

		extract( $params );

		$query_args = array(
			'taxonomy' => 'category',
			'order' => 'DESC',
			'hide_empty' => false,
			'hierarchical' => true,
			'pad_counts' => true
		);

		if ( ! empty( $orderby ) && is_string( $orderby ) ) {
			$query_args['orderby'] = $orderby;
		}

		if ( ! empty( $order ) && is_string( $order ) ) {
			$query_args['order'] = $order;
		}

		$categories_slug = array();

		if ( ! empty( $categories ) && is_string( $categories ) ) {

			$categories = explode( ',', $categories );

			foreach ( $categories as $key => $cat ) {
				$categories_slug[ $key ] = $cat;
			}

			$query_args['slug'] = $categories_slug;

		}

		$all_terms = get_terms(
			$query_args
		);

		if ( is_wp_error( $all_terms ) ) {
			return;
		}

		//now create an array with the category slug as key so we can reference/search easier
//		$all_categories = array();
//		foreach ( $all_terms as $key => $term ) {
//			$all_categories[ $term->slug ] = $this->assemble_terms_childs($term);
//		}

		if ( ! $number_of_items = intval( $number_of_items ) ) {
			$number_of_items = 10;
		}

		$term_list = array_slice( $all_terms, 0, $number_of_items );
		$this->term_list_category = $term_list;

	}

	public function html() {

		if ( empty($this->term_list_category) ) return;

		$wrapper_attributes = array();
		$term_list_category = $this->term_list_category;

		$img_html = '';

		extract( $this->atts );

		$css_classes = array(
			'explore-box',
			'item-col-' . absint($columns),
			$style
		);

		if ( $style == 'style-3' ) {
			$css_classes[] = 'grid--isotope';
			$wrapper_attributes[] = 'data-masonry=true';
		}

		$css_class = preg_replace( '/\s+/', ' ', implode( ' ', array_filter( $css_classes ) ) );
		$wrapper_attributes[] = 'class="' . esc_attr( trim( $css_class ) ) . '"';

		ob_start(); ?>

		<div class="explore-holder">

			<?php
			echo suround_get_title(
				array(
					'title' => $title,
					'align_title' => $align_title,
					'heading' => $heading
				)
			);
			?>

			<div <?php echo implode( ' ', $wrapper_attributes ) ?>>

				<?php if ( $style == 'style-1' ): ?>

					<?php foreach ( $term_list_category as $key => $term ) :

						if ( !$term ) { continue; }

						$img_url = suround_get_category_meta( $term->term_id, 'image' );

						$attachment_id = suround_get_image_id_by_url( $img_url );

						if ( $attachment_id ) {
							$img_html = wp_get_attachment_image( $attachment_id, 'suround-450x115-center-center' );
						}

						if ( empty( $img_html ) ) {
							$img_html = '<img width="430" height="115" src="' . esc_url( $img_url ) . '" alt="' . esc_attr( $term->name ) . '"/>';
						}

						?>

						<div class="grid-item" id="term-<?php echo esc_attr($term->term_id) ?>">

							<div class="explore-item">

								<div class="explore-wrap">

									<a href="<?php echo esc_url( get_term_link( $term->term_id ) ); ?>" class="overlink"></a>

									<?php echo wp_kses_post($img_html); ?>

									<h4 class="explore-title">
										<a href="<?php echo esc_url( get_term_link( $term->term_id ) ); ?>">
											<?php echo esc_html($term->name); ?>
										</a>
										<i class="licon-chevron-right-circle"></i>
									</h4>

								</div>

							</div>

						</div>

					<?php endforeach; ?>

				<?php elseif ( $style == 'style-2' ): ?>

					<?php foreach ( $term_list_category as $key => $term ) :

						if ( !$term ) { continue; }

						$img_url = suround_get_category_meta( $term->term_id, 'image' );
						$attachment_id = suround_get_category_meta( $term->term_id, 'image_id' );
						$bg_image = !empty( $img_url ) ? $img_url : '';
						$img_id = !empty( $bg_image ) ? suround_get_image_id_by_url($bg_image) : '';

						if ( empty($img_id) ) {
							$img_id = $attachment_id ? $attachment_id : '';
						}
						?>

						<div class="grid-item">

							<div class="explore-item">

								<div class="explore-wrap">

									<a href="<?php echo esc_url( get_term_link( $term->term_id ) ); ?>" class="overlink"></a>

									<?php if ( $img_id ) : ?>
										<?php echo wp_get_attachment_image( $img_id, 'suround-315x335-center-center' ); ?>
									<?php endif; ?>

									<h4 class="explore-title">
										<a href="<?php echo esc_url( get_term_link( $term->term_id ) ); ?>">
											<?php echo esc_html($term->name); ?>
										</a>
										<i class="licon-chevron-right-circle"></i>
									</h4>

								</div>

							</div>

						</div>

					<?php endforeach; ?>

				<?php elseif ( $style == 'style-3'): ?>

					<?php
					$defaults = array(
						'term_id' => '',
						'name' => '',
						'slug' => '',
						'count' => '',
						'parent' => '',
						'size_css_class' => 'small--size',
						'image_size' => 'suround-441x336-center-center'
					);
					?>

					<?php if ( !empty($this->loop) ): ?>

						<?php foreach( $this->loop as $term ): extract(array_merge($defaults, $term)); ?>

							<?php if ( !$term ) { continue; } ?>

							<?php
							$img_url = suround_get_category_meta( $term_id, 'image' );

							if ( !empty( $img_url ) ) {
								$attachment_id = suround_get_image_id_by_url( $img_url );

								$img_html = wp_get_attachment_image( $attachment_id, $image_size );

								if ( empty( $img_html ) ) {
									$img_html = '<img width="441" height="336" src="'.esc_url( $img_url ).'" alt="'. esc_attr($name) .'"/>';
								}
							}

							?>

							<div class="grid-item <?php echo sanitize_html_class($size_css_class) ?>">

								<div class="explore-item">

									<div class="explore-wrap">

										<a href="<?php echo esc_url( get_term_link( $term_id ) ); ?>" class="overlink"></a>

										<?php echo wp_kses_post($img_html); ?>

										<h4 class="explore-title">
											<a href="<?php echo esc_url( get_term_link( $term_id ) ); ?>">
												<?php echo esc_html($name); ?>
											</a>
											<i class="licon-chevron-right-circle"></i>
										</h4>

									</div>

								</div>

							</div>

						<?php endforeach; ?>

					<?php endif; ?>

				<?php endif; ?>

			</div><!--/ .flex-row-->

		</div><!--/ .categories-holder-->

		<?php return ob_get_clean();
	}

	public function convert_image_sizes( $size ) {

		switch ( $size ) {
			case 'small':       $image_size = 'suround-440x335-center-center'; break;
			case 'middle': 		$image_size = 'suround-440x698-center-center'; break;
			case 'large': 		$image_size = 'suround-908x335-center-center'; break;
			default: 			$image_size = 'suround-440x335-center-cente'; break;
		}

		return $image_size;
	}

	public function get_size_class( $size ) {

		switch ( $size ) {
			case 'small':       $css_class = 'small--size'; break;
			case 'middle': 		$css_class = 'medium--size'; break;
			case 'large': 		$css_class = 'large--size'; break;
			default: 			$css_class = 'small--size'; break;
		}

		return $css_class;
	}

	public function prepare_entries() {

		$this->loop = array();
//
		if ( empty($this->term_list_category) ) return;
//
		foreach ( $this->term_list_category as $key => $term ) {
			$this->loop[$key]['term_id'] = $term_id = $term->term_id;
			$this->loop[$key]['name'] = $term->name;
			$this->loop[$key]['slug'] = $term->slug;
			$this->loop[$key]['count'] = $term->count;
			$this->loop[$key]['parent'] = $term->parent;
			$this->loop[$key]['size_css_class'] = $this->get_size_class(suround_get_category_meta($term_id, 'image_size'));
			$this->loop[$key]['image_size'] = $this->convert_image_sizes( suround_get_category_meta($term_id, 'image_size') );
		}

	}

}