<?php

class WPBakeryShortCode_VC_mad_team_members extends WPBakeryShortCode {

	public $atts = array();
	public $entries = '';

	protected function content($atts, $content = null) {

		$this->atts = shortcode_atts( array(
			'title' => '',
			'subtitle' => '',
			'align_title' => 'align-left',
			'heading' => 'h3',
			'style' => 'style-1',
			'columns' => 3,
			'items' => 3,
			'carousel' => false,
			'multi_members' => '',
			'members' => '',
			'categories' => array(),
			'orderby' => 'date',
			'order' => 'DESC'
		), $atts, 'vc_mad_team_members' );

		$this->query_entries();
		$html = $this->html();

		return $html;
	}

	public function query_entries() {

		$params = $this->atts;

		$tax_query = array();

		$query = array(
			'post_type' => 'team-members',
			'posts_per_page' => $params['items'],
			'orderby' => $params['orderby'],
			'order' => $params['order'],
			'tax_query' => $tax_query
		);

		$multi_members = trim($this->atts['multi_members']);

		if ( !empty($multi_members) ) {
			$multi_members_array = explode(',', $this->atts['multi_members']);
			$query['post__in'] = $multi_members_array;
		}

		$this->entries = new WP_Query($query);
	}

	public function html() {

		if ( empty($this->entries) || empty($this->entries->posts) ) return;

		$title = $style = $members = $columns = '';
		$wrapper_attributes = array();

		extract( $this->atts );

		$css_classes = array(
			'team-holder',
			$style,
			'flex-row',
			'item-col-' . absint($columns)
		);

		$wrapper_attributes[] = 'class="' . esc_attr( trim( implode( ' ', array_filter( $css_classes ) ) ) ) . '"';

		ob_start() ?>

		<?php
		echo suround_get_title(
			array(
				'title' => $title,
				'subtitle' => $subtitle,
				'align_title' => $align_title,
				'heading' => $heading
			)
		);
		?>

		<?php if ( $style == 'style-1' ): ?>

			<div <?php echo implode( ' ', $wrapper_attributes ) ?>>

				<?php foreach ( $this->entries->posts as $entry ): ?>

					<?php
					$id = $entry->ID;
					$name = get_the_title($id);
					$link  = get_permalink($id);
					$position = mad_meta( 'suround_tm_position', '', $id );
					$content = has_excerpt($id) ? $entry->post_excerpt : $entry->post_content;
					?>

					<div class="team-item">

						<?php if ( has_post_thumbnail( $id ) ): ?>
							<a href="<?php echo esc_url($link) ?>" class="member-photo">
								<?php echo get_the_post_thumbnail( $id, '' ); ?>
							</a>
						<?php endif; ?>

						<div class="team-desc">
							<div class="member-info">
								<h5 class="member-name"><a href="<?php echo esc_url($link) ?>"><?php echo esc_html($name); ?></a></h5>
								<div class="member-position"><?php echo esc_html($position) ?></div>
							</div>
						</div>

					</div><!--/ .team-item-->

				<?php endforeach; ?>

			</div><!--/ .team-holder-->

		<?php elseif ( $style == 'style-2' ): ?>

			<?php if ( !$members ) { return; } ?>

			<?php $member = get_post( $members ); ?>

			<?php if ( !empty($member) ): ?>

				<?php
				$id = $member->ID;
				$name = get_the_title($id);
				$link  = get_permalink($id);
				$position = mad_meta( 'suround_tm_position', '', $id );
				$content = has_excerpt($id) ? $member->post_excerpt : $member->post_content;
				?>

				<div class="team-holder flex-row justify-content-center">

					<div class="team-item single-item">

						<?php if ( has_post_thumbnail( $id ) ): ?>
							<a href="<?php echo esc_url($link) ?>" class="member-photo">
								<?php echo get_the_post_thumbnail( $id, '' ); ?>
							</a>
						<?php endif; ?>

						<div class="team-desc">

							<div class="member-info">
								<h4 class="member-name"><a href="<?php echo esc_url($link) ?>"><?php echo esc_html($name); ?></a></h4>
								<div class="member-position"><?php echo esc_html($position) ?></div>
							</div>

							<?php echo apply_filters( 'the_content', $content ); ?>

						</div>

					</div><!--/ .team-item-->

				</div><!--/ .team-holder-->

			<?php endif; ?>

		<?php elseif ( $style == 'style-3' ): ?>

			<div class="carousel-type-2">

				<div class="owl-carousel team-holder" data-max-items="4" data-item-margin="30">

					<?php foreach ( $this->entries->posts as $entry ): ?>

						<?php
						$id = $entry->ID;
						$name = get_the_title($id);
						$link  = get_permalink($id);
						$position = mad_meta( 'suround_tm_position', '', $id );
						?>

						<div class="team-item">

							<?php if ( has_post_thumbnail( $id ) ): ?>
								<a href="<?php echo esc_url($link) ?>" class="member-photo">
									<?php echo get_the_post_thumbnail( $id, 'suround-315x335-center-center' ); ?>
								</a>
							<?php endif; ?>

							<div class="team-desc">
								<div class="member-info">
									<h5 class="member-name"><a href="<?php echo esc_url($link) ?>"><?php echo esc_html($name); ?></a></h5>
									<div class="member-position"><?php echo esc_html($position) ?></div>
								</div>
							</div>

						</div><!--/ .team-item-->

					<?php endforeach; ?>

				</div>

			</div>

		<?php endif; ?>

		<?php return ob_get_clean();
	}

}