<?php

class WPBakeryShortCode_VC_mad_testimonials extends WPBakeryShortCode {

	public $atts = array();
	public $entries = '';

	protected function content( $atts, $content = null ) {

		$this->atts = shortcode_atts( array(
			'title'       => '',
			'heading'     => 'h3',
			'title_color' => '',
			'align_title' => 'align-left',
			'style'       => 'carousel-style',
			'orderby'     => 'date',
			'order'       => 'DESC',
			'image'       => '',
			'items'       => 6,
		), $atts, 'vc_mad_testimonials' );

		$this->query_entries();

		return $this->html();
	}

	public function query_entries() {
		$params = $this->atts;
		$page   = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : get_query_var( 'page' );
		if ( ! $page ) {
			$page = 1;
		}

		$tax_query = array();

		$query = array(
			'post_type'      => 'testimonials',
			'orderby'        => $params['orderby'],
			'order'          => $params['order'],
			'paged'          => $page,
			'posts_per_page' => $params['items']
		);

		if ( ! empty( $tax_query ) ) {
			$query['tax_query'] = $tax_query;
		}

		$this->testimonials = new WP_Query( $query );
	}

	public function html() {

		if ( empty( $this->testimonials ) || empty( $this->testimonials->posts ) ) {
			return;
		}

		extract( $this->atts );

		$css_classes = array(
			'testimonial-holder',
			$style
		);

		$wrapper_attributes = array();

		if ( $style == 'carousel-style' ) {
			$wrapper_attributes[] = 'data-max-items="1"';
			$wrapper_attributes[] = 'data-autoplay="true"';
			$wrapper_attributes[] = 'data-dots="true"';
			$css_classes[]        = 'owl-carousel';
		}

		$wrapper_attributes[] = 'class="' . esc_attr( trim( implode( ' ', array_filter( $css_classes ) ) ) ) . '"';

		ob_start(); ?>

		<?php
		echo suround_get_title(
			array(
				'title'   => $title,
				'heading' => $heading
			)
		);
		?>

		<?php if ( $style == 'carousel-style' ): ?>

			<div <?php echo implode( ' ', $wrapper_attributes ) ?>>

				<?php foreach ( $this->testimonials->posts as $testimonial ):
					$id = $testimonial->ID;
					$name = get_the_title( $id );
					$link = get_permalink( $id );
					$photo_image_id = get_post_meta( $id, 'suround_testi_photo', true );
					$testi_text = get_post_meta( $id, 'suround_testi_text', true );
					?>

					<div class="item-carousel">
						<div class="testimonial">

							<div class="author-box">
								<div class="author-info">

									<?php
									$photo = '';
									if ( ! empty( $photo_image_id ) ) {
										$photo = wp_get_attachment_image_src( $photo_image_id, 'suround-112x112-center-center' );
									}

									if ( ! empty( $photo ) && ( strstr( $photo[0], 'http' ) || file_exists( $photo[0] ) ) ) {
										$photo = $photo[0];
										echo '<div class="member-photo"><img src="' . esc_attr( $photo ) . '" alt="' . esc_attr( get_the_title( $id ) ) . '" /></div>';
									}
									?>

									<div class="author"><?php echo esc_html( $name ) ?></div>
									<a href="<?php echo esc_url( $link ) ?>"
									   class="author-position"><?php echo get_post_meta( $id, 'suround_testi_name', true ); ?></a>
								</div>
							</div>

							<?php if ( !empty($testi_text) ): ?>

								<blockquote>
									<p>“<?php echo wp_kses_post($testi_text) ?>”</p>
								</blockquote>

							<?php endif; ?>

						</div>
					</div>

				<?php endforeach; ?>

			</div>

		<?php elseif ( $style == 'list-style' ): ?>

			<div <?php echo implode( ' ', $wrapper_attributes ) ?>>

				<?php foreach ( $this->testimonials->posts as $testimonial ):
					$id = $testimonial->ID;
					$name = get_the_title( $id );
					$link = get_permalink( $id );
					$photo_image_id = get_post_meta( $id, 'suround_testi_photo', true );
					$testi_text = get_post_meta( $id, 'suround_testi_text', true );
					?>

					<div class="testimonial">

						<?php if ( !empty($testi_text) ): ?>

							<blockquote>
								<p>“<?php echo wp_kses_post($testi_text) ?>”</p>
							</blockquote>

						<?php endif; ?>

						<div class="author-box">

							<?php
							$photo_src = '';
							if ( ! empty( $photo_image_id ) ) {
								$photo_src = wp_get_attachment_image_src( $photo_image_id, '' );
							}

							if ( ! empty( $photo_src ) && ( strstr( $photo_src[0], 'http' ) || file_exists( $photo[0] ) ) ) {
								$photo_src = $photo_src[0];
								echo '<div class="member-photo"><img src="' . esc_attr( $photo_src ) . '" alt="' . esc_attr( get_the_title( $id ) ) . '" /></div>';
							}
							?>

							<div class="author-info">
								<div class="author"><?php echo esc_html( $name ) ?></div>
								<a href="<?php echo esc_url( $link ) ?>"
								   class="author-position"><?php echo get_post_meta( $id, 'suround_testi_name', true ); ?></a>
							</div>

						</div><!--/ .author-box-->

					</div><!--/ .testimonial-->

				<?php endforeach; ?>

			</div>

		<?php endif; ?>

		<?php return ob_get_clean();
	}

}