<?php
/**
 * WooCommerce
 *
 * @category Integration
 */
class Suround_WooCommerce extends Suround_Integration {

	public function __construct() {

		$this->includes = array(
			'functions.php',
			'class-woocommerce-template.php',
			'class-woocommerce-new-badge.php',
			'class-woocommerce-ordering.php',
			'class-woocommerce-layout.php',
			'class-woocommerce-shopcart.php'
		);

		// add customizer support
		parent::__construct( dirname( __FILE__ ) );
	}

	public function init() {

		$this->template = new Suround_WooCommerce_Template();
		$this->ordering = new Suround_Catalog_Ordering();
		$this->new = new Suround_WooCommerce_New_Badge();
		$this->layout = new Suround_WooCommerce_Layout();

	}

	public function after_setup() {
		add_action( 'after_setup_theme', array( $this, 'setup' ) );
	}

	public function setup_actions() {
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
	}


	public function setup() {

		add_theme_support( 'woocommerce', apply_filters( 'suround_woocommerce_args', array(
			'thumbnail_image_width' => 450,
			'gallery_thumbnail_image_width' => 206,
			'single_image_width' => 680,
			'product_grid'          => array(
				'default_columns' => 4,
				'default_rows'    => 4,
				'min_columns'     => 2,
				'max_columns'     => 4,
				'min_rows'        => 1
			)
		) ) );

		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );

	}

	/**
	 * Enqueue script on favorite form.
	 *
	 * @since 3.6.0
	 */
	public function enqueue_scripts() {

//		wp_enqueue_style( 'suround-woocommerce-mod', $this->get_url() . 'css/woocommerce' . ( WP_DEBUG ? '' : '.min' ) . '.css' );
		wp_enqueue_script( 'suround-woocommerce-mod', $this->get_url() . 'js/woocommerce' . ( WP_DEBUG ? '' : '.min' ) . '.js', array( 'jquery' ), 1, true );
		wp_localize_script( 'suround-woocommerce-mod', 'suround_woocommerce_mod', array(
			'ajaxurl' => admin_url( 'admin-ajax.php' ),
			'nonce_cart_item_remove' => wp_create_nonce( 'suround_cart_item_remove' )
		));

	}

}
