<?php

/**
 * Save category meta
 *
 * Callback function to save category meta data
 */

add_action( 'edited_category', 'suround_save_category_meta_fields', 10, 2 );
add_action( 'create_category', 'suround_save_category_meta_fields', 10, 2 );

if ( !function_exists( 'suround_save_category_meta_fields' ) ) :
	function suround_save_category_meta_fields( $term_id ) {

		if ( ! isset($_POST['suround']) ) return;
		if ( ! current_user_can('edit_term', $term_id) ) return;

		$extra = wp_unslash( $_POST['suround'] );

		$meta = array();

		foreach( $extra as $key => $val ) {
			$meta[$key] = $val;
		}

		if ( ! empty( $meta ) ) {
			update_term_meta( $term_id, '_suround_meta', $meta );
		} else {
			delete_term_meta( $term_id, '_suround_meta' );
		}

		return $term_id;

	}
endif;

/**
 * Add category meta
 *
 */

add_action( 'category_add_form_fields', 'suround_category_add_meta_fields', 10, 2 );

if( !function_exists('suround_category_add_meta_fields') )	:
	function suround_category_add_meta_fields() {
		$meta = suround_get_category_meta();
		$image_sizes = suround_get__sizes();
		$sidebar = suround_sidebar_position(true);
		$layouts = suround_get_category_layouts();
		$all_sidebars = suround_get_registered_sidebars(
			array( '' => esc_html('Default', 'surround' ) )
		);
		?>

		<div class="form-field">
			<label class="layout-title"><?php esc_html_e( 'Layout options', 'surround' ); ?></label>
			<label><input type="radio" name="suround[layout][type]" value="inherit" class="layout-type" <?php checked( $meta['layout']['type'], 'inherit' );?>> <?php esc_html_e( 'Inherit from global category options', 'surround' ); ?></label>
			<label><input type="radio" name="suround[layout][type]" value="custom" class="layout-type" <?php checked( $meta['layout']['type'], 'custom' );?>> <?php esc_html_e( 'Set custom layout', 'surround' ); ?></label>
		</div>

		<div class="form-field suround-layout-opt">
			<label class="layout-title"><?php esc_html_e( 'Layout', 'surround' ); ?></label>

			<select class="layout-main" name="suround[layout][main]">
				<?php foreach ( $layouts as $key => $name ) : ?>
					<option value="<?php echo esc_attr($key) ?>" <?php selected( $key, $meta['layout']['main'] ); ?>><?php echo wp_kses_post($name); ?></option>
				<?php endforeach ?>
			</select>

		</div>

		<div class="form-field suround-layout-opt suround-layout-grid-fullwidth">
			<label class="layout-title"><?php esc_html_e( 'Full Width', 'surround' ); ?></label>
			<label><input type="radio" name="suround[layout][grid_fullwidth]" value="1" <?php checked( 1, $meta['layout']['grid_fullwidth']); ?>><?php esc_html_e('Yes', 'surround'); ?></label>
			<label><input type="radio" name="suround[layout][grid_fullwidth]" value="0" <?php checked( 0, $meta['layout']['grid_fullwidth']); ?>><?php esc_html_e('No', 'surround'); ?></label>
		</div>

		<div class="form-field suround-layout-opt suround-layout-grid-columns">
			<label class="layout-title"><?php esc_html_e( 'Columns for grid layout', 'surround' ); ?></label>

			<select name="suround[layout][columns]">
				<option <?php selected( 2, $meta['layout']['columns'] ); ?> value="2">2</option>
				<option <?php selected( 3, $meta['layout']['columns'] ); ?> value="3">3</option>
				<option <?php selected( 4, $meta['layout']['columns'] ); ?> value="4">4</option>
			</select>

		</div>

		<div class="form-field suround-layout-opt">
			<label class="layout-title"><?php esc_html_e( 'Number of posts', 'surround' ); ?></label>
			<input name="suround[layout][ppp]" type="text" class="suround-small-text" value="<?php echo esc_attr($meta['layout']['ppp']); ?>" />
		</div>

		<div class="form-field suround-layout-opt suround-layout-grid-breadcrumbs">
			<label class="layout-title"><?php esc_html_e( 'Breadcrumbs', 'surround' ); ?></label>
			<label><input type="radio" class="layout-breadcrumb" name="suround[layout][breadcrumb]" value="1" <?php checked( 1, $meta['layout']['breadcrumb']); ?>><?php esc_html_e('Show', 'surround'); ?></label>
			<label><input type="radio" class="layout-breadcrumb" name="suround[layout][breadcrumb]" value="0" <?php checked( 0, $meta['layout']['breadcrumb']); ?>><?php esc_html_e('Hide', 'surround'); ?></label>
		</div>

		<div class="form-field suround-layout-opt suround-layout-breadcrumbs-position">
			<label class="layout-title"><?php esc_html_e( 'Position Breadcrumbs', 'surround' ); ?></label>
			<label><input type="radio" name="suround[layout][position_breadcrumb]" value="after" <?php checked( 'after', $meta['layout']['position_breadcrumb']); ?>><?php esc_html_e('After header', 'surround'); ?></label>
			<label><input type="radio" name="suround[layout][position_breadcrumb]" value="before" <?php checked( 'before', $meta['layout']['position_breadcrumb']); ?>><?php esc_html_e('Before content', 'surround'); ?></label>
		</div>

		<div class="form-field suround-layout-opt suround-layout-breadcrumbs-position">
			<label class="layout-title"><?php esc_html_e( 'Align Breadcrumbs', 'surround' ); ?></label>
			<label><input type="radio" name="suround[layout][breadcrumb_align]" value="center" <?php checked( 'center', $meta['layout']['breadcrumb_align']); ?>><?php esc_html_e('Center', 'surround'); ?></label>
			<label><input type="radio" name="suround[layout][breadcrumb_align]" value="right" <?php checked( 'right', $meta['layout']['breadcrumb_align']); ?>><?php esc_html_e('Right (with overlay)', 'surround'); ?></label>
		</div>

		<div class="form-field suround-layout-opt">
			<label class="layout-title"><?php esc_html_e( 'Map', 'surround' ); ?></label>
			<label><input type="radio" name="suround[layout][map]" value="show" <?php checked( 'show', $meta['layout']['map']); ?>><?php esc_html_e('Show', 'surround'); ?></label>
			<label><input type="radio" name="suround[layout][map]" value="hide" <?php checked( 'hide', $meta['layout']['map']); ?>><?php esc_html_e('Hide', 'surround'); ?></label>
			<label><input type="radio" name="suround[layout][map]" value="no" <?php checked( 'no', $meta['layout']['map']); ?>><?php esc_html_e('No', 'surround'); ?></label>
		</div>

		<div class="form-field suround-layout-opt">
			<label class="layout-title"><?php esc_html_e( 'Filter', 'surround' ); ?></label>
			<label><input type="radio" name="suround[layout][filter]" value="1" <?php checked( 1, $meta['layout']['filter']); ?>><?php esc_html_e('Show', 'surround'); ?></label>
			<label><input type="radio" name="suround[layout][filter]" value="0" <?php checked( 0, $meta['layout']['filter']); ?>><?php esc_html_e('Hide', 'surround'); ?></label>
		</div>

		<div class="form-field suround-layout-opt">
			<label class="layout-title"><?php esc_html_e( 'Order', 'surround' ); ?></label>
			<label>
				<input type="radio" name="suround[layout][order]" value="date" <?php checked( 'date', $meta['layout']['order'] );?>>
				<?php esc_html_e('Latest Post', 'surround'); ?>
			</label>
			<label>
				<input type="radio" name="suround[layout][order]" value="comment_count" <?php checked( 'comment_count', $meta['layout']['order'] );?>>
				<?php esc_html_e('Most commented posts', 'surround'); ?>
			</label>
			<label>
				<input type="radio" name="suround[layout][order]" value="views" <?php checked( 'views', $meta['layout']['order'] );?>>
				<?php esc_html_e('Most viewed posts', 'surround'); ?>
			</label>
		</div>

		<div class="form-field">
			<label class="layout-title"><?php esc_html_e( 'Sidebar options', 'surround' ); ?></label>

			<label>
				<input type="radio" name="suround[sidebar][type]" value="inherit" class="layout-sidebar" <?php checked( $meta['sidebar']['type'], 'inherit' );?>> <?php esc_html_e( 'Inherit from global category sibebar options', 'surround' ); ?>
			</label>
			<label>
				<input type="radio" name="suround[sidebar][type]" value="custom" class="layout-sidebar" <?php checked( $meta['sidebar']['type'], 'custom' );?>> <?php esc_html_e( 'Set custom category sidebar options', 'surround' ); ?>
			</label>

		</div>

		<div class="form-field suround-sidebar-opt">
			<label class="layout-title"><?php esc_html_e( 'Display sidebar', 'surround' ); ?></label>

			<ul class="suround-img-select-wrap">
				<?php foreach ( $sidebar as $id => $layout ): ?>
					<li>
						<?php $selected_class = suround_compare( $id, $meta['sidebar']['use_sidebar'] ) ? ' selected': ''; ?>
						<img src="<?php echo esc_url($layout['img']); ?>" title="<?php echo esc_attr($layout['title']); ?>" class="suround-img-select<?php echo esc_attr( $selected_class ); ?>">
						<br/><span><?php echo esc_attr($layout['title']); ?></span>
						<input type="radio" class="suround-hidden suround-count-me" name="suround[sidebar][use_sidebar]" value="<?php echo esc_attr($id); ?>" <?php checked( $id, $meta['sidebar']['use_sidebar'] );?>/>
					</li>
				<?php endforeach; ?>
			</ul>

		</div>

		<div class="form-field suround-sidebar-opt">
			<label class="layout-title"><?php esc_html_e( 'Category standard sidebar', 'surround' ); ?></label>
			<select name="suround[sidebar][standard_sidebar]" >
				<?php foreach ( $all_sidebars as $key => $name ) : ?>
					<option value="<?php echo esc_attr($key) ?>" <?php selected( $key, $meta['sidebar']['standard_sidebar'] ); ?>><?php echo wp_kses_post($name); ?></option>
				<?php endforeach ?>
			</select>
		</div>

		<div class="form-field">
			<label class="layout-title"><?php esc_html_e( 'Image', 'surround' ); ?></label>
			<?php $display = $meta['image'] ? 'initial' : 'none'; ?>
			<p>
				<img id="suround-image-preview" class="suround-image-preview" src="<?php echo esc_url( $meta['image'] ); ?>" style="display:<?php echo esc_attr( $display ); ?>;">
			</p>

			<p>
				<input type="hidden" name="suround[image]" id="suround-image-url" value="<?php echo esc_attr( $meta['image'] ); ?>"/>
				<input type="hidden" name="suround[image_id]" id="suround-image-id" value="<?php echo absint( $meta['image_id'] ); ?>"/>
				<input type="button" id="suround-image-upload" class="button-secondary" value="<?php esc_attr_e( 'Upload', 'surround' ); ?>"/>
				<input type="button" id="suround-image-clear" class="button-secondary" value="<?php esc_attr_e( 'Clear', 'surround' ); ?>" style="display:<?php echo esc_attr( $display ); ?>"/>
			</p>

			<p class="description"><?php esc_html_e( 'Upload an image for this category', 'surround' ); ?></p>
		</div>

		<div class="form-field">
			<label class="layout-title"><?php esc_html_e( 'Image Size', 'surround' ); ?></label>
			<select name="suround[image_size]">
				<?php foreach ( $image_sizes as $key => $name ) : ?>
					<option value="<?php echo esc_attr($key) ?>" <?php selected( $key, $meta['image_size'] ); ?>>
						<?php echo wp_kses_post($name); ?>
					</option>
				<?php endforeach ?>
			</select>
		</div>

	<?php }
endif;

/**
 * Edit category meta
 *
 */

add_action( 'category_edit_form_fields', 'suround_category_edit_meta_fields', 10, 2 );

if ( !function_exists( 'suround_category_edit_meta_fields' ) ) :
	function suround_category_edit_meta_fields( $term ) {
		$meta = suround_get_category_meta( $term->term_id );
		$image_sizes = suround_get__sizes();
		$sidebar = suround_sidebar_position(true);
		$layouts = suround_get_category_layouts();
		$all_sidebars = suround_get_registered_sidebars(
			array( '' => esc_html('Default', 'surround' ) )
		);

		?>

		<tr class="form-field">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Layout options', 'surround' ); ?></label></th>
			<td>
				<label><input type="radio" name="suround[layout][type]" value="inherit" class="layout-type" <?php checked( $meta['layout']['type'], 'inherit' );?>> <?php esc_html_e( 'Inherit from global options', 'surround' ); ?></label><br>
				<label><input type="radio" name="suround[layout][type]" value="custom" class="layout-type" <?php checked( $meta['layout']['type'], 'custom' );?>> <?php esc_html_e( 'Set custom layout', 'surround' ); ?></label>
			</td>
		</tr>

		<tr class="form-field suround-layout-opt">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Layout', 'surround' ); ?></label></th>

			<td>
				<select class="layout-main" name="suround[layout][main]">
					<?php foreach ( $layouts as $key => $name ) : ?>
						<option value="<?php echo esc_attr($key) ?>" <?php selected( $key, $meta['layout']['main'] ); ?>><?php echo wp_kses_post($name); ?></option>
					<?php endforeach ?>
				</select>
			</td>
		</tr>

		<tr class="form-field suround-layout-opt suround-layout-grid-fullwidth">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Full Width', 'surround' ); ?></label></th>
			<td>
				<label><input type="radio" name="suround[layout][grid_fullwidth]" value="1" <?php checked( 1 , $meta['layout']['grid_fullwidth']); ?>><?php esc_html_e('Yes', 'surround'); ?></label>
				<label><input type="radio" name="suround[layout][grid_fullwidth]" value="0" <?php checked( 0 , $meta['layout']['grid_fullwidth']); ?>><?php esc_html_e('No', 'surround'); ?></label>
			</td>
		</tr>

		<tr class="form-field suround-layout-opt suround-layout-grid-columns">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Columns for grid layout', 'surround' ); ?></label></th>

			<td>
				<select name="suround[layout][columns]">
					<option <?php selected( 2, $meta['layout']['columns'] ); ?> value="2">2</option>
					<option <?php selected( 3, $meta['layout']['columns'] ); ?> value="3">3</option>
					<option <?php selected( 4, $meta['layout']['columns'] ); ?> value="4">4</option>
				</select>
			</td>
		</tr>

		<tr class="form-field suround-layout-opt">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Number of posts', 'surround' ); ?></label></th>
			<td>
				<input name="suround[layout][ppp]" type="text" class="suround-small-text" value="<?php echo esc_attr($meta['layout']['ppp']); ?>" />
			</td>
		</tr>

		<tr class="form-field suround-layout-opt suround-layout-grid-breadcrumbs">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Breadcrumbs', 'surround' ); ?></label></th>
			<td>
				<label><input type="radio" class="layout-breadcrumb"  name="suround[layout][breadcrumb]" value="1" <?php checked( 1 , $meta['layout']['breadcrumb']); ?>><?php esc_html_e('Show', 'surround'); ?></label>
				<label><input type="radio" class="layout-breadcrumb"  name="suround[layout][breadcrumb]" value="0" <?php checked( 0 , $meta['layout']['breadcrumb']); ?>><?php esc_html_e('Hide', 'surround'); ?></label>
			</td>
		</tr>

		<tr class="form-field suround-layout-opt suround-layout-breadcrumbs-position">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Position Breadcrumbs', 'surround' ); ?></label></th>
			<td>
				<label><input type="radio" name="suround[layout][position_breadcrumb]" value="after" <?php checked( 'after', $meta['layout']['position_breadcrumb']); ?>><?php esc_html_e('After header', 'surround'); ?></label>
				<label><input type="radio" name="suround[layout][position_breadcrumb]" value="before" <?php checked( 'before', $meta['layout']['position_breadcrumb']); ?>><?php esc_html_e('Before content', 'surround'); ?></label>
			</td>
		</tr>

		<tr class="form-field suround-layout-opt suround-layout-breadcrumbs-position">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Align Breadcrumbs', 'surround' ); ?></label></th>
			<td>
				<label><input type="radio" name="suround[layout][breadcrumb_align]" value="center" <?php checked( 'center', $meta['layout']['breadcrumb_align']); ?>><?php esc_html_e('Center', 'surround'); ?></label>
				<label><input type="radio" name="suround[layout][breadcrumb_align]" value="right" <?php checked( 'right', $meta['layout']['breadcrumb_align']); ?>><?php esc_html_e('Right (with overlay)', 'surround'); ?></label>
			</td>
		</tr>

		<tr class="form-field suround-layout-opt suround-layout-map-mode">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Map', 'surround' ); ?></label></th>
			<td>
				<label><input type="radio" name="suround[layout][map]" value="show" <?php checked( 'show' , $meta['layout']['map']); ?>><?php esc_html_e('Show', 'surround'); ?></label>
				<label><input type="radio" name="suround[layout][map]" value="hide" <?php checked( 'hide' , $meta['layout']['map']); ?>><?php esc_html_e('Hide', 'surround'); ?></label>
				<label><input type="radio" name="suround[layout][map]" value="no" <?php checked( 'no' , $meta['layout']['map']); ?>><?php esc_html_e('No', 'surround'); ?></label>
			</td>
		</tr>

		<tr class="form-field suround-layout-opt">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Filter', 'surround' ); ?></label></th>
			<td>
				<label><input type="radio" name="suround[layout][filter]" value="1" <?php checked( 1 , $meta['layout']['filter']); ?>><?php esc_html_e('Show', 'surround'); ?></label>
				<label><input type="radio" name="suround[layout][filter]" value="0" <?php checked( 0 , $meta['layout']['filter']); ?>><?php esc_html_e('Hide', 'surround'); ?></label>
			</td>
		</tr>

		<tr class="form-field suround-layout-opt">

			<th scope="row" valign="top"><label><?php esc_html_e( 'Order', 'surround' ); ?></label></th>

			<td>
				<label>
					<input type="radio" name="suround[layout][order]" value="date" <?php checked( 'date', $meta['layout']['order'] );?>>
					<?php esc_html_e('Latest Post', 'surround'); ?>
				</label>
				<label>
					<input type="radio" name="suround[layout][order]" value="comment_count" <?php checked( 'comment_count', $meta['layout']['order'] );?>>
					<?php esc_html_e('Most commented posts', 'surround'); ?>
				</label>
				<label>
					<input type="radio" name="suround[layout][order]" value="views" <?php checked( 'views', $meta['layout']['order'] );?>>
					<?php esc_html_e('Most viewed posts', 'surround'); ?>
				</label>
			</td>

		</tr>

		<tr class="form-field">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Sidebar options', 'surround' ); ?></label></th>

			<td>
				<label>
					<input type="radio" name="suround[sidebar][type]" value="inherit" class="layout-sidebar" <?php checked( $meta['sidebar']['type'], 'inherit' );?>> <?php esc_html_e( 'Inherit from global category sibebar options', 'surround' ); ?><br>
				</label>
				<label>
					<input type="radio" name="suround[sidebar][type]" value="custom" class="layout-sidebar" <?php checked( $meta['sidebar']['type'], 'custom' );?>> <?php esc_html_e( 'Set custom category sidebar options', 'surround' ); ?>
				</label>
			</td>

		</tr>

		<tr class="form-field suround-sidebar-opt">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Display sidebar', 'surround' ); ?></label></th>

			<td>
				<ul class="suround-img-select-wrap">
					<?php foreach ( $sidebar as $id => $layout ): ?>
						<li>
							<?php $selected_class = suround_compare( $id, $meta['sidebar']['use_sidebar'] ) ? ' selected': ''; ?>
							<img src="<?php echo esc_url($layout['img']); ?>" title="<?php echo esc_attr($layout['title']); ?>" class="suround-img-select<?php echo esc_attr( $selected_class ); ?>">
							<br/><span><?php echo esc_attr($layout['title']); ?></span>
							<input type="radio" class="suround-hidden suround-count-me" name="suround[sidebar][use_sidebar]" value="<?php echo esc_attr($id); ?>" <?php checked( $id, $meta['sidebar']['use_sidebar'] );?>/>
						</li>
					<?php endforeach; ?>
				</ul>
			</td>

		</tr>

		<tr class="form-field suround-sidebar-opt">

			<th scope="row" valign="top"><label><?php esc_html_e( 'Category standard sidebar', 'surround' ); ?></label></th>

			<td>
				<select name="suround[sidebar][standard_sidebar]" >
					<?php foreach ( $all_sidebars as $key => $name ) : ?>
						<option value="<?php echo esc_attr($key) ?>" <?php selected( $key, $meta['sidebar']['standard_sidebar'] ); ?>><?php echo wp_kses_post($name); ?></option>
					<?php endforeach ?>
				</select>
			</td>
		</tr>

		<tr class="form-field">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Image', 'surround' ); ?></label></th>
			<?php $display = $meta['image'] ? 'initial' : 'none'; ?>

			<td>
				<p>
					<img id="suround-image-preview" class="suround-image-preview" src="<?php echo esc_url( $meta['image'] ); ?>" style="display:<?php echo esc_attr( $display ); ?>;">
				</p>

				<p>
					<input type="hidden" name="suround[image]" id="suround-image-url" value="<?php echo esc_attr( $meta['image'] ); ?>"/>
					<input type="hidden" name="suround[image_id]" id="suround-image-id" value="<?php echo absint( $meta['image_id'] ); ?>"/>
					<input type="button" id="suround-image-upload" class="button-secondary" value="<?php esc_attr_e( 'Upload', 'surround' ); ?>"/>
					<input type="button" id="suround-image-clear" class="button-secondary" value="<?php esc_attr_e( 'Clear', 'surround' ); ?>" style="display:<?php echo esc_attr( $display ); ?>"/>
				</p>

				<p class="description"><?php esc_html_e( 'Upload an image for this category', 'surround' ); ?></p>
			</td>
		</tr>

		<tr class="form-field">

			<th scope="row" valign="top"><label><?php esc_html_e( 'Image Size', 'surround' ); ?></label></th>

			<td>
				<select name="suround[image_size]">
					<?php foreach ( $image_sizes as $key => $name ) : ?>
						<option value="<?php echo esc_attr($key) ?>" <?php selected( $key, $meta['image_size'] ); ?>><?php echo wp_kses_post($name); ?></option>
					<?php endforeach ?>
				</select>
			</td>

		</tr>

	<?php }
endif;
