<?php

if ( !function_exists( 'suround_compare' ) ):
	function suround_compare( $a, $b ) {
		return (string) $a === (string) $b;
	}
endif;

if ( !function_exists( 'suround_post_format_action' ) ):
	function suround_post_format_action( $format = 'video' ) {

		$icons = array(
			'video' => 'licon-play',
		);

		$icons = apply_filters( 'suround_post_format_actions', $icons );

		return '<span class="suround-format-action"><i class="'.esc_attr( $icons[$format] ).'"></i></span>';

	}
endif;

if ( !function_exists('suround_display_icon') ) {
	function suround_display_icon( $post_id, $attachment_id = null ) {

		$url = get_post_meta( $post_id, 'map-svg-icon', true );

		if ( !empty($url) && is_string($url) ) {

			global $wp_filesystem;

			if ( empty($wp_filesystem) ) {
				require_once(ABSPATH . '/wp-admin/includes/file.php');
				WP_Filesystem();
			}

			if ( substr($url, -4) === '.svg' ) {

				if ( !empty($attachment_id) ) {
					return $wp_filesystem->get_contents(get_attached_file($attachment_id));
				} elseif ( false !== ($svg_code = get_transient(md5($url))) ) {
					return $svg_code;
				} else {

					$svg_code = $wp_filesystem->get_contents($url);

					if ( !empty($svg_code) ) {
						set_transient(md5($url), $svg_code, 12 * HOUR_IN_SECONDS);
						return $svg_code;
					}

				}

			} else {
				return '';
			}

		} else { return ''; }
	}
}

if ( !function_exists( 'suround_get_data_properties' ) ):
	function suround_get_data_properties( $post_id ) {

		$features = $properties = array();
		$output = '';

		$output .= '<div class="entry-col">';
			$output .= '<div class="entry">';

			if ( '' !== get_the_post_thumbnail() ) {
				$output .= '<div class="thumbnail-attachment">';
				$output .= '<a href="'. get_the_permalink() .'" class="entry-overlink"></a>';
				$output .= suround_get_meta_actions();
				$output .= get_the_post_thumbnail($post_id, 'suround-315x210-center-center');
				$output .= '</div>';
			}

			$output .= '<div class="entry-body">';

				$output .= suround_get_category_list($post_id, false);

				$output .= '<h5 class="entry-title">';
					$output .= '<a href="' . get_the_permalink() . '">'. get_the_title() .'</a>';
				$output .= '</h5>';

				if ( $meta = suround_blog_post_meta( false, array( 'date', 'views', 'vote' ) ) ) {
					$output .= '<div class="entry-meta">' . wp_kses_post($meta) . '</div>';
				}

			$output .= '</div>';

			$output .= '</div>';
		$output .= '</div>';

		$features['properties'] = array(
			'title' => get_the_title($post_id),
			'imageUrl' => has_post_thumbnail() ? get_the_post_thumbnail_url($post_id, 'thumbnail') : '',
			'icon' => suround_display_icon($post_id),
			'html' => $output
		);

		$features['geometry']['coordinates'] = array(
			get_post_meta( $post_id, 'geolocation_long', true ),
			get_post_meta( $post_id, 'geolocation_lat', true )
		);

		return json_encode($features);

	}
endif;


/**
 * Get featured image
 *
 */

if ( !function_exists( 'suround_get_featured_image' ) ):
	function suround_get_featured_image( $size = 'large', $post_id = false ) {
		if ( empty( $post_id ) ) {
			$post_id = get_the_ID();
		}

		if ( has_post_thumbnail( $post_id ) ) {
			return get_the_post_thumbnail( $post_id, $size );
		}

		return false;
	}
endif;

if ( !function_exists( 'suround_get_post_attachment_image' ) ):
	function suround_get_post_attachment_image( $attachment_id, $dimensions = '', $crop = true ) {
		$img_src = wp_get_attachment_image_src( $attachment_id, $dimensions );
		$img_src = $img_src[0] ? $img_src[0] : '';
		return $img_src;
	}
endif;

if ( !function_exists( 'suround_get_post_featured_image' ) ):
	function suround_get_post_featured_image( $post_id = null, $dimensions = '', $crop = true ) {
		if ( ! $post_id ) {
			$post_id = get_the_ID();
		}
		$img_src = wp_get_attachment_image_src( get_post_thumbnail_id($post_id), $dimensions );
		$img_src = $img_src[0] ? $img_src[0] : '';
		return $img_src;
	}
endif;

if ( !function_exists( 'suround_get_the_thumbnail' ) ):
	function suround_get_the_thumbnail($attach_id, $dimensions, $crop = true, $thumbnail_atts = array(), $image_atts = array()) {
		$atts = '';
		$sizes = array_filter(explode("*", $dimensions));
		if (is_array($sizes) && !empty($sizes)) {
			$atts = "width={$sizes[0]} height={$sizes[1]}";
		}
		return '<img '. esc_attr($atts) .' src="' . suround_get_post_attachment_image($attach_id, $dimensions, $crop) . '" ' . suround_create_data_string($thumbnail_atts) . ' />';
	}
endif;

if ( !function_exists( 'suround_create_data_string' ) ):
	function suround_create_data_string( $data = array() ) {
		$data_string = "";

		if (empty($data)) return;

		foreach ($data as $key => $value) {
			if (is_array($value)) $value = implode(", ", $value);
			$data_string .= " data-$key='$value' ";
		}
		return $data_string;

	}
endif;

if ( !function_exists( 'suround_which_video_service' ) ):
	function suround_which_video_service( $video_url ) {
		$videos = array();
		$videoIdRegex = null;

		if (strpos($video_url, 'youtube.com/watch') !== false || strpos($video_url, 'youtu.be/') !== false) {
			preg_match("#(?<=v=)[a-zA-Z0-9-]+(?=&)|(?<=v\/)[^&\n]+|(?<=v=)[^&\n]+|(?<=youtu.be/)[^&\n]+#", $video_url, $matches);
			$video_id = $matches[0];

			if (!empty($video_id)) {
				$videos['ytid'] = trim($video_id);
				$videos['videoattributes'] = "version=3&amp;enablejsapi=1&amp;html5=1&amp;volume=100&amp;hd=1&amp;wmode=opaque&showinfo=0&ref=0;";
			}
		} elseif (strpos($video_url, 'vimeo.com') !== false) {

			if (strpos($video_url, 'player.vimeo.com') !== false) {
				$videoIdRegex = '/player.vimeo.com\/video\/([0-9]+)\??/i';
			} else { $videoIdRegex = '/vimeo.com\/([0-9]+)\??/i'; }

			if ($videoIdRegex !== null) {
				if (preg_match($videoIdRegex, $video_url, $results)) {
					$video_id = $results[1];
				}
				if (!empty($video_id)) {
					$videos['vimeoid'] = trim($video_id);
					$videos['videoattributes'] = "title=0&byline=0&portrait=0&api=1";
				}
			}

		} else {
			if (preg_match("/\.mp4$/", $video_url)) {
				$videos['videomp4'] = trim($video_url);
			} else if (preg_match("/\.ogv$/", $video_url)) {
				$videos['videoogv'] = trim($video_url);
			} else if (preg_match("/\.webm$/", $video_url)) {
				$videos['videowebm'] = trim($video_url);
			}
		}

		return suround_create_data_string($videos);
	}
endif;

if ( !function_exists( 'suround_hex2rgba' ) ):
	function suround_hex2rgba($color, $opacity = false) {

		$default = 'rgb(0,0,0)';

		//Return default if no color provided
		if(empty($color))
			return $default;

		//Sanitize $color if "#" is provided
		if ($color[0] == '#' ) {
			$color = substr( $color, 1 );
		}

		//Check if color has 6 or 3 characters and get values
		if (strlen($color) == 6) {
			$hex = array( $color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5] );
		} elseif ( strlen( $color ) == 3 ) {
			$hex = array( $color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2] );
		} else {
			return $default;
		}

		//Convert hexadec to rgb
		$rgb =  array_map('hexdec', $hex);

		//Check if opacity is set(rgba or rgb)
		if($opacity){
			if(abs($opacity) > 1)
				$opacity = 1.0;
			$output = 'rgba('.implode(",",$rgb).','.$opacity.')';
		} else {
			$output = 'rgb('.implode(",",$rgb).')';
		}

		//Return rgb(a) color string
		return $output;
	}
endif;


function suround_get_meta_option( $name, $fallback = '', array $data = array() ) {

	global $suround_settings;
	$current_object_id = get_queried_object_id();

	if ( isset( $suround_settings[ $name ] ) ) {
		return $suround_settings[ $name ];
	} elseif ( function_exists( 'rwmb_get_value' ) && $current_object_id ) {
		$current_object_value = rwmb_get_value( $name, null, $current_object_id );
		return ( is_null( $current_object_value ) || ( is_string( $current_object_value ) && ! strlen( $current_object_value ) ) || ( $current_object_value === false ) ) ? $fallback : $current_object_value;
	}

	return $fallback;
}

if ( ! function_exists( 'suround_get_meta' ) ) {

	function suround_get_meta( $name, $fallback = '' ) {

		$meta = get_post_meta( get_the_ID(), $name, true );

		if ( ! empty( $meta ) ) {
			return $meta;
		}

		return $fallback;

	}
}

if ( ! function_exists( 'suround_get_page_meta' ) ):
	function suround_get_page_meta( $post_id = false, $field = false ) {

		if ( empty( $post_id ) ) {
			$post_id = get_the_ID();
		}

		$defaults = array(
			'cover' => array(
				'layout'   => 'none',
				'content'  => '',
				'bg_image' => '',
				'limit'    => 5,
				'order'    => 'date',
				'sort'     => 'DESC',
				'format'   => 0,
				'title'    => esc_html__( 'Adventure Around the World', 'surround' )
			)
		);

		$meta = get_post_meta( $post_id, '_suround_meta', true );
		$meta = wp_parse_args( $meta, $defaults );

		if ( $field ) {
			if ( isset( $meta[ $field ] ) ) {
				return $meta[ $field ];
			} else {
				return false;
			}
		}

		return $meta;
	}
endif;


/**
 * Get image ID from URL
 *
 * It gets image/attachment ID based on URL
 */

if ( ! function_exists( 'suround_get_image_id_by_url' ) ):
	function suround_get_image_id_by_url( $image_url ) {
		global $wpdb;

		$attachment = $wpdb->get_col( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE guid='%s';", $image_url ) );

		if ( isset( $attachment[0] ) ) {
			return $attachment[0];
		}

		return false;
	}
endif;

/**
 * Get default cover data
 *
 */
if ( ! function_exists( 'suround_get_cover_post_data_for_saving' ) ):
	function suround_get_cover_post_data_for_saving( $append = array() ) {
		$default = array(
			'layout',
			'limit',
			'limit',
			'order',
			'sort',
			'format',
			'content',
			'bg_image',
			'title',
		);

		$data = suround_parse_args( $append, $default );

		return apply_filters( 'suround_modify_cover_post_data', $data );
	}
endif;

if ( ! function_exists( 'suround_parse_args' ) ):
	function suround_parse_args( &$a, $b ) {
		$a = (array) $a;
		$b = (array) $b;
		$r = $b;

		foreach ( $a as $k => &$v ) {
			if ( is_array( $v ) && isset( $r[ $k ] ) ) {
				$r[ $k ] = suround_parse_args( $v, $r[ $k ] );
			} else {
				$r[ $k ] = $v;
			}
		}

		return $r;
	}
endif;

if ( !function_exists( 'suround_get__sizes' ) ):
	function suround_get__sizes() {
		return array(
			'small' => esc_html__('Small', 'surround'),
			'middle' => esc_html__('Middle', 'surround'),
			'large' => esc_html__('Large', 'surround')
		);
	}
endif;


/**
 * Get the list of registered sidebars
 *
 */

if ( !function_exists( 'suround_get_registered_sidebars' ) ):
	function suround_get_registered_sidebars( $sidebars = array(), $exclude_footer_row = true, $exclude = array(
		'shop-widget-area'
	)) {

		global $wp_registered_sidebars;

		foreach ( $wp_registered_sidebars as $key => $sidebar ) {

			if ( $exclude_footer_row ) {

				if ( strpos($sidebar['id'], 'footer-row') === false ) {
					if ( !in_array($sidebar['id'], $exclude) ) {
						$sidebars[$sidebar['id']] = $sidebar['name'];
					}
				}

			} else {
				if ( !in_array($sidebar['id'], $exclude) ) {
					$sidebars[$sidebar['id']] = $sidebar['name'];
				}
			}

		}

		$sidebars = apply_filters('suround_modify_sidebars_list', $sidebars );
		return $sidebars;
	}
endif;

/**
 * Get category meta data
 *
 */

if ( ! function_exists( 'suround_get_category_meta' ) ):
	function suround_get_category_meta( $cat_id = false, $field = false ) {
		$defaults = array(
			'layout'     => array(
				'type'  => 'inherit',
				'main' => suround_get_option( 'category_layout' ),
				'columns' => suround_get_option( 'category_grid_columns' ),
				'order' => suround_get_option( 'category_order' ),
				'ppp' => suround_get_option( 'category_ppp_num' ),
				'grid_fullwidth' => suround_get_option( 'category_grid_fullwidth' ),
				'breadcrumb' => suround_get_option( 'category_breadcrumb' ),
				'position_breadcrumb' => suround_get_option( 'category_position_breadcrumb' ),
				'breadcrumb_align' => suround_get_option( 'category_breadcrumb_align' ),
				'map' => suround_get_option( 'category_map' ),
				'filter' => suround_get_option( 'category_filter' )
			),
			'sidebar' => array(
				'type' => 'inherit',
				'use_sidebar' => suround_get_option( 'category_use_sidebar' ),
				'standard_sidebar' => suround_get_option( 'category_sidebar' ),

			),
			'image_size' => 'small',
			'image'      => suround_get_option( 'default_img' ),
			'image_id' => ''
		);

		if ( $cat_id ) {
			$meta = get_term_meta( $cat_id, '_suround_meta', true );
			$meta = suround_parse_args($meta, $defaults );
		} else {
			$meta = $defaults;
		}

		if ( $field ) {
			if ( isset( $meta[ $field ] ) ) {
				return $meta[ $field ];
			} else {
				return false;
			}
		}

		return $meta;
	}
endif;


/**
 * Get serie meta data
 *
 * @param unknown $field specific option key
 * @return mixed meta data value or set of values
 * @since  1.5
 */

if ( !function_exists( 'suround_get_series_meta' ) ):
	function suround_get_series_meta( $serie_id = false, $field = false ) {
		$defaults = array(
			'image' => ''
		);

		if ( $serie_id ) {
			$meta = get_term_meta( $serie_id, '_suround_meta', true );
			$meta = suround_parse_args($meta, $defaults );
		} else {
			$meta = $defaults;
		}

		if ( $field ) {
			if ( isset( $meta[$field] ) ) {
				return $meta[$field];
			} else {
				return false;
			}
		}

		return $meta;
	}
endif;


/**
 * Detect WordPress template
 *
 */

if ( ! function_exists( 'suround_detect_template' ) ):
	function suround_detect_template() {

		if ( is_single() ) {

			$type = get_post_type();

			if ( in_array( $type, array( 'product' ) ) ) {
				$template = $type;
			} else {
				$template = 'single';
			}

		} else if ( is_page() ) {
			$template = 'page';
		} else if ( is_category() ) {
			$template = 'category';
		} else if ( is_tag() ) {
			$template = 'tag';
		} else if ( is_search() ) {
			$template = 'search';
		} else if ( is_author() ) {
			$template = 'author';
		} else if ( is_tax( 'series' ) ) {
			$template = 'series';
		} else if ( is_tax( 'product_cat' ) || is_tax( 'product_tag' ) || is_post_type_archive( 'product' ) ) {
			$template = 'product_archive';
		} else if ( is_archive() ) {
			$template = 'archive';
		} else {
			$template = 'archive';
		}

		return $template;
	}
endif;


/**
 * Get post layout
 *
 * It checks which posts layout to display based on current template options
 *
 */

if ( ! function_exists( 'suround_get_current_post_layout' ) ):
	function suround_get_current_post_layout() {

		$layout = 'classic'; //layout a as default

		$suround_template = suround_detect_template();

		if ( in_array( $suround_template, array( 'search', 'tag', 'author', 'archive' ) ) ) {
			$layout = suround_get_option( $suround_template . '_layout' );
		} else if ( $suround_template == 'category' ) {

			$obj  = get_queried_object();
			$meta = suround_get_category_meta( $obj->term_id );

			if ( $meta['layout']['type'] == 'inherit' ) {
				$layout = suround_get_option( $suround_template . '_layout' );
			} else {
				$layout = $meta['layout']['main'];
			}

		}

		return $layout;
	}
endif;

if ( ! function_exists( 'suround_post_count' ) ) {

	function suround_post_count( $button_map = false, $map_text = 'no' ) {

		global $wp_query;
 		$post_count = $wp_query->post_count; ?>

		<div class="pre-header-wrap">

			<span class="pre-post-count">
				<?php echo sprintf( _n( '%s article', '%s articles', $post_count, 'surround' ), number_format_i18n( $post_count ) ); ?>
			</span>

			<?php if ( $button_map ): ?>
				<a class="map-toggle" href="javascript:void(0)">
					<i class="licon-map2"></i>
					<span class="text-change">
						<?php if ( $map_text == 'show' ): ?>

							<?php esc_html_e('Hide', 'surround') ?>

						<?php elseif ( $map_text == 'hide' ): ?>

							<?php esc_html_e('Show', 'surround') ?>

						<?php endif; ?>
					</span>
					<?php esc_html_e('Map', 'surround') ?>
				</a>
			<?php endif; ?>

		</div><!--/ .pre-header-wrap-->

		<?php

	}

}

if ( ! function_exists( 'suround_sort_header' ) ) {

	function suround_sort_header( $active = 'classic', $button_map = false, $show = array('classic', 'list', 'grid'), $map_text = 'no' ) {
		global $wp_query;
		$post_count = $wp_query->post_count;
		?>

		<div class="sort-header-wrap">
			<div class="sort-view-type">

				<span class="sort-view-title">
					<?php echo sprintf( _n( '%s article', '%s articles', $post_count, 'surround' ), number_format_i18n( $post_count ) ); ?>
				</span>

				<?php if ( in_array('classic', $show) ): ?>

					<a href="javascript:void(0)" title="<?php esc_html_e( 'Classic View', 'surround' ) ?>"
					   data-sort-view="classic" <?php if ( $active == 'classic' ): ?>class="active" <?php endif; ?>></a>

				<?php endif; ?>

				<?php if ( in_array('list', $show) ): ?>

					<a href="javascript:void(0)" title="<?php esc_html_e( 'List View', 'surround' ) ?>" data-sort-view="list"
					   <?php if ( $active == 'list' ): ?>class="active" <?php endif; ?>></a>

				<?php endif; ?>

				<?php if ( in_array('grid', $show) ): ?>

					<a href="javascript:void(0)" title="<?php esc_html_e( 'Grid View', 'surround' ) ?>" data-sort-view="grid"
					   <?php if ( $active == 'grid' ): ?>class="active" <?php endif; ?>></a>

				<?php endif; ?>

			</div><!--/ .sort-view-type-->

			<?php if ( $button_map ): ?>
				<a class="map-toggle" href="javascript:void(0)">
					<i class="licon-map2"></i>
					<span class="text-change">
						<?php if ( $map_text == 'show' ): ?>

							<?php esc_html_e('Hide', 'surround') ?>

						<?php elseif ( $map_text == 'hide' ): ?>

							<?php esc_html_e('Show', 'surround') ?>

						<?php endif; ?>
					</span>
					<?php esc_html_e('Map', 'surround') ?>
				</a>
			<?php endif; ?>

		</div><!--/ .sort-header-wrap-->
		<?php
	}

}

if ( ! function_exists( 'suround_get_terms_as_array' ) ) {
	function suround_get_terms_as_array( $taxonomy = 'category' ) {
		$terms_formatted = array();
		$terms           = get_terms( $taxonomy );

		if ( ! is_wp_error( $terms ) && is_array( $terms ) && count( $terms ) ) {
			foreach ( $terms as $term ) {
				$terms_formatted[ $term->slug ] = $term->name;
			}
		}

		return $terms_formatted;
	}
}

if ( ! function_exists( 'suround_get_posts_as_array' ) ) {
	function suround_get_posts_as_array( $post_type = 'post' ) {

		global $post;
		$posts_formatted = array();

		$posts = get_posts( array(
			'post_type'   => $post_type,
			'numberposts' => - 1
		) );

		if ( ! is_wp_error( $posts ) && is_array( $posts ) && count( $posts ) ) {
			foreach ( $posts as $post ) {
				setup_postdata( $post );
				$posts_formatted[ $post->ID ] = $post->post_title;
			}
		}

		return $posts_formatted;
	}
}

/**
 * Get featured area query
 *
 */

if ( ! function_exists( 'suround_get_cover_area_query' ) ):
	function suround_get_cover_area_query( $data ) {

		$args['ignore_sticky_posts'] = 1;
		$args['post_type']           = 'post';
		$args['posts_per_page']      = absint( $data['posts_per_page'] );

		if ( ! empty( $data['categories'] ) ) {
			$args['tax_query'][] = array(
				'taxonomy'         => 'category',
				'field'            => 'slug',
				'terms'            => $data['categories'],
				'operator'         => 'IN',
				'include_children' => true
			);
		}

		if ( ! empty( $data['tags'] ) ) {
			$args['tax_query'][] = array(
				'taxonomy'         => 'post_tag',
				'field'            => 'slug',
				'terms'            => $data['tags'],
				'operator'         => 'IN',
				'include_children' => true
			);
		}

		if ( ! empty( $data['posts_in'] ) ) {
			$args['post__in'] = $data['posts_in'];
		}

		if ( ! empty( $data['posts_out'] ) ) {
			$args['post__not_in'] = $data['posts_out'];
		}

		$args['orderby'] = $data['order_by'];
		$args['order']   = $data['order'];

		if ( $args['orderby'] == 'views' && function_exists( 'ev_get_meta_key' ) ) {
			$args['orderby']  = 'meta_value_num';
			$args['meta_key'] = ev_get_meta_key();
		}

		if ( $args['orderby'] == 'title' ) {
			$args['order'] = 'ASC';
		}

		$args = apply_filters( 'suround_modify_posts_query_args', $args );

		$query = new WP_Query( $args );

		return $query;

	}
endif;

/**
 * Get the list of available options for post ordering
 *
 */

if ( ! function_exists( 'suround_get_post_order' ) ) :
	function suround_get_post_order() {

		$options = array(
			'date'          => esc_html__( 'Date', 'surround' ),
			'comment_count' => esc_html__( 'Number of comments', 'surround' ),
			'views'         => esc_html__( 'Number of views', 'surround' ),
			'title'         => esc_html__( 'Title (alphabetically)', 'surround' ),
			'rand'          => esc_html__( 'Random', 'surround' ),
		);

		$options = apply_filters( 'suround_modify_post_order', $options );

		return $options;
	}
endif;

/**
 * Get the list of available options to filter posts by format
 *
 */

if ( ! function_exists( 'suround_get_post_formats' ) ) :
	function suround_get_post_formats() {

		$options             = array();
		$options['standard'] = esc_html__( 'Standard', 'surround' );

		$formats = get_theme_support( 'post-formats' );
		if ( ! empty( $formats ) && is_array( $formats[0] ) ) {
			foreach ( $formats[0] as $format ) {
				$options[ $format ] = ucfirst( $format );
			}
		}

		$options['0'] = esc_html__( 'All', 'surround' );

		$options = apply_filters( 'suround_modify_post_formats', $options );

		return $options;
	}
endif;







