<?php

/**
 * Save series meta
 *
 * Callback function to save category meta data
 */

add_action( 'edited_series', 'suround_save_series_meta_fields', 10, 2 );
add_action( 'create_series', 'suround_save_series_meta_fields', 10, 2 );

if ( !function_exists( 'suround_save_series_meta_fields' ) ) :
	function suround_save_series_meta_fields( $term_id ) {

		global $pagenow;

		if ( !in_array( $pagenow, array('post.php', 'post-new.php') ) && isset( $_POST['surround'] ) ) {

			$meta = array();

			if ( isset( $_POST['surround']['image'] ) ) {
				$meta['image'] = $_POST['surround']['image'];
			}

			if ( ! empty( $meta ) ) {
				update_term_meta( $term_id, '_suround_meta', $meta );
			} else {
				delete_term_meta( $term_id, '_suround_meta' );
			}

		}

	}
endif;

/**
 * Add series meta
 *
 * Callback function to load series meta fields on "new series" screen
 *
 * @since  1.0
 */

add_action( 'series_add_form_fields', 'suround_series_add_meta_fields', 10, 2 );

if( !function_exists('suround_series_add_meta_fields') )	:
	function suround_series_add_meta_fields() {
		$meta = suround_get_series_meta();
		?>

		<div class="form-field">
			<label class="layout-title"><?php esc_html_e( 'Image', 'surround' ); ?></label>
			<?php $display = $meta['image'] ? 'initial' : 'none'; ?>
			<p>
				<img id="suround-image-preview" class="suround-image-preview" src="<?php echo esc_url( $meta['image'] ); ?>" style="display:<?php echo esc_attr( $display ); ?>;">
			</p>

			<p>
				<input type="hidden" name="suround[image]" id="suround-image-url" value="<?php echo esc_attr( $meta['image'] ); ?>"/>
				<input type="button" id="suround-image-upload" class="button-secondary" value="<?php esc_attr_e( 'Upload', 'surround' ); ?>"/>
				<input type="button" id="suround-image-clear" class="button-secondary" value="<?php esc_attr_e( 'Clear', 'surround' ); ?>" style="display:<?php echo esc_attr( $display ); ?>"/>
			</p>

			<p class="description"><?php esc_html_e( 'Upload an image for this serie', 'surround' ); ?></p>
		</div>

	<?php }
endif;

/**
 * Edit series meta
 *
 */

add_action( 'series_edit_form_fields', 'suround_series_edit_meta_fields', 10, 2 );

if ( !function_exists( 'suround_series_edit_meta_fields' ) ) :
	function suround_series_edit_meta_fields( $term ) {
		$meta = suround_get_series_meta( $term->term_id );
		?>

		<tr class="form-field">
			<th scope="row" valign="top"><label><?php esc_html_e( 'Image', 'surround' ); ?></label></th>
			<?php $display = $meta['image'] ? 'initial' : 'none'; ?>
			<td>
				<p>
					<img id="suround-image-preview" class="suround-image-preview" src="<?php echo esc_url( $meta['image'] ); ?>" style="display:<?php echo esc_attr( $display ); ?>;">
				</p>

				<p>
					<input type="hidden" name="suround[image]" id="suround-image-url" value="<?php echo esc_attr( $meta['image'] ); ?>"/>
					<input type="button" id="suround-image-upload" class="button-secondary" value="<?php esc_attr_e( 'Upload', 'surround' ); ?>"/>
					<input type="button" id="suround-image-clear" class="button-secondary" value="<?php esc_attr_e( 'Clear', 'surround' ); ?>" style="display:<?php echo esc_attr( $display ); ?>"/>
				</p>

				<p class="description"><?php esc_html_e( 'Upload an image for this serie', 'surround' ); ?></p>
			</td>
		</tr>

	<?php }
endif;
