<?php
/**
 * This file represents an example of the code that themes would use to register
 * the required vendors.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @see http://tgmpluginactivation.com/configuration/ for detailed documentation.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.6.1 for parent theme Suround for publication on ThemeForest
 * @author     Thomas Griffin, Gary Jones, Juliette Reinders Folmer
 * @copyright  Copyright (c) 2011, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/TGMPA/TGM-Plugin-Activation
 */

/**
 * Include the TGM_Plugin_Activation class.
 */

add_action( 'tgmpa_register', 'suround_register_required_plugins' );

if ( !function_exists('suround_added_admin_action') ) {

	function suround_added_admin_action() {
		add_action( 'admin_enqueue_scripts', 'suround_added_plugin_style' );
	}

	function suround_added_plugin_style() {
		wp_enqueue_style( 'suround-admin-vendors', get_theme_file_uri('css/admin-plugin.css'), array() );
	}

	add_action( 'load-vendors.php', 'suround_added_admin_action', 1 );

}
/**
 * Register the required vendors for this theme.
 *
 * In this example, we register two vendors - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function suround_register_required_plugins() {

	/**
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */

	global $Suround;
	$theme_plugins = $Suround->getRequiredThemePlugins();

	$plugins = array_merge($theme_plugins, array(
		array(
			'name'     => 'Redux Framework',
			'slug'     => 'redux-framework',
			'required' => false
		),
		array(
			'name'     => 'Woocommerce',
			'slug'     => 'woocommerce',
			'required' => false
		),
		array(
			'name'      => esc_html__('Meta Box', 'surround' ),
			'slug'      => 'meta-box',
			'required'  => true
		),
		array(
			'name'      => esc_html__('Breadcrumb NavXT', 'surround'),
			'slug'      => 'breadcrumb-navxt',
			'required'  => true
		),
		array(
			'name'     => esc_html__('Contact Form 7', 'surround' ),
			'slug'     => 'contact-form-7',
			'required' => false
		),
		array(
			'name'     => esc_html__('Smash Balloon Instagram Feed', 'surround' ),
			'slug'     => 'instagram-feed',
			'required' => false
		),
		array(
			'name' => esc_html__('MailPoet emails and newsletters in WordPress', 'surround' ),
			'slug' => 'mailpoet',
			'required' => false
		),
		array(
			'name' => esc_html__('WP Google Street View Shortcode', 'surround' ),
			'slug' => 'wp-google-street-view-shortcode',
			'required' => false
		),
	));

	/**
	 * Array of configuration settings. Amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * leave the strings uncommented.
	 * Some of the strings are added into a sprintf, so see the comments at the
	 * end of each line for what each argument will be.
	 */
	$config = array(
		'domain'       => 'surround', // Text domain - likely want to be the same as your theme.
		'id'           => 'surround',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '', // Default absolute path to bundled vendors.
		'menu'         => 'install-required-vendors',
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => true,                   // Automatically activate vendors after installation or not.
		'message'      => ''
	);

	tgmpa( $plugins, $config );

}