<?php

/**
 * Custom Suround template tags
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package WordPress
 * @since Suround 1.0
 */

if ( !function_exists( 'suround_logo' ) ) {

	function suround_logo() {
		global $suround_settings, $suround_config;

		switch ( $suround_config['header_style'] ) {
			case 'style-1':
			case 'style-2':
			case 'style-3':
			case 'style-4':
				$logo = $suround_settings['logo']['url'];
				$logo_hidpi = $suround_settings['logo_hidpi']['url'];
				break;
			case 'style-5':
			case 'style-6':
				$logo = $suround_settings['logo_header_5']['url'];
				$logo_hidpi = $suround_settings['logo_header_5_hidpi']['url'];
				break;
			default:
				$logo = $suround_settings['logo']['url'];
				$logo_hidpi = $suround_settings['logo_hidpi']['url'];
				break;
		}

		ob_start();

		if ( !$logo ): ?>

			<h4 class="logo"><?php else : ?><?php endif; ?>

		<a class="logo" href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?> - <?php bloginfo( 'description' ); ?>" rel="home">
			<?php if ( $logo ) {
				echo '<img class="standard-logo" src="' . esc_url(str_replace( array( 'http:', 'https:' ), '', $logo)) . '" srcset="'. esc_url( str_replace( array( 'http:', 'https:' ), '', $logo_hidpi ) ) .' 2x" alt="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '" />';
			} else {
				bloginfo( 'name' );
			} ?>
		</a>

		<?php if ( !$logo ) : ?></h4><?php else : ?><?php endif;

		return apply_filters( 'suround_logo', ob_get_clean() );
	}

}

if ( !function_exists( 'suround_get_option' ) ):
	function suround_get_option( $option ) {

		global $suround_settings;

		if ( empty( $suround_settings ) ) {
			$suround_settings = suround_check_theme_options();
		}

		if ( isset( $suround_settings[$option] ) ) {
			return is_array( $suround_settings[$option] ) && isset( $suround_settings[$option]['url'] ) ? $suround_settings[$option]['url'] : $suround_settings[$option];
		} else {
			return false;
		}

	}
endif;

if ( !function_exists( 'suround_main_navigation' ) ) {
	function suround_main_navigation( $theme_location = 'primary', $menu_class = '' ) {

		if ( is_array($menu_class) ) {
			$menu_class = implode(" ", $menu_class);
		}

		$defaults = array(
			'container' => 'ul',
			'menu_class' => $menu_class,
			'theme_location' => $theme_location,
			'fallback_cb' => false,
			'walker' => new suround_primary_navwalker
		);

		if ( has_nav_menu($theme_location) ) {
			wp_nav_menu( $defaults );
		} else {
			echo '<ul id="menu" class="clearfix">';
			wp_list_pages('title_li=');
			echo '</ul>';
		}

	}

}

if ( !function_exists( 'suround_mobile_menu' ) ) {
	function suround_mobile_menu( $args = array() ) {
		ob_start();

		$defaults = array(
			'container' => '',
			'menu_class' => 'menu__level',
			'theme_location' => 'primary',
			'fallback_cb' => false,
			'before' => '',
			'after' => '',
			'link_before' => '',
			'link_after' => '',
			'depth' => 1
		);

		$args = wp_parse_args($args, $defaults);

		if ( has_nav_menu('primary') ) {
			suround_wp_nav_menu( $args );
		} else {
			echo '<ul class="mobile-advanced">';
			wp_list_pages('title_li=');
			echo '</ul>';
		}

		$output = str_replace( '&nbsp;', '', ob_get_clean() );
		return apply_filters( 'suround_mobile_menu', $output );
	}
}


if ( ! function_exists('suround_excerpt') ) :
	/**
	 * Displays the optional excerpt.
	 *
	 * Wraps the excerpt in a div element.
	 *
	 * Create your own twentysixteen_excerpt() function to override in a child theme.
	 *
	 * @subpackage Suround
	 *
	 * @param string $class Optional. Class string of the div element. Defaults to 'entry-summary'.
	 */
	function suround_excerpt($class = 'entry-summary' ) {
		$class = esc_attr( $class );

		if ( has_excerpt() || is_search() ) : ?>
			<div class="<?php echo sanitize_html_class($class); ?>">
				<?php the_excerpt(); ?>
			</div><!-- .<?php echo sanitize_html_class($class); ?> -->
		<?php endif;
	}
endif;

if ( ! function_exists('suround_post_thumbnail') ) :
	function suround_post_thumbnail($size = 'post-thumbnail' ) {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>

			<div class="entry-thumb">
				<?php the_post_thumbnail($size); ?>
			</div>

		<?php else : ?>

			<a class="entry-thumb" href="<?php the_permalink(); ?>" aria-hidden="true">
				<?php the_post_thumbnail( 'post-thumbnail', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
			</a>

		<?php endif; // End is_singular()
	}
endif;


if ( ! function_exists('suround_comments_link') ) :

	function suround_comments_link($id = false, $comments_without_text = false, $echo = false, $zero = false, $one = false, $more = false, $css_class = 'entry-comments-link' ) {
		$number = get_comments_number( $id );

		if ( post_password_required() ) {
			esc_html_e( 'Enter your password to view comments.', 'surround' );
			return;
		}

		$output = '<div class="entry-comments"><a href="';
		$output .= apply_filters( 'suround_respond_link', get_permalink($id) . '#respond', $id );
		$output .= '"';

		if ( !empty( $css_class ) ) {
			$output .= ' class="'. $css_class .'" ';
		}

		$output .= '><i class="licon-bubble"></i>';

		if ( false === $more ) {

			if ( $comments_without_text ) {
				$output .= sprintf( '%s', number_format_i18n( $number ) );
			} else {
				$output .= sprintf( _n( '%s Comment', '%s Comments', $number, 'surround' ), number_format_i18n( $number ) );
			}

		} else {
			// % Comments
			/* translators: If comment number in your language requires declension,
			 * translate this to 'on'. Do not translate into your own language.
			 */
			if ( 'on' === _x( 'off', 'Comment number declension: on or off', 'surround' ) ) {
				$text = preg_replace( '#<span class="screen-reader-text">.+?</span>#', '', $more );
				$text = preg_replace( '/&.+?;/', '', $text ); // Kill entities
				$text = trim( strip_tags( $text ), '% ' );

				// Replace '% Comments' with a proper plural form
				if ( $text && ! preg_match( '/[0-9]+/', $text ) && false !== strpos( $more, '%' ) ) {
					/* translators: %s: number of comments */
					$new_text = _n( '%s Comment', '%s Comments', $number, 'surround' );
					$new_text = trim( sprintf( $new_text, '' ) );

					$more = str_replace( $text, $new_text, $more );
					if ( false === strpos( $more, '%' ) ) {
						$more = '% ' . $more;
					}
				}
			}

			$output .= str_replace( '%', number_format_i18n( $number ), $more );
		}

		$output .= '</a></div>';

		if ( $echo ) {
			echo wp_kses_post($output);
		} else {
			return $output;
		}

	}
endif;

if ( ! function_exists('suround_get_excerpt') ) :
	/**
	 * Displays the get excerpt.
	 *
	 */
	function suround_get_excerpt($post_content, $limit = 120 ) {
		if ( empty($post_content) ) return '';

		$content = suround_string_truncate( $post_content, $limit, ' ', "...", true, '' );
		$content = apply_filters( 'the_excerpt', $content );
		$content = do_shortcode($content);
		return '<div class="entry-excerpt">'. $content .'</div>';
	}
endif;

if ( ! function_exists('suround_get_title_excerpt') ) :
	/**
	 * Displays the get excerpt for title.
	 *
	 */
	function suround_get_title_excerpt($title, $limit = 120 ) {
		if ( empty($title) ) return '';

		$content = suround_string_truncate( $title, $limit, ' ', "...", true, '' );
		$content = apply_filters( 'the_title', $content );
		return $content;
	}
endif;


if ( ! function_exists('suround_get_search_excerpt') ) :
	/**
	 * Displays the get excerpt for search.
	 *
	 */
	function suround_get_search_excerpt($limit = 150, $more_link = true ) {

		if ( !$limit ) { $limit = 45; }

		if ( has_excerpt() ) {
			$content = strip_tags( strip_shortcodes(get_the_excerpt()) );
		} else {
			$content = strip_tags( strip_shortcodes(get_the_content()) );
		}

		$content = explode(' ', $content, $limit);

		if ( count($content) >= $limit ) {
			array_pop($content);
			if ($more_link)
				$content = implode(" ",$content).'... ';
			else
				$content = implode(" ",$content).' [...]';
		} else {
			$content = implode(" ",$content);
		}

		$content = apply_filters('the_content', $content);
		$content = do_shortcode($content);
		return $content;
	}
endif;

if ( ! function_exists('suround_format_date') ) {
	/**
	 * Formatted Date
	 *
	 * Returns formatted date
	 *
	 * @return string
	 */
	function suround_format_date($date, $display_time = false, $date_format = '' ) {

		$date = strtotime( $date );

		if ( $date_format ) {
			$format = $date_format;
		} else {
			$format = get_option( 'date_format' );
		}

		$date = date_i18n( $format, $date );

		return apply_filters( 'suround_formatted_date', $date, $display_time, $date_format );

	};
}

if ( !function_exists('suround_get_term_meta') ) {
	function suround_get_term_meta($term, $term_id = null, $is_tax = true ) {

		if ( function_exists('get_term_meta') ) {
			return get_term_meta( $term_id, $term, true );
		}

		return false;
	}
}

if ( !function_exists('suround_classes_output') ) {
	function suround_classes_output($classes) {
		$output_classes = '';

		if ( !empty($classes) && is_array($classes) ) {
			return implode( ' ', array_filter(array_values($classes)) );
		}

		return $output_classes;
	}
}



if ( ! function_exists( 'suround_side_widget_area' ) ):
	function suround_side_widget_area() {

		if ( is_active_sidebar( 'side-widget-area' ) ): ?>

			<div class="navbar-wrap">

				<div class="wrap-bg"></div>

				<div id="navbar-menu" class="navbar-menu">

					<button type="button" id="navbar-close" class="nav-bttn close-bttn"></button>

					<div class="nav-inner">
						<?php dynamic_sidebar( 'side-widget-area' ); ?>
					</div>

				</div>
			</div>

		<?php endif;

	}
endif;

if ( ! function_exists( 'suround_get_sort_class' ) ):
function suround_get_sort_class( $id ) {
	$classes = "";
	$item_tags = get_the_terms( $id, 'post_tag' );
	if ( is_object($item_tags) || is_array($item_tags) ) {
		foreach ( $item_tags as $tag ) {
			$classes .= $tag->slug . ' ';
		}
	}
	return str_replace( '%', '', $classes );
}
endif;

if ( ! function_exists( 'suround_output_sort_links' ) ):
	function suround_output_sort_links( $entries, $prefix = 'grid', $title = false ) {

		$tags = get_tags(array(
			'hide_empty'=> 0
		));
		$current_tags = array();
		$display_tags = array();

		foreach ( $entries as $entry ) {
			if ( $current_item_tags = get_the_terms( $entry->ID, 'post_tag' ) ) {
				if ( !empty($current_item_tags) ) {
					foreach ( $current_item_tags as $current_item_tag ) {
						if ( empty($display_tags) || in_array($current_item_tag->term_id, $display_tags) ) {
							$current_tags[$current_item_tag->term_id] = $current_item_tag->term_id;
						}
					}
				}
			}
		}

		ob_start(); ?>

		<?php if ( !empty($current_tags) ): ?>

			<div class="isotope-cont">

				<?php if ( $title ): ?>

					<div class="side-map-cat-title">
						<?php single_cat_title( '', true ); ?>
					</div>

				<?php endif; ?>

				<!-- - - - - - - - - - - - - - Filter - - - - - - - - - - - - - - - - -->

				<nav id="<?php echo esc_attr($prefix) ?>-filter" class="isotope-nav">
					<ul>
						<li><a href="javascript:void(0)" class="active" data-filter="*"><?php esc_html_e('All', 'surround') ?></a></li>

						<?php foreach ( $tags as $tag ): ?>
							<?php if ( in_array($tag->term_id, $current_tags) ): ?>
								<?php $nicename = str_replace('%', '', $tag->slug); ?>
								<li><a href="javascript:void(0)" data-filter=".<?php echo esc_attr($nicename) ?>"><?php echo esc_html(trim($tag->name)); ?></a></li>
							<?php endif; ?>

						<?php endforeach ?>
					</ul>
				</nav>

				<!-- - - - - - - - - - - - - - End of Filter - - - - - - - - - - - - - - - - -->

			</div>

		<?php endif; ?>

		<?php return ob_get_clean();
	}
endif;

/* 	Pagination
/* ---------------------------------------------------------------------- */

if ( ! function_exists( 'suround_paging_nav' ) ) {
	/**
	 * Display navigation to next/previous set of posts when applicable.
	 */
	function suround_paging_nav() {

		$args = array(
			'screen_reader_text' => '',
			'type'      => 'list',
			'next_text' => '',
			'prev_text' => '',
		);

		the_posts_pagination( $args );
	}
}


if( !function_exists('suround_pagination') ) {

	function suround_pagination($entries = '', $args = array(), $range = 10 ) {

		global $wp_query;

		$paged = (get_query_var('paged')) ? get_query_var('paged') : false;

		if ( $paged === false ) $paged = (get_query_var('page')) ? get_query_var('page') : false;
		if ( $paged === false ) $paged = 1;

		if ( $entries == '' ) {

			if ( isset( $wp_query->max_num_pages ) )
				$pages = $wp_query->max_num_pages;

			if( !$pages )
				$pages = 1;

		} else {
			$pages = $entries->max_num_pages;
		}

		if ( 1 != $pages ) { ob_start(); ?>

			<div class="page-nav">

				<ul class="pagination">

					<?php if( $paged > 1 ):  ?>
						<li><a class='prev-page' href='<?php echo esc_url(get_pagenum_link( $paged - 1 )) ?>'><span><?php esc_html_e('Previous', 'surround' ) ?></span></a></li>
					<?php endif; ?>

					<?php for( $i=1; $i <= $pages; $i++ ): ?>
						<?php if ( 1 != $pages &&( !( $i >= $paged + $range + 1 || $i <= $paged - $range - 1 ) || $pages <= $range ) ): ?>
							<?php $class = ( $paged == $i ) ? " active" : ''; ?>
							<li class="<?php echo sanitize_html_class($class) ?>"><a class="page-numbers" href='<?php echo esc_url(get_pagenum_link( $i )) ?>'><?php echo esc_html($i) ?></a></li>
						<?php endif; ?>
					<?php endfor; ?>

					<?php if ( $paged < $pages ):  ?>
						<li><a class='next-page' href='<?php echo esc_url(get_pagenum_link( $paged + 1 )) ?>'><span><?php esc_html_e('Next', 'surround' ) ?></span></a></li>
					<?php endif; ?>

				</ul>

			</div>

			<?php return ob_get_clean(); }
	}
}

if ( ! function_exists( 'suround_extract_youtube_id' ) ):
	function suround_extract_youtube_id( $url ) {
		parse_str( parse_url( $url, PHP_URL_QUERY ), $vars );

		if ( ! isset( $vars['v'] ) ) {
			return '';
		}

		return $vars['v'];
	}
endif;

if ( ! function_exists( 'suround_get_link_bookmark' ) ):
	function suround_get_link_bookmark() {

		if ( suround_in_watch_later( get_the_ID() ) ) {
			$action       = 'remove';
			$add_class    = 'add hidden';
		} else {
			$action       = 'add';
			$add_class    = 'add';
		}

		$meta = '<a class="entry-link-bookmark '.esc_attr( $add_class ).'" href="javascript:void(0);" data-id="' . esc_attr( get_the_ID() ) . '" data-action="' . esc_attr( $action ) . '"><i class="licon-bookmark2"></i>'. esc_html__('Add to Bookmarks', 'surround').'</a>';

		return wp_kses_post($meta);

	}
endif;

if ( ! function_exists( 'suround_get_cover_street_view' ) ):
	function suround_get_cover_street_view( $post_id = null ) {
		if ( $post_id === null ) { $post_id = suround_post_id(); }
		$geolocation_lat  = get_post_meta( $post_id, 'geolocation_lat', true );
		$geolocation_long = get_post_meta( $post_id, 'geolocation_long', true );
		?>
		<?php if ( $geolocation_lat && $geolocation_long ): ?>
			<?php echo do_shortcode('[streetview view="embed" width="100%" height="560" lat="'. $geolocation_lat . '" lng="'. $geolocation_long . '"][/streetview]'); ?>
		<?php endif;
	}
endif;

if ( ! function_exists( 'suround_get_cover_image_with_title' ) ):
	function suround_get_cover_image_with_title() {

		$attributes = array(); $bg_image = '';

		if ( has_post_thumbnail() ) {
			$bg_image = suround_get_post_featured_image();
		}

		if ( !empty($bg_image) ) {
			$style_bg_image = 'background-image: url('. $bg_image .')';
			$attributes[] = 'style="'. $style_bg_image. '"';
		}
		?>

		<div class="entry-cover-holder" <?php echo implode(' ', $attributes) ?>>

			<div <?php post_class('entry') ?>>

				<div class="entry-body">

					<?php echo suround_get_category_list() ?>

					<h1 class="entry-title"><?php the_title() ?></h1>

					<?php if ( $meta = suround_blog_post_meta( false, array( 'date', 'views', 'vote', 'comments' ) ) ) : ?>
						<div class="entry-meta"><?php echo wp_kses_post($meta); ?></div>
					<?php endif; ?>

				</div><!--/ .entry-body-->

			</div><!--/ .entry-->

		</div>

		<?php
	}
endif;


if ( ! function_exists( 'suround_get_cover_video' ) ):
	function suround_get_cover_video($video_url) {

		$attributes = array(); $bg_image = '';

		if ( has_post_thumbnail() ) {
			$bg_image = suround_get_post_featured_image();
		}

		if ( !empty($bg_image) ) {
			$style_bg_image = 'background-image: url('. $bg_image .')';
			$attributes[] = 'style="'. $style_bg_image. '"';
		}

		?>
		<div class="suround-cover-bg" <?php echo implode(' ', $attributes) ?>>

			<a class="suround-video-cover"
			   href="javascript: void(0);"
			   data-action="video"
			   data-id="<?php echo esc_attr(get_the_ID()); ?>">
				<?php echo suround_post_format_action(); ?>
			</a>

			<?php echo '<div class="suround-video-content"><div id="suround-player-cover" data-youtube-video-id="'. esc_attr(suround_extract_youtube_id($video_url)) .'"></div></div>'; ?>

		</div>
		<?php
	}
endif;

if ( ! function_exists( 'suround_get_fixed_popup_video' ) ):
	function suround_get_fixed_popup_video($video_url) {
		echo '<div id="suround-fixed-popup-video"><button class="item-close"></button><div class="responsive-iframe"><div id="suround-player-popup" data-youtube-video-id="'. esc_attr(suround_extract_youtube_id($video_url)) .'"></div></div></div>';
	}
endif;


if ( ! function_exists( 'suround_get_featured_gallery' ) ):
	function suround_get_featured_gallery( $gallery, $items = 1, $size = 'suround-1040x600-center-center' ) {

		if ( empty($gallery) ) return; ?>

		<div class="entry-featured-gallery">

			<div class="owl-carousel owl-nav__big--white" data-max-items="<?php echo esc_attr($items) ?>" data-autoplay="true" data-nav="true">

				<?php foreach( $gallery as $item ): ?>
					<div class="item">
						<img src="<?php echo suround_get_post_attachment_image( $item, $size ) ?>" alt="<?php the_title() ?>">
					</div>
				<?php endforeach; ?>

			</div>

		</div>

		<?php
	}
endif;

if ( ! function_exists( 'suround_get_featured_carousel' ) ):
	function suround_get_featured_carousel($gallery) {

		if ( empty($gallery) ) return; ?>

		<div class="entry-featured-gallery">

			<div class="owl-carousel owl-nav__big--white" data-max-items="1" data-autoplay="true" data-nav="true">

				<?php foreach( $gallery as $item ): ?>
					<div class="item">
						<img src="<?php echo suround_get_post_attachment_image( $item, 'suround-1040x600-center-center' ) ?>" alt="<?php the_title() ?>">
					</div>
				<?php endforeach; ?>

			</div>

		</div>

		<?php
	}
endif;


if ( ! function_exists( 'suround_get_meta_actions' ) ):
	function suround_get_meta_actions() {

		$meta_data = array(
			'video-mode',
			'watch-later'
		);

		$output = '';
		$meta = '';

		foreach ( $meta_data as $mkey ) {

			switch ( $mkey ) {

				case 'video-mode':

					$video = suround_media_grabber();

					if ( !empty($video) ) {
						$meta .= '<a class="entry-link-video" href="javascript:void(0);" data-id="'. esc_attr( get_the_ID() ) .'" data-action="suround_popup_video"></a>';
					}

					break;

				case 'watch-later':

					if ( suround_in_watch_later( get_the_ID() ) ) {
						$action       = 'remove';
						$add_class    = 'add hidden';
					} else {
						$action       = 'add';
						$add_class    = 'add';
					}

					$meta .= '<a class="entry-link-bookmark '.esc_attr( $add_class ).'" href="javascript:void(0);" data-id="' . esc_attr( get_the_ID() ) . '" data-action="' . esc_attr( $action ) . '"></a>';

					break;

			}

		}

		if ( !empty( $meta ) ) {
			$output .= '<div class="entry-fast-links">';
			$output .= $meta;
			$output .= '</div>';
		}

		return wp_kses_post($output);

	}
endif;

if ( ! function_exists( 'suround_recommended_output' ) ):
	function suround_recommended_output() {

		global $suround_settings;

		$include        = $suround_settings['search_rec_posts'];
		$per_page       = $suround_settings['search_per_page_limit'];
		$posts_per_page = $per_page ? $per_page : 4;

		$query = array(
			'post_type'           => 'post',
			'post_status'         => array( 'publish' ),
			'orderby'             => 'ID',
			'ignore_sticky_posts' => true,
			'posts_per_page'      => $posts_per_page
		);

		if ( is_array( $include ) && ! empty( $include ) ) {
			$query['post_in'] = $include;
		}

		$entries = new WP_Query( $query );
		?>

		<?php if ( $entries->have_posts() ): ?>

			<div class="search-section">

				<div class="container wide">

					<div class="entry-holder entry-layout-a4">

						<div class="title-holder heading-h6">
							<h6 class="section-title"><?php echo esc_html__( 'Recommended articles', 'surround' ) ?></h6>
						</div>

						<div class="entry-box">
							<?php while ( $entries->have_posts() ): $entries->the_post(); ?>
								<?php get_template_part( 'template-parts/post/layout', 'a4' ); ?>
							<?php endwhile;
							wp_reset_postdata(); ?>
						</div>

					</div>

				</div>

			</div>

		<?php endif;
	}
endif;

if ( !function_exists( 'suround_in_watch_later' ) ):
	function suround_in_watch_later( $id ) {

		if ( !in_array( $id, suround_get_watch_later_posts() ) ) {
			return false;
		}

		return true;
	}
endif;

/**
 * Get watch later posts
 */

if ( ! function_exists( 'suround_get_watch_later_posts' ) ):
	function suround_get_watch_later_posts() {

		if ( ! isset( $_COOKIE['suround_watch_later'] ) ) {
			return array();
		}

		return explode( "_", $_COOKIE['suround_watch_later'] );

	}
endif;

if ( ! function_exists( 'suround_post_single_reviewer' ) ) {
	function suround_post_single_reviewer( $postid = null ) {

		if ( ! $postid ) {
			$post_id = get_the_ID();
		}

		global $suround_settings;

		$template = $suround_settings['post-review-template']; ?>

		<?php if ( $template ): ?>

			<div class="suround-single-box">
				<?php echo do_shortcode( '[rwp-review branch="form"  id="-1" post="' . $post_id . '" template="' . $template . '"]' ); ?>
			</div>

		<?php endif;

	}
}

/**
 * Get category list
 */

if ( ! function_exists( 'suround_get_category_list' ) ):
	function suround_get_category_list( $post_id = false, $echo = true ) {

		$categories = get_the_category_list( ' ', '', $post_id );

		if ( $categories ) {

			$template = '<div class="entry-cats">%1$s</div>';

			if ( $echo ) {
				echo sprintf( $template, $categories );
			} else {
				return sprintf( $template, $categories );
			}

		}

	}
endif;

/**
 * Get likes
 */

if ( ! function_exists('suround_get_reviewer_likes') ) {
	function suround_get_reviewer_likes( $post_id = null ) {

		if ( !$post_id ) { $post_id = get_the_ID(); }

		$likes = get_post_meta( $post_id, 'rwp_likes', true );
		$likes = is_array( $likes ) ? $likes : array();

		$likess = array();
		$yes    = 0;
		$no     = 0;

		if ( ! empty( $likes ) ) {
			foreach ( $likes as $id => $like ) {
				$likess['yes'][] = $like['yes'];
				$likess['no'][]  = $like['no'];
			}

			extract( array(
				'yes' => array_sum( $likess['yes'] ),
				'no'  => array_sum( $likess['no'] )
			) );
		}

		ob_start();
		?>

		<div class="entry-vote">
			<span><i class="licon-thumbs-up"></i> <?php echo absint( $yes ) ?></span>
		</div>

		<div class="entry-vote">
			<span><i class="licon-thumbs-down"></i><?php echo absint( $no ) ?></span>
		</div>

		<?php return ob_get_clean();

	}
}

if ( !function_exists('suround_get_taxonomy_featured_image') ) :
	function suround_get_taxonomy_featured_image( $size = 'suround-450x280-center-center', $tax_id, $taxonomy ) {

		if ( empty( $tax_id ) ) {
			$tax_id = get_queried_object_id();
		}

		$img_url = $taxonomy == 'series' ? suround_get_series_meta( $tax_id, 'image' ) : suround_get_category_meta( $tax_id, 'image' );
		$img_html = '';

		if ( !empty( $img_url ) ) {
			$img_id = suround_get_image_id_by_url( $img_url );
			$img_html = wp_get_attachment_image( $img_id, $size );
			if ( empty( $img_html ) ) {
				$img_html = '<img src="' . esc_url( $img_url ) . '"/>';
			}
		}

		return $img_html;
	}
endif;

/**
 * Get post meta
 */

if ( ! function_exists('suround_blog_post_meta') ) :

	function suround_blog_post_meta( $layout = 'a1', $force_meta = false, $post_id = null ) {

		if ( ! $post_id ) {
			$post_id = get_the_ID();
		}

		$meta_data = $force_meta !== false ? $force_meta : array_keys( array_filter( suround_get_option( 'lay_' . $layout . '_meta' ) ) );

		$output = '';

		if ( !empty($meta_data) ) {

			foreach ( $meta_data as $mkey ) {

				$meta = '';

				switch ( $mkey ) {

					case 'date':
						$time_string = sprintf( '<time datetime="%1$s"><a href="%2$s" rel="bookmark">%3$s</a></time>',
							get_the_date( DATE_W3C ),
							esc_url( get_permalink() ),
							get_the_date()
						);
						$meta = sprintf( '%1$s', $time_string );
						break;

					case 'views':

						if ( function_exists('ev_post_views') ) {
							$meta = '<span><i class="licon-eye"></i>'. ev_get_post_views(array('text' => '%s')) .'</span>';
						}

						break;
					case 'vote':

						if ( class_exists('RWP_Reviewer') ) {
							$meta = suround_get_reviewer_likes( $post_id );
						}

						break;
					case 'comments':

						$meta = suround_comments_link( $post_id, true );

						break;

				}

				if ( ! empty( $meta ) ) {
					$output .= '<div class="meta-item meta-' . $mkey . '">' . $meta . '</div>';
				}
			}
		}

		return $output;
	}
endif;

/**
 * Print later posts
 */
if ( ! function_exists( 'suround_print_later_posts' ) ):
	function suround_print_later_posts( $args ) {

		$args['ignore_sticky_posts'] = 1;

		if ( isset( $_GET[ 'wpml_lang' ] ) ) {
			do_action( 'wpml_switch_language',  $_GET[ 'wpml_lang' ] );
		}

		$menu_posts = new WP_Query( $args );

		if ( $menu_posts->have_posts() ):

			while ( $menu_posts->have_posts() ) : $menu_posts->the_post(); ?>

				<article class="entry suround-menu-item">

					<?php if ( $fimg = suround_get_featured_image( 'thumbnail', false, false, true ) ) : ?>
						<div class="entry-image">
							<a href="<?php echo esc_url( get_permalink() ); ?>"
							   title="<?php echo esc_attr( get_the_title() ); ?>">
								<?php echo wp_kses_post( $fimg ); ?>
							</a>
						</div>
					<?php endif; ?>

					<div class="entry-description">

						<?php echo suround_get_category_list( get_the_ID() ) ?>

						<?php the_title( sprintf( '<h6 class="entry-title"><a href="%s">', esc_url( get_permalink() ) ), '</a></h6>' ); ?>

						<a href="javascript:void(0);" class="suround-remove-wl"
						   data-id="<?php echo esc_attr( get_the_ID() ); ?>"></a>

					</div>

				</article>

			<?php endwhile;

		endif;

		wp_reset_postdata();
	}
endif;


/**
 * Get archive title
 */
if ( ! function_exists( 'suround_the_archive_title' ) ):
	function suround_the_archive_title( $before = '', $after = '' ) {

		$title = suround_get_the_archive_title();

		if ( ! empty( $title ) ) {
			echo sprintf('%s %s %s', $before, $title, $after);
		}
	}
endif;

/**
 * Retrieve the archive title based on the queried object.
 *
 * @return string Archive title.
 */
function suround_get_the_archive_title() {
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_tag() ) {
		$title = single_tag_title( '', false );
	} elseif ( is_author() ) {
		$title = '<span class="vcard">' . get_the_author() . '</span>';
	} elseif ( is_year() ) {
		$title = get_the_date('Y');
	} elseif ( is_month() ) {
		$title = get_the_date('F Y');
	} elseif ( is_day() ) {
		$title = get_the_date('F j, Y');
	} elseif ( is_tax( 'post_format' ) ) {
		if ( is_tax( 'post_format', 'post-format-aside' ) ) {
			$title = _x( 'Asides', 'post format archive title', 'surround' );
		} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
			$title = _x( 'Galleries', 'post format archive title', 'surround' );
		} elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
			$title = _x( 'Images', 'post format archive title', 'surround' );
		} elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
			$title = _x( 'Videos', 'post format archive title', 'surround' );
		} elseif ( is_tax( 'post_format', 'post-format-quote' ) ) {
			$title = _x( 'Quotes', 'post format archive title', 'surround' );
		} elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
			$title = _x( 'Links', 'post format archive title', 'surround' );
		} elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
			$title = _x( 'Statuses', 'post format archive title', 'surround' );
		} elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
			$title = _x( 'Audio', 'post format archive title', 'surround' );
		} elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
			$title = _x( 'Chats', 'post format archive title', 'surround' );
		}
	} elseif ( is_post_type_archive() ) {
		$title = post_type_archive_title( '', false );
	} elseif ( is_tax() ) {
		$tax = get_taxonomy( get_queried_object()->taxonomy );
		$title = sprintf( __( '%1$s: %2$s', 'surround' ), $tax->labels->singular_name, single_term_title( '', false ) );
	} else {
		$title = esc_html__( 'Archives', 'surround' );
	}

	return apply_filters( 'suround_get_the_archive_title', $title );
}




