/**
 * Mapbox Mapify: Add Map To Address Input
 */
;( function ( $ ) {
	$.fn.extend({

		/* Create Function */
		mapboxMapify: function( options ) {

			/* Set default options */
			var settings = $.extend({
				height        : '300px',
				lat           : -74.50,
				lng           : 40,
				lock          : 'unlock',
				lat_input     : 'geo_lat',
				lng_input     : 'geo_lng',
				lock_input    : 'geo_map_lock_status'
			}, options );

			var that = $( this );

			/* Do this for each element */
			return this.each( function(){

				/* Prepare
				------------------------------------------ */

				/* Always add wrapper for consistency */
				that.wrap( '<div class="mapify"><span id="geocoder" class="geocoder"></span></div>' );

				/* Wrap El Vars */
				var mapifyEl = that.parents( '.mapify' );

				/* Add Map */
				if ( ! $( "#" + settings.id ).length ) {
					mapifyEl.append( '<div id="map-canvas" class="map-canvas" style="width:100%; height:' + settings.height + ';"></div>' );
				}
				var lock_text = 'unlock' == settings.lock ? mapifyl10n.locked : mapifyl10n.unlocked;
				var lock_class = 'unlock' == settings.lock ? 'unlocked' : 'locked';
				mapifyEl.append( '<div class="map-canvas-options"><span class="map-action-lock ' + lock_class + '" data-lock_status="' + settings.lock + '" data-lock="' + mapifyl10n.locked + '" data-unlock="' + mapifyl10n.unlocked + '">' + lock_text + '</span></div>' );
				mapifyEl.append( '<input autocomplete="off" type="hidden" name="' + settings.lock_input + '" value="' + settings.lock + '">' );
				mapifyEl.append( '<input autocomplete="off" type="hidden" name="' + settings.lat_input + '" value="' + settings.lat + '">' );
				mapifyEl.append( '<input autocomplete="off" type="hidden" name="' + settings.lng_input + '" value="' + settings.lng + '">' );

				/* Vars */
				var addressInput = that;
				var mapCanvas    = mapifyEl.find( '.map-canvas' );
				var lockInput    = mapifyEl.find( 'input[name="' + settings.lock_input + '"]' );
				var latInput     = mapifyEl.find( 'input[name="' + settings.lat_input + '"]' );
				var lngInput     = mapifyEl.find( 'input[name="' + settings.lng_input + '"]' );
				var map;
				var marker;

				/* Method Handler
				------------------------------------------ */
				var mapifyHandler = {

					/* Init
					------------------------------------------ */
					init: function(){

						/* Load Map */
						mapifyHandler.loadMap();

						mapifyHandler.toggleLock();

					},


					/* Load Map
					------------------------------------------ */
					loadMap: function() {

						if ( typeof mapboxgl !== "object" ) {
							return;
						}

						mapboxgl.accessToken = settings.mapbox_token;

						var LngLat = new mapboxgl.LngLat(settings.lng, settings.lat);

						var map = new mapboxgl.Map({
							container: mapCanvas[0],
							style: 'mapbox://styles/mapbox/streets-v10',
							center: LngLat,
							zoom: 8,
							trackResize: true
						});

						marker = new mapboxgl.Marker()
							.setLngLat(LngLat)
							.addTo(map);

						var geocoder = new MapboxGeocoder({
							accessToken: mapboxgl.accessToken,
							mapboxgl: mapboxgl,
							marker: true,
							placeholder: settings.placeholder
						});

						document.getElementById('geocoder').appendChild(geocoder.onAdd(map));

						map.on('load', function () {
							map.resize();

							geocoder.on('result', function (ev) {
								mapifyHandler.SetCoordinate(ev.result);
							});
						});

						marker.on('dragend', function(e) {

							if ( 'unlock' == mapifyEl.data( 'lock_status' ) ) {
								var lngLat = marker.getLngLat();
								var url = "https://api.mapbox.com/geocoding/v5/mapbox.places/" + lngLat.lng + "," + lngLat.lat + ".json?access_token=" + mapboxgl.accessToken;
								$.get( url, function( data ) {

									var result = data.features[0];

									if ( result ) {
										mapifyHandler.SetCoordinate(result);
										$(geocoder.container).find('input[type="text"]').val(result.place_name);
									}

								});
							}

						});

					},

					SetCoordinate: function(result) {
						mapifyHandler.updatePosition(result);
						mapifyHandler.updateAddress(result);
					},

					/* Toggle Lock
					 ------------------------------------------ */
					toggleLock: function(){
						mapifyEl.find( '.map-action-lock' ).click( function(e){
							e.preventDefault();
							var lockStatus = $( this ).data( 'lock_status' );

							if( 'unlock' == lockStatus ){
								marker.setDraggable( false );
								$( this ).removeClass( 'locked unlocked' ).addClass( 'locked' );
								$( this ).text( $( this ).data( 'unlock' ) );
								$( this ).data( 'lock_status', 'lock' );
								lockStatus = $( this ).data( 'lock_status' );
								$( this ).attr( 'data-lock_status', lockStatus );
								mapifyEl.data( 'lock_status', lockStatus );
								lockInput.val( lockStatus );
							} else {
								marker.setDraggable( true );
								$( this ).removeClass( 'locked unlocked' ).addClass( 'unlocked' );
								$( this ).text( $( this ).data( 'lock' ) );
								$( this ).data( 'lock_status', 'unlock' );
								lockStatus = $( this ).data( 'lock_status' );
								$( this ).attr( 'data-lock_status', lockStatus );
								mapifyEl.data( 'lock_status', lockStatus );
								lockInput.val( lockStatus );
							}
						});
					},

					/* Utility
					------------------------------------------ */

					updatePosition : function( result ){
						/* Update input */
						lngInput.val( result.center[0] );
						latInput.val( result.center[1] );
					},

					/* Update Address by Position */
					updateAddress : function( result ) {
						addressInput.val(result.place_name);
					},

				};

				/* Load Init */
				mapifyHandler.init();

			});
		},

	});
}( jQuery ));
