;(function($){
	'use strict';

	/**
	 * Suround_Custom_Selects
	 *
	 * @constructor
	 * @object options
	 **/
	function Suround_Custom_Selects(options) {
		this.collection = $();

		this.config = {
			target: '.mad-custom-select',
			cssPrefix: 'mad-'
		};

		options = options || {};
		$.extend(this.config, options);

		this.collection = this.collection.add($(this.config.target));

		if(this.collection.length) this.build().bindEvents();
	}

	/**
	 * Creates necessary select elements and adds them to container element
	 **/
	Suround_Custom_Selects.prototype.build = function(){

		var self = this;

		this.collection.each(function(index, element){
			var $element = $(element),
				$select = $element.children('select'),
				$selectedOption,
				$optionsList,
				$options,
				selectedFlag = false;

			if(!$select.length) return;

			$select.hide();

			$options = $select.find('option');

			$selectedOption = $('<div></div>', {
				'class': self.config.cssPrefix + 'selected-option',
				text: $select.data('default-text')
			});

			$optionsList = $('<ul></ul>', {
				'class': self.config.cssPrefix + 'options-list'
			});

			for(var i = 0, l = $options.length; i < l; i++){
				var option = $options.eq(i);

				var li = $('<li></li>', {
					'text': option.text(),
					'data-value': option.val()
				});

				if(option.attr('selected')){
					li.addClass(self.config.cssPrefix + 'active');
					$selectedOption.text(option.text());
					selectedFlag = true;
				}

				$optionsList.append(li);

			}

			if(!$select.data('default-text') && !selectedFlag){

				$selectedOption.text($options.eq(0).text());
				$optionsList.children('li').eq(0).addClass(self.config.cssPrefix + 'active');

			}

			$element.append($selectedOption);
			$element.append($optionsList);
		});

		return this;

	};

	/**
	 * Returns custom select to the default state.
	 **/
	Suround_Custom_Selects.prototype.toDefaultState = function(e){

		e.preventDefault();
		e.stopPropagation();

		var $this = $(this),
			self = e.data.self,
			$element = $this.closest(self.config.target);

		if($element.length && !$element.hasClass(self.config.cssPrefix + 'opened')){
			$element.removeClass(self.config.cssPrefix + 'over');
		}

	};

	/**
	 * Binds events to select elements
	 **/
	Suround_Custom_Selects.prototype.bindEvents = function(){

		var self = this;

		$('body').on('click.MadCustomSelects', this.config.target + ' .' + this.config.cssPrefix + 'selected-option', function(e) {
			var $element = $(this).closest(self.config.target);

			if($element.length) {
				$element.addClass(self.config.cssPrefix + 'over');
				$element.toggleClass(self.config.cssPrefix + 'opened');
			}

			e.stopPropagation();
		})
			.on('focus.MadCustomSelects', this.config.target + ' select', function(e) {
				var $element = $(this).closest(self.config.target);

				$element.addClass(self.config.cssPrefix + 'opened');
				e.preventDefault();
			})
			.on('click.MadCustomSelects', this.config.target + ' .' + this.config.cssPrefix + 'options-list li', function(e) {

				var $this = $(this),
					value = $this.data('value'),
					$element = $this.closest(self.config.target),
					$select = $element.find('select'),
					$selectedOption = $element.find('.' + self.config.cssPrefix + 'selected-option'),
					$options = $select.find('option'),
					$currentOption;

				$this.addClass(self.config.cssPrefix + 'active').siblings().removeClass(self.config.cssPrefix + 'active');

				$selectedOption.text($this.text());

				if($options.length) {
					$currentOption = $options.filter('[value="'+value+'"]');
					$options.not($currentOption).removeAttr('selected');
					if($currentOption.length) {
						$currentOption.attr('selected', 'true');
					}
				}

				$select.val(value);
				$select.trigger('change');
				$element.removeClass(self.config.cssPrefix + 'opened');

				e.stopPropagation();
			})
			.on('webkitTransitionEnd otransitionend oTransitionEnd msTransitionEnd transitionend', this.config.target + ' .' + this.config.cssPrefix + 'options-list', {self: this},  this.toDefaultState);


		$(document).on('click.selectFocusOut', function(e){
			e.stopPropagation();
			if(!$(e.target).closest('.' + self.config.cssPrefix + 'custom-select').length) $('.' + self.config.cssPrefix +  'custom-select').removeClass(self.config.cssPrefix + 'opened');
		});

	};

	$.extend({
		SuroundCustomSelects: function(options) {
			return new Suround_Custom_Selects(options);
		}
	});

})(jQuery);

/*!
 * Theia Sticky Sidebar v1.7.0
 * https://github.com/WeCodePixels/theia-sticky-sidebar
 *
 * Glues your website's sidebars, making them permanently visible while scrolling.
 *
 * Copyright 2013-2016 WeCodePixels and other contributors
 * Released under the MIT license
 */

(function ($) {
	$.fn.theiaStickySidebar = function (options) {
		var defaults = {
			'containerSelector': '',
			'additionalMarginTop': 0,
			'additionalMarginBottom': 0,
			'updateSidebarHeight': true,
			'minWidth': 0,
			'disableOnResponsiveLayouts': true,
			'sidebarBehavior': 'modern',
			'defaultPosition': 'relative',
			'namespace': 'TSS'
		};
		options = $.extend(defaults, options);

		// Validate options
		options.additionalMarginTop = parseInt(options.additionalMarginTop) || 0;
		options.additionalMarginBottom = parseInt(options.additionalMarginBottom) || 0;

		tryInitOrHookIntoEvents(options, this);

		// Try doing init, otherwise hook into window.resize and document.scroll and try again then.
		function tryInitOrHookIntoEvents(options, $that) {
			var success = tryInit(options, $that);

			if (!success) {
				console.log('TSS: Body width smaller than options.minWidth. Init is delayed.');

				$(document).on('scroll.' + options.namespace, function (options, $that) {
					return function (evt) {
						var success = tryInit(options, $that);

						if (success) {
							$(this).unbind(evt);
						}
					};
				}(options, $that));
				$(window).on('resize.' + options.namespace, function (options, $that) {
					return function (evt) {
						var success = tryInit(options, $that);

						if (success) {
							$(this).unbind(evt);
						}
					};
				}(options, $that))
			}
		}

		// Try doing init if proper conditions are met.
		function tryInit(options, $that) {
			if (options.initialized === true) {
				return true;
			}

			if ($('body').width() < options.minWidth) {
				return false;
			}

			init(options, $that);

			return true;
		}

		// Init the sticky sidebar(s).
		function init(options, $that) {
			options.initialized = true;

			// Add CSS
			var existingStylesheet = $('#theia-sticky-sidebar-stylesheet-' + options.namespace);
			if (existingStylesheet.length === 0) {
				$('head').append($('<style id="theia-sticky-sidebar-stylesheet-' + options.namespace + '">.theiaStickySidebar:after {content: ""; display: table; clear: both;}</style>'));
			}

			$that.each(function () {
				var o = {};

				o.sidebar = $(this);

				// Save options
				o.options = options || {};

				// Get container
				o.container = $(o.options.containerSelector);
				if (o.container.length == 0) {
					o.container = o.sidebar.parent();
				}

				// Create sticky sidebar
				o.sidebar.parents().css('-webkit-transform', 'none'); // Fix for WebKit bug - https://code.google.com/p/chromium/issues/detail?id=20574
				o.sidebar.css({
					'position': o.options.defaultPosition,
					'overflow': 'visible',
					// The "box-sizing" must be set to "content-box" because we set a fixed height to this element when the sticky sidebar has a fixed position.
					'-webkit-box-sizing': 'border-box',
					'-moz-box-sizing': 'border-box',
					'box-sizing': 'border-box'
				});

				// Get the sticky sidebar element. If none has been found, then create one.
				o.stickySidebar = o.sidebar.find('.theiaStickySidebar');
				if (o.stickySidebar.length == 0) {
					// Remove <script> tags, otherwise they will be run again when added to the stickySidebar.
					var javaScriptMIMETypes = /(?:text|application)\/(?:x-)?(?:javascript|ecmascript)/i;
					o.sidebar.find('script').filter(function (index, script) {
						return script.type.length === 0 || script.type.match(javaScriptMIMETypes);
					}).remove();

					o.stickySidebar = $('<div>').addClass('theiaStickySidebar').append(o.sidebar.children());
					o.sidebar.append(o.stickySidebar);
				}

				// Get existing top and bottom margins and paddings
				o.marginBottom = parseInt(o.sidebar.css('margin-bottom'));
				o.paddingTop = parseInt(o.sidebar.css('padding-top'));
				o.paddingBottom = parseInt(o.sidebar.css('padding-bottom'));

				// Add a temporary padding rule to check for collapsable margins.
				var collapsedTopHeight = o.stickySidebar.offset().top;
				var collapsedBottomHeight = o.stickySidebar.outerHeight();
				o.stickySidebar.css('padding-top', 1);
				o.stickySidebar.css('padding-bottom', 1);
				collapsedTopHeight -= o.stickySidebar.offset().top;
				collapsedBottomHeight = o.stickySidebar.outerHeight() - collapsedBottomHeight - collapsedTopHeight;
				if (collapsedTopHeight == 0) {
					o.stickySidebar.css('padding-top', 0);
					o.stickySidebarPaddingTop = 0;
				}
				else {
					o.stickySidebarPaddingTop = 1;
				}

				if (collapsedBottomHeight == 0) {
					o.stickySidebar.css('padding-bottom', 0);
					o.stickySidebarPaddingBottom = 0;
				}
				else {
					o.stickySidebarPaddingBottom = 1;
				}

				// We use this to know whether the user is scrolling up or down.
				o.previousScrollTop = null;

				// Scroll top (value) when the sidebar has fixed position.
				o.fixedScrollTop = 0;

				// Set sidebar to default values.
				resetSidebar();

				o.onScroll = function (o) {
					// Stop if the sidebar isn't visible.
					if (!o.stickySidebar.is(":visible")) {
						return;
					}

					// Stop if the window is too small.
					if ($('body').width() < o.options.minWidth) {
						resetSidebar();
						return;
					}

					// Stop if the sidebar width is larger than the container width (e.g. the theme is responsive and the sidebar is now below the content)
					if (o.options.disableOnResponsiveLayouts) {
						var sidebarWidth = o.sidebar.outerWidth(o.sidebar.css('float') == 'none');

						if (sidebarWidth + 50 > o.container.width()) {
							resetSidebar();
							return;
						}
					}

					var scrollTop = $(document).scrollTop();
					var position = 'static';

					// If the user has scrolled down enough for the sidebar to be clipped at the top, then we can consider changing its position.
					if (scrollTop >= o.sidebar.offset().top + (o.paddingTop - o.options.additionalMarginTop)) {
						// The top and bottom offsets, used in various calculations.
						var offsetTop = o.paddingTop + options.additionalMarginTop;
						var offsetBottom = o.paddingBottom + o.marginBottom + options.additionalMarginBottom;

						// All top and bottom positions are relative to the window, not to the parent elemnts.
						var containerTop = o.sidebar.offset().top;
						var containerBottom = o.sidebar.offset().top + getClearedHeight(o.container);

						// The top and bottom offsets relative to the window screen top (zero) and bottom (window height).
						var windowOffsetTop = 0 + options.additionalMarginTop;
						var windowOffsetBottom;

						var sidebarSmallerThanWindow = (o.stickySidebar.outerHeight() + offsetTop + offsetBottom) < $(window).height();
						if (sidebarSmallerThanWindow) {
							windowOffsetBottom = windowOffsetTop + o.stickySidebar.outerHeight();
						}
						else {
							windowOffsetBottom = $(window).height() - o.marginBottom - o.paddingBottom - options.additionalMarginBottom;
						}

						var staticLimitTop = containerTop - scrollTop + o.paddingTop;
						var staticLimitBottom = containerBottom - scrollTop - o.paddingBottom - o.marginBottom;

						var top = o.stickySidebar.offset().top - scrollTop;
						var scrollTopDiff = o.previousScrollTop - scrollTop;

						// If the sidebar position is fixed, then it won't move up or down by itself. So, we manually adjust the top coordinate.
						if (o.stickySidebar.css('position') == 'fixed') {
							if (o.options.sidebarBehavior == 'modern') {
								top += scrollTopDiff;
							}
						}

						if (o.options.sidebarBehavior == 'stick-to-top') {
							top = options.additionalMarginTop;
						}

						if (o.options.sidebarBehavior == 'stick-to-bottom') {
							top = windowOffsetBottom - o.stickySidebar.outerHeight();
						}

						if (scrollTopDiff > 0) { // If the user is scrolling up.
							top = Math.min(top, windowOffsetTop);
						}
						else { // If the user is scrolling down.
							top = Math.max(top, windowOffsetBottom - o.stickySidebar.outerHeight());
						}

						top = Math.max(top, staticLimitTop);

						top = Math.min(top, staticLimitBottom - o.stickySidebar.outerHeight());

						// If the sidebar is the same height as the container, we won't use fixed positioning.
						var sidebarSameHeightAsContainer = o.container.height() == o.stickySidebar.outerHeight();

						if (!sidebarSameHeightAsContainer && top == windowOffsetTop) {
							position = 'fixed';
						}
						else if (!sidebarSameHeightAsContainer && top == windowOffsetBottom - o.stickySidebar.outerHeight()) {
							position = 'fixed';
						}
						else if (scrollTop + top - o.sidebar.offset().top - o.paddingTop <= options.additionalMarginTop) {
							// Stuck to the top of the page. No special behavior.
							position = 'static';
						}
						else {
							// Stuck to the bottom of the page.
							position = 'absolute';
						}
					}

					/*
					 * Performance notice: It's OK to set these CSS values at each resize/scroll, even if they don't change.
					 * It's way slower to first check if the values have changed.
					 */
					if (position == 'fixed') {
						var scrollLeft = $(document).scrollLeft();

						o.stickySidebar.css({
							'position': 'fixed',
							'width': getWidthForObject(o.stickySidebar) + 'px',
							'transform': 'translateY(' + top + 'px)',
							'left': (o.sidebar.offset().left + parseInt(o.sidebar.css('padding-left')) - scrollLeft) + 'px',
							'top': '0px'
						});
					}
					else if (position == 'absolute') {
						var css = {};

						if (o.stickySidebar.css('position') != 'absolute') {
							css.position = 'absolute';
							css.transform = 'translateY(' + (scrollTop + top - o.sidebar.offset().top - o.stickySidebarPaddingTop - o.stickySidebarPaddingBottom) + 'px)';
							css.top = '0px';
						}

						css.width = getWidthForObject(o.stickySidebar) + 'px';
						css.left = '';

						o.stickySidebar.css(css);
					}
					else if (position == 'static') {
						resetSidebar();
					}

					if (position != 'static') {
						if (o.options.updateSidebarHeight == true) {
							o.sidebar.css({
								'min-height': o.stickySidebar.outerHeight() + o.stickySidebar.offset().top - o.sidebar.offset().top + o.paddingBottom
							});
						}
					}

					o.previousScrollTop = scrollTop;
				};

				// Initialize the sidebar's position.
				o.onScroll(o);

				// Recalculate the sidebar's position on every scroll and resize.
				$(document).on('scroll.' + o.options.namespace, function (o) {
					return function () {
						o.onScroll(o);
					};
				}(o));
				$(window).on('resize.' + o.options.namespace, function (o) {
					return function () {
						o.stickySidebar.css({'position': 'static'});
						o.onScroll(o);
					};
				}(o));

				// Recalculate the sidebar's position every time the sidebar changes its size.
				if (typeof ResizeSensor !== 'undefined') {
					new ResizeSensor(o.stickySidebar[0], function (o) {
						return function () {
							o.onScroll(o);
						};
					}(o));
				}

				// Reset the sidebar to its default state
				function resetSidebar() {
					o.fixedScrollTop = 0;
					o.sidebar.css({
						'min-height': '1px'
					});
					o.stickySidebar.css({
						'position': 'static',
						'width': '',
						'transform': 'none'
					});
				}

				// Get the height of a div as if its floated children were cleared. Note that this function fails if the floats are more than one level deep.
				function getClearedHeight(e) {
					var height = e.height();

					e.children().each(function () {
						height = Math.max(height, $(this).height());
					});

					return height;
				}
			});
		}

		function getWidthForObject(object) {
			var width;

			try {
				width = object[0].getBoundingClientRect().width;
			}
			catch (err) {
			}

			if (typeof width === "undefined") {
				width = object.width();
			}

			return width;
		}

		return this;
	}
})(jQuery);


/*
 * debouncedresize: special jQuery event that happens once after a window resize
 *
 * latest version and complete README available on Github:
 * https://github.com/louisremi/jquery-smartresize
 *
 * Copyright 2012 @louis_remi
 * Licensed under the MIT license.
 *
 * This saved you an hour of work?
 * Send me music http://www.amazon.co.uk/wishlist/HNTU0468LQON
 */
(function($) {

	var $event = $.event,
		$special,
		resizeTimeout;

	$special = $event.special.debouncedresize = {
		setup: function() {
			$(this).on("resize", $special.handler);
		},
		teardown: function() {
			$(this).off("resize", $special.handler);
		},
		handler: function(event, execAsap) {
			// Save the context
			var context = this,
				args = arguments,
				dispatch = function() {
					// set correct event type
					event.type = "debouncedresize";
					$event.dispatch.apply(context, args);
				};

			if (resizeTimeout) {
				clearTimeout(resizeTimeout);
			}

			execAsap ?
				dispatch() :
				resizeTimeout = setTimeout(dispatch, $special.threshold);
		},
		threshold: 150
	};

})(jQuery);


/* ----------------------------------------
 FitVids
 ---------------------------------------- */

/*jshint browser:true */
/*!
 * FitVids 1.1
 *
 * Copyright 2013, Chris Coyier - http://css-tricks.com + Dave Rupert - http://daverupert.com
 * Credit to Thierry Koblentz - http://www.alistapart.com/articles/creating-intrinsic-ratios-for-video/
 * Released under the WTFPL license - http://sam.zoy.org/wtfpl/
 *
 */

;(function( $ ){

	'use strict';

	$.fn.fitVids = function( options ) {
		var settings = {
			customSelector: null,
			ignore: null
		};

		if(!document.getElementById('fit-vids-style')) {
			var head = document.head || document.getElementsByTagName('head')[0];
			var css = '.fluid-width-video-wrapper{width:100%;position:relative;padding:0;}.fluid-width-video-wrapper iframe,.fluid-width-video-wrapper object,.fluid-width-video-wrapper embed {position:absolute;top:0;left:0;width:100%;height:100%;}';
			var div = document.createElement("div");
			div.innerHTML = '<p>x</p><style id="fit-vids-style">' + css + '</style>';
			head.appendChild(div.childNodes[1]);
		}

		if ( options ) {
			$.extend( settings, options );
		}

		return this.each(function(){
			var selectors = [
				'iframe[src*="player.vimeo.com"]',
				'iframe[src*="youtube.com"]',
				'iframe[src*="youtube-nocookie.com"]',
				'iframe[src*="kickstarter.com"][src*="video.html"]',
				'object',
				'embed'
			];

			if (settings.customSelector) {
				selectors.push(settings.customSelector);
			}

			var ignoreList = '.fitvidsignore';

			if(settings.ignore) {
				ignoreList = ignoreList + ', ' + settings.ignore;
			}

			var $allVideos = $(this).find(selectors.join(','));
			$allVideos = $allVideos.not('object object'); // SwfObj conflict patch
			$allVideos = $allVideos.not(ignoreList); // Disable FitVids on this video.

			$allVideos.each(function(){
				var $this = $(this);
				if($this.parents(ignoreList).length > 0) {
					return; // Disable FitVids on this video.
				}
				if (this.tagName.toLowerCase() === 'embed' && $this.parent('object').length || $this.parent('.fluid-width-video-wrapper').length) { return; }
				if ((!$this.css('height') && !$this.css('width')) && (isNaN($this.attr('height')) || isNaN($this.attr('width'))))
				{
					$this.attr('height', 9);
					$this.attr('width', 16);
				}
				var height = ( this.tagName.toLowerCase() === 'object' || ($this.attr('height') && !isNaN(parseInt($this.attr('height'), 10))) ) ? parseInt($this.attr('height'), 10) : $this.height(),
					width = !isNaN(parseInt($this.attr('width'), 10)) ? parseInt($this.attr('width'), 10) : $this.width(),
					aspectRatio = height / width;
				if(!$this.attr('name')){
					var videoName = 'fitvid' + $.fn.fitVids._count;
					$this.attr('name', videoName);
					$.fn.fitVids._count++;
				}
				$this.wrap('<div class="fluid-width-video-wrapper"></div>').parent('.fluid-width-video-wrapper').css('padding-top', (aspectRatio * 100)+'%');
				$this.removeAttr('height').removeAttr('width');
			});
		});
	};

	// Internal counter for unique video names.
	$.fn.fitVids._count = 0;

// Works with either jQuery or Zepto
})( window.jQuery || window.Zepto );


var Suround = (function($) {
	'use strict';

	var App = {},
		DOMDfd = $.Deferred(),
		$body = $('body'),
		$window = $(window),
		$doc = $(document);

	window.DOMDfd = DOMDfd;

	App.modules = {};
	App.helpers = {};
	App._localCache = {};

	App.ISTOUCH = Modernizr.touchevents;
	App.EVENT = App.ISTOUCH ? 'touchstart' : 'click';
	App.ANIMATIONDURATION = 500;
	App.ANIMATIONEASING = 'easeOutQuart';
	App.ANIMATIONSUPPORTED = Modernizr.cssanimations;
	App.ANIMATIONEND = "webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend";
	App.RTL = getComputedStyle(document.body).direction === 'rtl';
	App.ISLEGACYBROWSER = !Modernizr.flexbox;

	App.afterDOMReady = function() {

		if ( $('#scroll-event').length ) this.helpers.scrollEvent();

		if ( $('#social-fixed').length ) this.helpers.socialFixed();

		if ( $('.accordion').length ) this.helpers.accordion();

		if ( $('.tabs-section').length ) this.helpers.tabs();

		if ( $('#main-navigation').length ) this.modules.navInit();

		if ( $('.sticky-header').length && suround_global_vars.header_sticky ) this.modules.stickyHeader();

		if ( $('.dropdown-invoker').length ) this.modules.dropdown();

		if ( $('.search-button').length ) this.modules.searchClick();

		if ( $('.entry-link-bookmark').length ) this.modules.watchLater();

		if ( $('#navbar-menu').length ) this.modules.sidebarMenu();

		if ( $('.counter').length ) this.modules.counters();

		if ( $('.countdown').length ) this.modules.countdown();

		if ( $('.newsletter-wrap').length ) this.modules.newsletter();

		if ( $('.suround-gmap').length ) this.modules.gMap();

		if ( $('.grid--isotope').length ) this.modules.isotope();

		if ( $('[data-sort-view]').length) this.modules.sortView();

		if ( $('.map-toggle').length && $('.section-map').length ) this.modules.mapToggle();

		if ( $('.entry-link-video').length) this.modules.popupVideo();

		if ( $('.related-popup').length) this.modules.relatedPopup();

		if ( $('.suround-video-cover').length ) this.modules.videoCover();

		if ( this.modules.backToTop ) { this.modules.backToTop(); }

		this.modules.searchForm();

		/* ---------------------------------------------------- */
		/*	Custom Select										*/
		/* ---------------------------------------------------- */

		if ( $('.mad-custom-select').length ) {
			$.SuroundCustomSelects();
		};

	}

	App.afterOuterResourcesLoaded = function(window) {

		if ( this.helpers.Colorizer ) this.helpers.Colorizer.init();

		if ( $('.cat-layout-side-map').length ) {
			this.helpers.customizePadding(window);
		}

		/* ----------------------------------------
		 Carousel
		 ---------------------------------------- */

		if ( $('.owl-carousel').length ) {
			this.helpers.owlAdaptive();
			this.modules.owlCarousel();
		}

	}

	/* ----------------------------------------
	 Searchform
	 ---------------------------------------- */

	App.modules.searchForm = function() {

		var $forms = $('.searchform-line, form.mailpoet_form_widget');

		if ( $forms.length ) {

			$forms.each(function(i, el) {

				var $form = $(el);

				var $button = $form.find('button[type="submit"]');

				if ( $(el).hasClass('mailpoet_form_widget') ) {
					$button = $form.find('.mailpoet_submit');
				}

				$button.on('mouseenter', function() {
					$form.addClass('form-hover-class');
				}).on('mouseleave', function() {
					$form.removeClass('form-hover-class');
				});

			});

		}

	}

	/* ----------------------------------------
	 Counters
	 ---------------------------------------- */

	App.modules.counters = function(){

		$('.counter').each(function(){

			var $this = $(this),
				offset = $this.offset().top - 3000;

			$(window).on('scroll',function(){
				if($this.hasClass('counted')) return false;

				if($(this).scrollTop() >= offset){

					$this.addClass('counted');

					(function ($) {
						$.fn.countTo = function (options) {
							options = options || {};

							return $(this).each(function () {
								// set options for current element
								var settings = $.extend({}, $.fn.countTo.defaults, {
									from:            $(this).data('from'),
									to:              $(this).data('to'),
									speed:           $(this).data('speed'),
									refreshInterval: $(this).data('refresh-interval'),
									decimals:        $(this).data('decimals')
								}, options);

								// how many times to update the value, and how much to increment the value on each update
								var loops = Math.ceil(settings.speed / settings.refreshInterval),
									increment = (settings.to - settings.from) / loops;

								// references & variables that will change with each update
								var self = this,
									$self = $(this),
									loopCount = 0,
									value = settings.from,
									data = $self.data('countTo') || {};

								$self.data('countTo', data);

								// if an existing interval can be found, clear it first
								if (data.interval) {
									clearInterval(data.interval);
								}
								data.interval = setInterval(updateTimer, settings.refreshInterval);

								// initialize the element with the starting value
								render(value);

								function updateTimer() {
									value += increment;
									loopCount++;

									render(value);

									if (typeof(settings.onUpdate) == 'function') {
										settings.onUpdate.call(self, value);
									}

									if (loopCount >= loops) {
										// remove the interval
										$self.removeData('countTo');
										clearInterval(data.interval);
										value = settings.to;

										if (typeof(settings.onComplete) == 'function') {
											settings.onComplete.call(self, value);
										}
									}
								}

								function render(value) {
									var formattedValue = settings.formatter.call(self, value, settings);
									$self.html(formattedValue);
								}
							});
						};

						$.fn.countTo.defaults = {
							from: 0,               // the number the element should start at
							to: 0,                 // the number the element should end at
							speed: 1000,           // how long it should take to count between the target numbers
							refreshInterval: 100,  // how often the element should be updated
							decimals: 0,           // the number of decimal places to show
							formatter: formatter,  // handler for formatting the value before rendering
							onUpdate: null,        // callback method for every time the element is updated
							onComplete: null       // callback method for when the element finishes updating
						};

						function formatter(value, settings) {
							return value.toFixed(settings.decimals);
						}
					}(jQuery));

					jQuery(function ($) {
						// custom formatting example
						$('.count-number').data('countToOptions', {
							formatter: function (value, options) {
								return value.toFixed(options.decimals).replace(/\B(?=(?:\d{3})+(?!\d))/g, ' ');
							}
						});

						// start all the timers
						$('.timer').each(count);

						function count(options) {
							var $this = $(this);
							options = $.extend({}, options || {}, $this.data('countToOptions') || {});
							$this.countTo(options);
						}
					});

				}

			});

		});

	}

	/* ----------------------------------------
	 Countdown
	 ---------------------------------------- */

	App.modules.countdown = function() {

		$('.countdown').each(function () {
			var $this = $(this),
				endDate = $this.data('terminal-date');

			$this.countdown({
				until: new Date(endDate),
				format: 'dHMS',
				labels: ['Years', 'Month', 'Weeks', 'Days', 'Hours', 'Minutes', 'Seconds']
			});
		});

	}

	/* ----------------------------------------
	 Map Toggle
	 ---------------------------------------- */

	App.modules.mapToggle = function() {

		var $section_map = $('.section-map');

		if ( !$section_map.length ) return;

		if ( $section_map.hasClass('hide_map') ) {
			$section_map.slideUp();
		}

		$('.map-toggle').on('click', function (e) {
			e.preventDefault();

			var $this = $(this);
			var $text_change =  $this.find('.text-change');

			if ( $section_map.length ) {

				if ( $section_map.hasClass('show_map') ) {

					$text_change.fadeOut(function() {
						$section_map.slideUp();
						$(this).text(suround_global_vars.show_text).fadeIn();
						$section_map.removeClass('show_map').addClass('hide_map');
					});

				} else {

					$text_change.fadeOut(function() {
						$section_map.slideDown();
						$(this).text(suround_global_vars.hide_text).fadeIn();
						$section_map.removeClass('hide_map').addClass('show_map');
					});

				}

			}


		});

	}

	/* ----------------------------------------
	 Sort View
	 ---------------------------------------- */

	App.modules.sortView = function () {

		var collection = $('[data-sort-view]');
		if ( !collection.length ) return;

		collection.on('click', function (e) {
			e.preventDefault();

			var $this = $(this),
				$target = $this.parents('.sort-header-wrap').next('#filter-section');

			$this
				.addClass('active')
				.siblings()
				.removeClass('active');

			if ( $target.length ) {

				$target
					.removeClass('view-list view-grid view-classic')
					.addClass('view-' + $this.data('sort-view'));

				if ( $target.find('.grid--isotope').length ) {
					$target.find('.grid--isotope').isotope('layout');
				}
			}

		});

		return collection;

	}

	/* ----------------------------------------
	 Isotope
	 ---------------------------------------- */

	App.modules.isotope = function() {

		var $isotope = $('.grid--isotope');

		if ( $isotope.length && window.SuroundIsotopeWrapper ) {
			$isotope.each(function(index, container) {
				var $container = $(container);
				$container.jQueryImagesLoaded().then(function () {
					SuroundIsotopeWrapper.init($container, {
						itemSelector: '.grid-item',
						transitionDuration: 500
					});
				});
			});
		}

	}

	/* ----------------------------------------
	 Google Map
	 ---------------------------------------- */

	App.modules.gMap = function() {

		function heightFullWidth(elem, map_override) {

			var logginHeight = $('body').hasClass('logged-in') ? 32 : 0;
			var heightHeader = $('#header').outerHeight() + 56 + logginHeight + 'px';

			if ( map_override == 'ex-full' ) {
				$('body').addClass('ex-full');
				elem.css({
					height: 'calc(100vh - '+ heightHeader + ')'
				});
			}

		}

		$('.suround-gmap').each(function () {

			var elem = $(this),
				id = elem.attr('id'),
				map_override = elem.data('map_override'),
				options = elem.data('options');

			if ( id !== null ) {

				var isDraggable = $(document).width() > 641 ? true : options['dragging'];

				try {

					var coordinate = new google.maps.LatLng(options['lat'], options['lng']);

					var mapOptions = {
						zoom: parseInt(options['zoom']),
						center: coordinate,
						scaleControl: true,
						streetViewControl: options['streetviewcontrol'],
						mapTypeControl: options['maptypecontrol'],
						panControl: options['pancontrol'],
						zoomControl: options['zoomcontrol'],
						scrollwheel: options['scrollwheel'],
						draggable: isDraggable,
						zoomControlOptions: {
							style: options['zoomcontrolsize']
						}
					}

					if (options['map_style'] == "") {
						mapOptions['mapTypeId'] = google.maps.MapTypeId[options['map_type']];
					} else {
						mapOptions['mapTypeControlOptions'] = {
							'mapTypeIds': [google.maps.MapTypeId[options['map_type']], 'map_style']
						}
					}

					if (options['map_style'] !== "") {
						var styles = options['map_style'];
						var styledMap = new google.maps.StyledMapType(styles);
					}

					var map = new google.maps.Map(document.getElementById(id), mapOptions);

					if ( options['map_style'] !== "" ) {
						map.mapTypes.set('map_style', styledMap);
						map.setMapTypeId('map_style');
					}

					if ( map ) {

						if ( options['marker_lat'] != "" && options['marker_lng'] != "" ) {

							var myIcon = new google.maps.MarkerImage(options['icon_url'], null, null, null, new google.maps.Size(45, 50));

							var marker = new google.maps.Marker({
								position: new google.maps.LatLng(options['marker_lat'], options['marker_lng']),
								animation: google.maps.Animation.DROP,
								map: map,
								icon: myIcon
							});

							if ( options['content'] !== "" ) {

								var infoBubble = new InfoBubble({
									map: map,
									content: options['content'],
									position: new google.maps.LatLng(options['marker_lat'], options['marker_lng']),
									shadowStyle: 1,
									padding: 0,
									backgroundColor: 'rgb(255,255,255)',
									borderRadius: 4,
									arrowSize: 20,
									borderWidth: 0,
									borderColor: 'transparent',
									disableAutoPan: true,
									hideCloseButton: false,
									arrowPosition: 0,
									backgroundClassName: 'ch-map-style',
									arrowStyle: 2,
								});
								infoBubble.open(map, marker);

								infoBubble.setMaxWidth(300);
								infoBubble.setMinHeight(290);

								// var infowindow = new google.maps.InfoWindow();
								// infowindow.setContent(options['content']);

								google.maps.event.addListener(marker, 'click', function () {
									// infowindow.open(map, marker);
									infoBubble.open(map, marker);
								});

							}

						}

						google.maps.event.trigger(map, 'resize');

						heightFullWidth(elem, map_override);

						$(window).on( 'resize', heightFullWidth );

					}

				} catch (e) { }



			}

		});

	}

	App.modules.newsletter = function($form) {

		var $forms = $form && $form.length ? $form : $('.newsletter-wrap');

		if ( $forms.length ) {

			if ( $forms.is('.style-2') || $forms.is('.style-3') ) {

				$forms.each(function (index, element) {

					var $element = $(element),
						$paragraph = $element.find('.mailpoet_paragraph');

					$paragraph.each(function() {
						$(this).next('.mailpoet_paragraph').andSelf().wrapAll('<div class="mailpoet_half"/>');
					});

				});

			} else {

				$forms.each(function (index, element) {

					var $element = $(element),
						$input_text = $element.find('.mailpoet_text'),
						$submit = $element.find('.mailpoet_submit'),
						$submit_html = $submit.parent().html();

					if ( $submit_html.length ) {
						$input_text.after($submit_html);
						if ($submit.length) $submit.remove();
					}

				});

			}

		}

	}

	/* ----------------------------------------
	 Side Panel
	 ---------------------------------------- */

	App.modules.sidebarMenu = function () {

		var $win = $('.wrapper-container');
		var sideMenu = $('#navbar-menu');
		var wrapMenu = $('.navbar-wrap');

		$win.on('click.Bst', function(event){
			if ( sideMenu.has(event.target).length === 0  && !sideMenu.is(event.target) ){
				wrapMenu.removeClass('active');
			}
		});

		$('.navbar-toggle').on('click',function() {
			wrapMenu.toggleClass('active');
			return false;
		});

		$('#navbar-close').on('click',function() {
			wrapMenu.removeClass('active');
			return false;
		});

	}

	/* ----------------------------------------
	 Watch Later
	 ---------------------------------------- */

	App.modules.watchLater = function() {

		$('body').on('click', '.entry-link-bookmark', function(e) {

			e.preventDefault();

			var $this = $(this);
			var container = $('.suround-watch-later');
			var counter = container.find('.suround-watch-later-count');
			var empty = container.find('.suround-menu-empty');
			var posts = container.find('.suround-menu-posts');
			var id = $this.attr('data-id');
			var what = $this.attr('data-action');

			if ( what == 'add' ) {
				counter.text(parseInt(counter.first().text()) + 1);
				$this.attr('data-action', 'remove');
			} else {
				counter.text(parseInt(counter.first().text()) - 1);
				$this.attr('data-action', 'add');
			}

			if ( parseInt(counter.text()) > 0 ) {
				counter.fadeIn(300);
				empty.fadeOut(300);
			} else {
				counter.fadeOut(300);
				empty.fadeIn(300);
			}

			var data = {
				action: 'suround_watch_later',
				what: what,
				id: id
			};

			$.post(suround_global_vars.ajaxurl, data, function(response) {
				posts.html(response);
			});

		}).on('click', '.suround-remove-wl', function(e) {
			e.preventDefault();

			var $this = $(this);
			var container = $('.suround-watch-later');
			var posts = container.find('.suround-menu-posts');
			var empty = container.find('.suround-menu-empty');
			var counter = container.find('.suround-watch-later-count');
			var id = $this.attr('data-id');

			counter.text(parseInt(counter.first().text()) - 1);

			$this.closest('.suround-menu-item').fadeOut(300).remove();

			if ( parseInt(counter.text()) == 0 ) {
				counter.fadeOut(300);
				empty.fadeIn(300);
			}

			var data = {
				action: 'suround_watch_later',
				what: 'remove',
				id: id
			};

			$.post(suround_global_vars.ajaxurl, data, function(response) {});

		});

		if ( $('.suround-watch-later').length ) {
			$.post(suround_global_vars.ajaxurl, {
				action: 'suround_load_watch_later'
			}, function(response) {
				$('.suround-watch-later').html(response);
			});
		}

	}

	/* ----------------------------------------
	 Popup Video
	 ---------------------------------------- */

	App.modules.popupVideo = function() {

		$('body').on( 'click', '.entry-link-video', function(e) {

			e.preventDefault();

			$.fancybox.open({
				src  : suround_global_vars.ajaxurl,
				type : 'ajax',
				iframe : {
					preload : false
				},
				opts : {
					ajax: {
						settings: {
							type: 'POST',
							data: {
								action: $(this).data('action'),
								id: $(this).data('id')
							}
						}
					}
				}

			});

		});

	}

	/* ----------------------------------------
	 Related Popup
	 ---------------------------------------- */

	App.modules.relatedPopup = function() {

		var bannerWin = $('.related-popup');
			bannerWin.addClass('hide');

		var run = true;
		var offset = 1500;

		$(window).on('scroll', function () {
			var windowpos = $(window).scrollTop();
			var $comments = $('#comments');
			if ( $comments.length ) {
				offset = $comments.offset().top - 700;
			}

			if ( windowpos > offset ) {
				if ( run ) {
					bannerWin
						.addClass('show toggle')
						.removeClass('hide');
					run = false;
				}
			} else {
				bannerWin
					.removeClass('show toggle')
					.addClass('hide');
				run = true;
			}
		});

		$('.toggle-button', bannerWin).on('click', function (e) {
			e.preventDefault();
			run = false;
			bannerWin.toggleClass('show toggle');
		});

		$(window).on('load resize', function () {
			if ( $(window).width() < 768 ) {
				bannerWin.removeClass('toggle');
			}
		});


	}

	/* ----------------------------------------
	 Video Cover
	 ---------------------------------------- */

	App.modules.videoCover = function(collection) {

		collection = collection ? collection : $('.suround-video-cover');

		if ( !collection.length ) return;

		var tag = document.createElement('script');
		tag.src = "//www.youtube.com/iframe_api";
		var firstScriptTag = document.getElementsByTagName('script')[0];
		firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);

		var playerCover;
		var playerPopup;

		window.onYouTubeIframeAPIReady = function() {

			var playerCoverId = document.getElementById('suround-player-cover');

			if ( playerCoverId ) {

				playerCover = new YT.Player('suround-player-cover', {
					height: '560',
					width: '1280',
					videoId: playerCoverId.getAttribute( 'data-youtube-video-id' ),
					playerVars: {
						autohide: 0,
						autoplay: 0,
						controls: 1,
						loop: 0,
						fs: 0,
						showinfo: 1,
						modestBranding: 1,
						start: 0,
						rel: 0,
						iv_load_policy: 3,
						wmode: 'transparent'
					},
					events: {
						'onReady': onPlayer1Ready,
						'onStateChange': onPlayer1StateChange
					}
				});

			}

			var playerPopupId = document.getElementById('suround-player-popup');

			if ( playerPopupId ) {

				playerPopup = new YT.Player('suround-player-popup', {
					height: '310',
					width: '200',
					videoId: playerPopupId.getAttribute( 'data-youtube-video-id' ),
					playerVars: {
						autohide: 0,
						autoplay: 0,
						controls: 1,
						loop: 0,
						fs: 0,
						showinfo: 0,
						modestBranding: 1,
						start: 0,
						rel: 0,
						iv_load_policy: 3,
						wmode: 'transparent'
					},
					events: {
						'onReady': onPlayer2Ready,
						'onStateChange': onPlayer2StateChange
					}
				});


			}

		}

		var playerCoverReady = false;
		var playerPopupReady = false;

		var preloading1 = false;
		var preloading2 = false;

		function onPlayer1Ready(event) {
			playerCoverReady = true;
			preloading1 = true;

			// playerPopup.mute();
			// playerCover.seekTo(1);
		}

		function onPlayer2Ready(event) {
			playerPopupReady = true;
			preloading2 = true;

			playerPopup.mute();
			// playerPopup.seekTo(1,true);
		}

		function onPlayer1StateChange(event) {

			if ( event.data == YT.PlayerState.PLAYING ) {

				if ( preloading1 ) {
					// playerCover.pauseVideo();
					// playerCover.seekTo(0);
					// playerCover.unMute();
					preloading1 = false;

					playerPopupReady = true;
					preloading2 = true;

					// playerPopup.mute();
					playerPopup.seekTo(playerCover.getCurrentTime());


				} else {

					playerPopup.playVideo();

				}

			} else if ( event.data == YT.PlayerState.PAUSED ) {

				if ( !preloading1 ) {
					playerPopup.pauseVideo();
				}

			} else if ( event.data == YT.PlayerState.BUFFERING ) {

				if ( !preloading1 ) {
					playerCover.playVideo();
					playerPopup.seekTo(playerCover.getCurrentTime());
				}

			} else if ( event.data == YT.PlayerState.CUED ) {

				if ( !preloading1 ) {
					playerPopup.pauseVideo();
				}

			} else if ( event.data == YT.PlayerState.ENDED ) {

				playerPopup.stopVideo();

			}
		}

		function onPlayer2StateChange(event) {

			if ( event.data == YT.PlayerState.PLAYING ) {

				if ( preloading2 ) {

					// playerPopup.pauseVideo();
					// playerPopup.seekTo(0);
					// playerPopup.unMute();

					// playerCover.seekTo(playerPopup.getCurrentTime());
					preloading2 = false;

				} else {

					playerCover.playVideo();

				}

			} else if ( event.data == YT.PlayerState.PAUSED ) {

				if ( !preloading2 ) {
					playerCover.pauseVideo();
				}

			} else if ( event.data == YT.PlayerState.BUFFERING ) {

				if ( !preloading2 ) {
					// playerCover.pauseVideo();
					playerPopup.playVideo();
					playerCover.seekTo(playerPopup.getCurrentTime());
				}

			} else if ( event.data == YT.PlayerState.CUED ) {

				if ( !preloading2 ) {
					playerCover.pauseVideo();
				}

			} else if ( event.data == YT.PlayerState.ENDED ) {

				playerCover.stopVideo();

			}

		}


		$('body').on( 'click', '.suround-video-cover', function( e ) {

			e.preventDefault();

			var $this = $(this),
				cover_bg = $this.closest('.suround-cover-bg'),
				container = cover_bg.find('.suround-video-content');

			cover_bg.attr('style', '');
			$this.fadeOut(300, function() {

				container.fadeIn(300, function() {

					playerCover.playVideo();

					setTimeout(function () {

						if ( $(window).width() > 768 ) {

							var set_height = cover_bg.get(0).scrollHeight;
							set_height = set_height < 560 ? 560 : set_height;
							cover_bg.animate({
								height: set_height
							}, 150);

						} else {
							cover_bg
								.css('height', 'auto')
								.parent()
								.css('height', 'auto');
						}

					}, 100);

				});
			});

		} );

		var videoPopup = $('#suround-fixed-popup-video');

		if ( videoPopup.length ) {

			$(window).scroll( function() {
				var scroll = $(window).scrollTop();

				if ( scroll >= 500 ) {
					videoPopup.fadeIn();
				} else {
					videoPopup.fadeOut();
				}
			} );

			videoPopup.children('.item-close').on('click', function () {
				videoPopup.fadeOut(function() {
					$(this).remove();
				});
			});

		}

	}

	/* ----------------------------------------
	 Sticky Header
	 ---------------------------------------- */

	App.modules.stickyHeader = function() {

		if ( $('#wpadminbar').length && $('#wpadminbar').is(':visible') ) {
			$('.sticky-header').css('top', $('#wpadminbar').height());
		}

		$(window).scroll(function () {

			var top = $(window).scrollTop();

			if (top >= suround_global_vars.header_sticky_offset) {
				if (!$('body').hasClass('sticky-header-on')) {
					$('body').addClass('sticky-header-on');
				}
			} else {
				$('body').removeClass('sticky-header-on');
			}

		});

	}

	/* ----------------------------------------
	 Navigation
	 ---------------------------------------- */

	App.modules.navInit = function() {

		return {
			init : function () {

				this.navMain = $('.main-navigation');
				this.navPanel = $('.nav-panel');
				this.wrapper = $('.wrapper-container');

				this.bindEvents();
				this.createResponsiveButtons();
				this.navProcess();

				if ( App.ISTOUCH ) {
					this.touchNavEvent();
				}
			},

			touchNavEvent: function (base) {
				var clicked = false;

				$('li.menu-item-has-children > a, li.cat-parent > a, li.page-item-has-children > a').on( App.EVENT, function (e) {
					if ( clicked != this ) {
						e.preventDefault();
						clicked = this;
					}
				});

			},

			navProcess: function () {

				var self = this;

				if ( Modernizr.es6array ) {
					var mlmenu = new Suround_ML_Menu(this.navPanel[0], {
						breadcrumbsCtrl : false, // show breadcrumbs
						// initialBreadcrumb : 'all', // initial breadcrumb text
						backCtrl : true, // show back button
					});
				}

				$('ul.cats-tabs-caption').on('mouseover', 'li', function() {
					$(this)
						.closest('.cats-tabs')
						.find('.cats-tab-content')
						.removeClass('active')
						.eq($(this).index())
						.addClass('active');
				});

				this.navButton.on(App.EVENT, function (e) {
					e.preventDefault();
					self.navPanel.toggleClass('menu--open');
				});

				this.navHide.on(App.EVENT, function (e) {
					e.preventDefault();
					self.navPanel.removeClass('menu--open');
				});

			},

			bindEvents: function() {
				this.navMain.on('mouseenter.smart touchstart.mobilenav', 'li[class*="menu-item-has-children"], li[class*="page_item_has_children"]', this.smartPosition);
			},

			smartPosition: function(e) {

				var $this = $(this),
					$wW = $(window).width();

				var child = $this.children('.sub-menu-wrap, ul.children, ul.sub-menu'),
					transformCoeficient = child.outerWidth() - child.outerWidth() * .85;

				if ( App.RTL ) {

					if ( child.offset().left - transformCoeficient < 0 ) child.addClass('suround-menu-reverse');

				} else {
					var posX = child.offset().left,
						oW = child.outerWidth();

					if ( posX + oW > $wW ) {
						child.addClass('suround-menu-reverse');
					}
				}

			},

			createResponsiveButtons : function () {

				this.navButton = $('<button></button>', {
					'id': 'responsive-nav-button',
					'class': 'responsive-nav-button'
				}).insertBefore(this.navMain);

				this.navHide = $('<a></a>', {
					'id': 'advanced-menu-hide',
					'class': 'advanced-menu-hide',
					'href' : 'javascript:void(0)'
				}).prependTo(this.navPanel);

			},
		}.init();

	}

	/* ----------------------------------------
	 Search
	 ---------------------------------------- */

	App.modules.searchClick = function () {

		$.searchClick = function (el, options) {
			this.el = $(el);
			this.init(options);
		}

		$.searchClick.DEFAULTS = {
			key_esc: 27
		}

		$.searchClick.prototype = {
			init: function (options) {
				var base = this;
				base.o = $.extend({}, $.searchClick.DEFAULTS, options);
				base.key_esc = base.o.key_esc;
				base.searchWrap = $('.searchform-wrap');
				base.searchBtn = $('.search-button', base.el);
				base.searchClose = $('.close-search-form', base.el);
				base.searchField = $('#s', base.el);
				base.event = Modernizr.touch ? 'touchstart' : 'click';

				base.set();
				base.bind();
			},
			set: function () {
				var transEndEventNames = {
					'WebkitTransition': 'webkitTransitionEnd',
					'MozTransition': 'transitionend',
					'OTransition': 'oTransitionEnd',
					'msTransition': 'MSTransitionEnd',
					'transition': 'transitionend'
				};
				this.transEndEventName = transEndEventNames[Modernizr.prefixed( 'transition' )];
				this.animations = Modernizr.csstransitions;
			},
			hide: function () {
				var base = this;
				base.searchWrap.addClass('closed').removeClass('opened');
				var onEndTransitionFn = function () {
					base.searchWrap.removeClass('closed');
				};
				if ( base.animations ) {
					base.searchWrap.on(base.transEndEventName, onEndTransitionFn);
				} else {
					onEndAnimationFn();
				}

			},
			bind: function () {
				this.searchBtn.on( this.event, $.proxy(this.display_show, this) );

				this.searchClose.on( this.event, $.proxy(function (e) {
					this.display_hide(e, this.key_esc);
				}, this) );

				this.keyDownHandler(this.key_esc);

				$(window).on('load',function() {

					var $body = $('.wrapper-container');
					var $box = $('.wrapper-container');
					var $sb = $(".search-button");

					$body.on('click.Bst', function(event){
						if (
							$box.has(event.target).length == 0 &&
							!$box.is(event.target) &&
							!$sb.is(event.target)
						){
							$('.searchform-wrap').removeClass('opened');;
						}
					});

					$('.close-search-form').on( "click", function() {
						$('.searchform-wrap').removeClass('opened');
						$('#wrapper').css('height', 'auto');
					});

					$('.search-button').on( "click", function() {
						$('#wrapper').css('height', '100%');
					});

				});

			},
			display_show: function (e) {
				e.preventDefault();

				if (!this.searchWrap.hasClass('opened')) {
					this.searchWrap.addClass('opened');
					this.searchField.focus();
				}
			},
			display_hide: function (e, key) {
				var base = this;
				if (base.searchWrap.hasClass('opened')) {
					if (e.type == base.event || e.type == 'keydown' && e.keyCode === key) {
						e.preventDefault();
						base.hide();
						base.searchField.blur();
					}
				}
			},
			keyDownHandler: function (key) {
				$(window).on('keydown', $.proxy(function (e) {
					this.display_hide(e, key);
				}, this));
			}
		}

		var searchHolder = $('.search-holder');

		if ( searchHolder.length ) {
			searchHolder.searchClick();
		}

	}

	/* ----------------------------------------
	 Dropdowns
	 ---------------------------------------- */

	App.modules.dropdown = function() {

		var dropdown = {

			init: function(){

				this.bindEvents();

			},

			bindEvents: function(){

				var self = this;

				$('body').on('click', '.dropdown-invoker', function(e){

					e.preventDefault();
					e.stopPropagation();

					var invoker = $(this),
						dropdown = invoker.next('.dropdown-window');

					self.smartPosition(dropdown);

					invoker.add(dropdown).toggleClass('opened');
					dropdown.parent().toggleClass('dropdown-over');

				});

				$(document).on('click', function(e){

					var dropdown = $('.dropdown-window');

					if(!$(e.target).closest(dropdown).length){

						dropdown.add(dropdown.prev('.dropdown-invoker')).removeClass('opened');
						dropdown.parent().removeClass('dropdown-over');

					}

				});

			},

			smartPosition: function(dropdown){

				var dWidth = dropdown.outerWidth(),
					dOfsset = dropdown.offset().left,
					$wW = $(window).width();

				if(dOfsset + dWidth > $wW) dropdown.addClass('reverse');

			}

		}

		dropdown.init();

	}

	/* ----------------------------------------
	 Carousel
	 ---------------------------------------- */

	App.modules.owlCarousel = function () {

		$('.owl-carousel').not('.has-custom-dots, .n1-custom-dots').each(function () {

			var $this = $(this);
			var max_items = $this.data('max-items');
			var tablet_items = max_items;

			if ( max_items > 4 ) {
				tablet_items = max_items - 2;
			} else {
				tablet_items = max_items - 1;
			}

			var smart_items = max_items;

			if ( max_items > 4 ) {
				smart_items = max_items - 3;
			} else if (max_items == 4) {
				smart_items = max_items - 2;
			} else {
				smart_items = 1;
			}

			if ( max_items < 2 ) {
				smart_items = max_items;
				tablet_items = max_items;
			}

			var mobile_items = 1;
			var autoplay_carousel = $this.data('autoplay');
			var center_carousel = $this.data('center');
			var item_margin = $this.data('item-margin');
			var nav = $this.data('nav') || false;
			var dots = $this.data('dots') || false;
			var auto_height = $this.data('auto-height') || false;

			$this.owlCarousel({
				smartSpeed: 450,
				nav: nav ? true : false,
				dots: dots ? true : false,
				loop: true,
				autoplay: autoplay_carousel,
				center: center_carousel,
				autoplayTimeout: 3000,
				navText: false,
				autoHeight: auto_height,
				margin: item_margin,
				lazyLoad: true,
				rtl: App.RTL ? true : false,
				responsiveClass: true,
				responsive: {
					0:   { items: mobile_items },
					480: { items: smart_items },
					768: { items: tablet_items },
					992: { items: max_items }
				}
			});

		});

		if ( $('.has-custom-dots').length ) {

			$('.has-custom-dots').each(function() {

				var $customDots = $(this);

				$customDots.owlCarousel({
					smartSpeed : 450,
					nav : true,
					autoplay : true,
					loop  : true,
					autoplayTimeout: 3000,
					items: 1,
					navText : false,
					lazyLoad: true,
					rtl: App.RTL ? true : false,
					dotsContainer: '#carousel-custom-dots',
					dotsClass: '.custom-dot',
					dotsEach:true
				});

				// Call Vars
				$customDots.find( '.custom-dot' ).on( 'click', function() {
					$customDots.trigger('to.owl.carousel', [$customDots.index(), 300]);
					$('.custom-dot').removeClass( 'active' );
					$customDots.addClass( 'active' );
				})

			});

		}

	}

	App.modules.scrollSideMapSidebar = function( section_id ) {

		if ( !section_id ) return;

		var $sidebar = $('#side-map-sidebar');
		var item = $('#grid-item-' + section_id);

		return {
			init: function() {
				var offsetTop = ( item && item.length && [item['position']().top, item] ) || null;
				if ( offsetTop != null ) {
					this.animateItem( offsetTop );
				}
			},
			animateItem: function( offsetTop ) {

				var element = offsetTop[1];

				if ( !element.length ) return;

				element.siblings().removeClass('item--active').end().addClass('item--active');

				$sidebar.stop(true, true).animate({
					scrollTop: offsetTop[0]
				}, {
					duration: 500
				});
			}

		}.init();

	}

	/* ----------------------------------------
	 Preloader
	 ---------------------------------------- */

	App.modules.preloader = function(options) {

		var config = {
				waitAfterLoad: 200,
				duration: 800
			}, loader = $('#loader');

		$.extend(config, options);

		$(window).on('beforeunload load', function () {

			$('body').jQueryImagesLoaded().then(function() {

				setTimeout(function(){

					loader.addClass('hide');

					loader.fadeOut(config.duration, function(e){
						loader.removeClass('hide');
					});

				}, config.waitAfterLoad);

			});

		});

		return this;

	}

	/* ----------------------------------------
	 Back Top
	 ---------------------------------------- */

	App.modules.backToTop = function(config) {

		var backToTop = {

			init: function(config) {

				var self  = this;

				if ( config ) {
					this.config = $.extend(this.config, config);
				}

				this.btn = $('<button></button>', {
					'class': self.config.cssPrefix + 'back-to-top animated stealthy',
					html: '<span class="icon icon-chevron-up"></span>'
				});

				this.bindEvents();
				$body.append(this.btn);
			},

			config: {
				breakpoint: 700,
				showClass: 'visibleIn',
				hideClass: 'visibleOut',
				easing: 'linear',
				speed: 550,
				cssPrefix: ''
			},

			bindEvents: function() {

				var page = $('html, body'),
					self = this;

				this.btn.on('click', function(e){
					e.preventDefault();
					page.stop().animate({
						scrollTop: 0
					}, {
						easing: self.config.easing,
						duration: self.config.speed
					});
				});

				this.btn.on(App.ANIMATIONEND, function(e) {

					e.preventDefault();

					var $this = $(this);

					if ( $this.hasClass(self.config.hideClass)) {

						$this
							.addClass('stealthy')
							.removeClass(self.config.hideClass + " " + self.config.cssPrefix + "inview");

					}

				});

				$(window).on('scroll.backtotop', { self: this}, this.toggleBtn);

			},

			toggleBtn: function(e) {

				var $this = $(this),
					self = e.data.self;

				if( $this.scrollTop() > self.config.breakpoint && !self.btn.hasClass(self.config.cssPrefix + 'inview') ) {

					self.btn
						.addClass(self.config.cssPrefix + 'inview')
						.removeClass('stealthy');

					if ( App.ANIMATIONSUPPORTED ) {
						self.btn.addClass(self.config.showClass);
					}

				} else if( $this.scrollTop() < self.config.breakpoint && self.btn.hasClass(self.config.cssPrefix + 'inview') ) {

					self.btn.removeClass(self.config.cssPrefix + 'inview');

					if ( !App.ANIMATIONSUPPORTED ) {
						self.btn.addClass('stealthy');
					} else {
						self.btn.removeClass(self.config.showClass).addClass(self.config.hideClass);
					}

				}

			}

		};

		backToTop.init(config);

		return this;

	}

	/* ----------------------------------------
	 Owl Carousel helpers
	 ---------------------------------------- */

	App.baseOwlSettings = {
		items: 1,
		margin: 30,
		nav: true,
		rtl: App.RTL,
		navText: App.RTL ? ['<span class="icon icon-chevron-right"></span>', '<span class="icon icon-chevron-left"></span>'] : ['<span class="icon icon-chevron-left"></span>', '<span class="icon icon-chevron-right"></span>'],
		dots: false,
		autoplayHoverPause: true,
		smartSpeed: App.ANIMATIONDURATION,
		fluidSpeed: App.ANIMATIONDURATION,
		autoplaySpeed: App.ANIMATIONDURATION,
		navSpeed: App.ANIMATIONDURATION,
		dotsSpeed: App.ANIMATIONDURATION,
		dragEndSpeed: App.ANIMATIONDURATION,
		onInitialized: function() {

		}
	};

	App.helpers.owlAdaptive = function(collection) {

		var collection = collection ? collection : $('.owl-carousel');
		if ( !collection.length ) return;

		collection.each(function(i, el){

			var $this = $(el);

			$this.on('initialized.owl.carousel', function(e){
				App.helpers.owlUpdateIsotopeParent($this, true);
			});

			$this.on('resized.owl.carousel', function(e){
				App.helpers.owlContainerHeight($this, true);
			});

			$this.on('changed.owl.carousel', function(e) {
				App.helpers.owlContainerHeight($this, true);
			});

		});

	};

	App.helpers.owlContainerHeight = function(owl, resized) {

		if ( owl.hasClass('owl-carousel--vadaptive') ) return;

		if ( !owl.hasClass('owl-carousel--height') ) return;

		setTimeout(function() {

			var max = 0,
				items = owl.find('.owl-item'),
				activeItems = items.filter('.active').children();

			// items.children().css('height', 'auto');

			activeItems.each(function(i, el){
				var $this = $(el),
					height = $this.outerHeight();

				if ( height > max ) max = height;

			});

			owl.find('.owl-stage-outer').stop().animate({
				height: max
			}, {
				duration: 150,
				complete: function() {
				}
			});

		}, 20);

	};

	App.helpers.owlUpdateIsotopeParent = function($owl) {

	};

	App.helpers.owlNav = function(owl) {

		setTimeout(function(){

			var settings = owl.data('owl.carousel').settings;
			if(settings.autoplay || settings.loop) return;

			var prev = owl.find('.owl-prev'),
				next = owl.find('.owl-next');

			if(owl.find('.owl-item').first().hasClass('active')) prev.addClass('disabled');
			else prev.removeClass('disabled');

			if(owl.find('.owl-item').last().hasClass('active')) next.addClass('disabled');
			else next.removeClass('disabled');

		}, 100);

	};

	App.helpers.owlSettings = function(settings) {
		return $.extend(true, {}, App.baseOwlSettings, settings);
	};

	App.helpers.owlSync = {

		init: function() {

			this.collection = $('.owl-carousel[data-sync]');
			if ( !this.collection.length ) return;

			this.prepare();
		},

		prepare: function(){

			this.collection.each(function(i, el){

				var $this = $(el),
					sync = $($this.data('sync'));

				sync.on('changed.owl.carousel', function(e){

					var index = e.item.index;

					if ( !sync.data('afterClicked') ) $this.trigger('to.owl.carousel', [index, 350, true]);

					sync.data('afterClicked', false);

				});

				$this.on('prev.owl.carousel', function() {

					sync.trigger('prev.owl.carousel');

				});

				$this.on('next.owl.carousel', function() {

					sync.trigger('next.owl.carousel');

				});

				$this.on('click.owlSync', '.owl-item', function(e) {

					e.preventDefault();

					var index = $(this).index();

					sync.data('afterClicked', true);

					sync.trigger('to.owl.carousel', [index, 350, true]);

				});

			});

		}

	};


	/* ----------------------------------------
	 Colorizer
	 ---------------------------------------- */

	App.helpers.Colorizer = {};
	App.helpers.Colorizer._$collection = $();
	App.helpers.Colorizer.config = {
		cssPrefix: 'suround-',
		classMap: {
			bgColorElement: 'colorizer-bg-color',
			bgImageElement: 'colorizer-bg-image',
			videoContainer: 'vc_video-bg-container',
			bgVideoElement: 'vc_video-bg',
			VCParallaxContainer: 'vc_parallax',
			VCParallax: 'vc_parallax-inner',
			VCRow: 'vc_row',
			parallax: 'colorizer--parallax'
		},
		afterInit: function() {}
	};

	Object.defineProperties(App.helpers.Colorizer, {
		bgColorElementClass: {
			get: function() {
				return this.config.cssPrefix + this.config.classMap.bgColorElement;
			}
		},
		bgImageElementClass: {
			get: function() {
				return this.config.cssPrefix + this.config.classMap.bgImageElement;
			}
		},
		bgVideoElementClass: {
			get: function() {
				return this.config.classMap.bgVideoElement;
			}
		},
		parallaxClass: {
			get: function() {
				return this.config.cssPrefix + this.config.classMap.parallax;
			}
		}
	});

	/**
	 *
	 * @param {jQuery} $collection - collection of elements to colorize
	 * @returns {jQuery} $collection
	 */
	App.helpers.Colorizer.init = function($collection, config) {
		var self = this;

		$collection = $collection ? $collection : $('.colorizer-functionality');

		if(!$.isjQuery($collection, true)) return $collection;

		this.config = $.extend(true, {}, this.config, config);

		$collection.each(function(index, element) {
			var $element = $(element);

			if(self._$collection.filter($element).length) return;

			self.initElement($element);
			self._$collection = self._$collection.add($element);
		});

		this.config.afterInit.call(this);

		return $collection;
	};

	/**
	 *
	 * @param {jQuery} $element
	 * @returns {Object} Colorizer
	 */
	App.helpers.Colorizer.add = function($element) {
		if(!this._$collection.filter($element).length) {
			this._$collection = this._$collection.add($element);
		}

		return this;
	};

	/**
	 *
	 * @param {jQuery} $element
	 * @returns {Object} Colorizer
	 */
	App.helpers.Colorizer.initElement = function($element) {
		if(this.hasBGVideoElement($element)) {
			this.prepareVideoElement($element);
		}

		if(this.hasVCParallax($element)) {
			this.prepareParallaxElement($element);
		}

		if(!this.hasBGImageElement($element) && $element.data('bg-image-src') && !this.hasVCParallax($element)) {
			this.appendBGImageElement($element);
		}

		return this;
	};

	/**
	 *
	 * @returns {Object} Colorizer
	 */
	App.helpers.Colorizer.update = function() {
		var self = this;

		this._$collection.each(function(index, element) {
			var $element = $(element);
			self.reset($element).initElement($element);
		});

		return this;
	};

	/**
	 *
	 * @param {jQuery} $element
	 * @returns {Object} Colorizer
	 */
	App.helpers.Colorizer.reset = function($element) {
		// var $bgElements = $element.find('.' + this.bgColorElementClass + ', .' + this.bgImageElementClass);
		var $bgElements = $element.find('.' + this.bgImageElementClass);

		if ( $bgElements.length ) $bgElements.remove();

		return this;
	};

	/**
	 *
	 * @param {jQuery} $element
	 * @returns {Boolean}
	 */
	App.helpers.Colorizer.hasVCParallax = function($element) {
		return $element.hasClass(this.config.classMap.VCParallaxContainer) && !$element.hasClass(this.config.classMap.videoContainer);
	};

	/**
	 *
	 * @param {jQuery} $element
	 * @returns {Boolean}
	 */
	App.helpers.Colorizer.hasBGColorElement = function($element) {
		return $element.data('bg-color') || $element.is('[class*="' + this.config.cssPrefix + 'colorizer--scheme-"]');
	};

	/**
	 *
	 * @param {jQuery} $element
	 * @returns {Boolean}
	 */
	App.helpers.Colorizer.hasBGVideoElement = function($element) {
		return $element.hasClass(this.config.classMap.videoContainer);
	};

	/**
	 *
	 * @param {jQuery} $element
	 * @returns {Boolean}
	 */
	App.helpers.Colorizer.hasBGImageElement = function($element) {
		return $element.children('.' + this.bgImageElementClass).length;
	};

	/**
	 *
	 * @param {jQuery} $element
	 * @returns {jQuery}
	 */
	App.helpers.Colorizer.prepareVideoElement = function($element) {
		var self = this,
			opacity = $element.data('bg-video-opacity'),
			$videoElement;

		if(!opacity) return $element;

		$element.data('SuroundIntervalID', setInterval(function(){
			$videoElement = $element.find('.' + self.bgVideoElementClass);
			if($videoElement.length) {
				$videoElement.css('opacity', opacity);
				clearInterval($element.data('SuroundIntervalID'));
			}
		}, 100));

		return $element;
	};

	/**
	 *
	 * @param {jQuery} $element
	 * @returns {jQuery}
	 */
	App.helpers.Colorizer.prepareParallaxElement = function($element) {
		var self = this,
			opacity = $element.data('bg-image-opacity'),
			$imageElement;

		if(!opacity) return $element;


		$element.data('SuroundIntervalID', setInterval(function(){
			$imageElement = $element.find('.' + self.config.classMap.VCParallax);
			if($imageElement.length) {
				$imageElement.css('opacity', opacity);
				clearInterval($element.data('SuroundIntervalID'));
			}
		}, 100));

		return $element;
	};

	/**
	 *
	 * @param {jQuery} $element
	 * @returns {jQuery}
	 */
	App.helpers.Colorizer.appendBGColorElement = function($element) {
		var self = this,
			backgroundColorData = $element.data('bg-color'),
			$bgColorElement = $('<div></div>', {
				'class': self.bgColorElementClass
			});

		if(backgroundColorData) {
			$bgColorElement.css('background-color', backgroundColorData);
		}

		return $element.prepend($bgColorElement);
	};

	/**
	 *
	 * @param {jQuery} $element
	 * @returns {jQuery}
	 */
	App.helpers.Colorizer.appendBGImageElement = function($element) {
		var self = this,
			src = $element.data('bg-image-src'),
			bgImageOpacityData = $element.data('bg-image-opacity'),
			$bgImageElement = $('<div></div>', {
				'class': self.bgImageElementClass
			});

		$bgImageElement.css({
			'background-image':  'url("' + src + '")'
		});

		if ( bgImageOpacityData ) {
			$bgImageElement.css('opacity', bgImageOpacityData);
		}

		$element.prepend($bgImageElement);

		return $element;
	};

	/* ----------------------------------------
	 End of Colorizer
	 ---------------------------------------- */

	/* ----------------------------------------
	 Customize Padding
	 ---------------------------------------- */

	App.helpers.customizePadding = function(window) {

		var $sidemap = $('.cat-layout-side-map'),
			$header = $sidemap.find('.header'),
			$isotopeNav = $sidemap.find('.isotope-cont'),
			$map = $sidemap.find('.suround-post-gmap'),
			$mapContent = $sidemap.find('#side-map-content'),
			headerHeight = $header.outerHeight(),
			isotopeNavHeight = $isotopeNav.outerHeight(),
			mapContentPadding = headerHeight;
			mapContentPadding += isotopeNavHeight;

		if ( window.width() < 767 ) {
			return;
		}

		if ( $('#wpadminbar').length ) {
			mapContentPadding += $('#wpadminbar').outerHeight();
		}

		if ( $header.length ) {
			$mapContent.css( {
				'top': mapContentPadding
			} );
		}

		if ( $map.length ) {
			$map.css({'height': 'calc(100vh - ' + mapContentPadding + 'px)'});
		}

		App.helpers.eventHandlers(window);

	}

	/* ----------------------------------------
	 Event Handlers
	 ---------------------------------------- */

	App.helpers.eventHandlers = function (window) {

		window.on('debouncedresize', function() {

			App.helpers.customizePadding(window);

			setTimeout(function() {
				window.trigger('update:map');
				window.trigger('pxg:refreshmap');
			});

		});

	}

	/* ----------------------------------------
	 Scroll Event
	 ---------------------------------------- */

	App.helpers.scrollEvent = function() {

		var nextArticle = $('#scroll-event');

		$(window).on('scroll', function () {

			if ($(window).scrollTop() >= (($(document).height() - $(window).height()) - $('#footer').innerHeight())) {

				var href = nextArticle.data('next-post');

				if (href) {
					setTimeout(function () {
						location.href = href;
					}, 1000);
				}

			}
		});

	}

	/* ----------------------------------------
	 Social Fixed
	 ---------------------------------------- */

	App.helpers.socialFixed = function() {

		$('#show-all').on('click', function (e) {
			e.preventDefault();
			$(this).toggleClass('clicked');
			$(this).parent('li').siblings('.hide').slideToggle();
		})

		var socPopup = $('#social-fixed');
			socPopup.fadeOut();

		$(window).scroll(function () {
			var scroll = $(window).scrollTop();

			if ( scroll >= 500 ) {
				socPopup.fadeIn();
			} else {
				socPopup.fadeOut();
			}
		});

	}

	/* ----------------------------------------
	 Accordion & Toggle
	 ---------------------------------------- */

	App.helpers.accordion = function() {

		var aItem = $('.accordion:not(.toggle) .accordion-item'),
			link = aItem.find('.a-title'),
			$label = aItem.find('label'),
			aToggleItem = $('.accordion.toggle .accordion-item'),
			tLink = aToggleItem.find('.a-title');

		aItem.add(aToggleItem).children('.a-title').not('.active').next().hide();

		function triggerAccordeon($item) {
			$item
				.addClass('active')
				.next().stop().slideDown()
				.parent().siblings()
				.children('.a-title')
				.removeClass('active')
				.next().stop().slideUp();
		}


		if ($label.length) {
			$label.on('click',function(){
				triggerAccordeon($(this).closest('.a-title'))
			});
		} else {
			link.on('click',function(){
				triggerAccordeon($(this))
			});
		}

		tLink.on('click',function(){
			$(this).toggleClass('active')
				.next().stop().slideToggle();

		});

	}

	/* ----------------------------------------
	 Tabs
	 ---------------------------------------- */

	App.helpers.tabs = function() {

		var tabs = $('.tabs-section');
		if ( tabs.length && $.fn.tabs ) {

			tabs.tabs({
				beforeActivate: function(event, ui) {
					var hash = ui.newTab.children("li a").attr("href");
				},
				hide : {
					effect : "fadeOut",
					duration : 450
				},
				show : {
					effect : "fadeIn",
					duration : 450
				},
				updateHash : false
			});
		}

	}

	/* ----------------------------------------
	 End of Owl Carousel helpers
	 ---------------------------------------- */

	$.extend({
		isjQuery: function(element, elementExists) {
			if(element === undefined || element === null) return false;

			if(elementExists === undefined) {
				return element instanceof jQuery;
			}
			else {
				return $.isjQuery(element) && element.length;
			}
		},
	})

	$.fn.extend({
		jQueryImagesLoaded : function () {
			var $imgs = this.find('img[src!=""]');

			if (!$imgs.length) {return $.Deferred().resolve().promise();}

			var dfds = [];

			$imgs.each(function(){
				var dfd = $.Deferred();
				dfds.push(dfd);
				var img = new Image();
				img.onload = function(){dfd.resolve();};
				img.onerror = function(){dfd.resolve();};
				img.src = this.src;
			});

			return $.when.apply($,dfds);
		},
		searchClick: function (option) {
			if (!this.length) return this;
			return this.each(function () {
				var $this = $(this), data = $this.data('searchClick'),
					options = typeof option == 'object' && option;
				if (!data) {
					$this.data('searchClick', new $.searchClick(this, options));
				}
			});
		}
	});

	$window.on('load', function() {
		App.afterOuterResourcesLoaded($window);
	});

	$doc.ready(function() {
		App.afterDOMReady();
	});

	if ( $.fn.theiaStickySidebar ) {
		$(window).on('load resize', function() {
			if ( $(window).width() > 992 && $('.sticky-bar').length ) {
				$('.sidebar').theiaStickySidebar({
					additionalMarginTop: 30
				});
			}

			if ( $(window).width() > 992 && $('.post-info-items').length ) {

				$('.post-info-items').theiaStickySidebar({
					additionalMarginTop: $('#header').outerHeight() + 50
				});
			}

		});
	}

	if( $('#loader').length ) App.modules.preloader();

	return App;

})(window.jQuery);
