(function ($) {

	"use strict"

	var map, marker, markers, custom_html_icon, $window = $(window);

	var emptyLatLng = function(data) {

		if ( typeof( data ) == 'number' || typeof( data ) == 'boolean' ) {
			return false;
		}
		if ( typeof( data ) == 'undefined' || data === null ) {
			return true;
		}
		if ( typeof( data.length ) != 'undefined' ) {
			return data.length === 0;
		}
		var count = 0;
		for ( var i in data ) {
			if ( Object.prototype.hasOwnProperty.call(data, i) ) {
				count++;
			}
		}
		return count === 0;
	}, addPinToMap = function(obj) {
		var $item = $(obj);

		if ( emptyLatLng($item.data('latitude')) || emptyLatLng($item.data('longitude')) ) {
			return false;
		}

		var svg = wp.template('empty-icon-svg'),
			iconSVG = svg(suround_global_vars);

		marker = L.marker([$item.data('latitude'), $item.data('longitude')], {
			icon: new custom_html_icon({
				html: "<div class='map-pin'>" + iconSVG + "</div>"
			})
		});

		marker.attachment_url = $item.data('attachment-url');

		marker.bindPopup( $item.html(), { maxWidth: 315 } )
			._popup.section_id = $item.data('post-id');

		markers.addLayer(marker);

		return true;
	}

	SuroundMap.Maps = {
		options: {
			scrollWheelZoom: false,
			zoomControl: true,
			maxZoom: 17,
			gestureHandling: true,
			fullscreenControl: true,
			skin: "skin1",
		},
		skins: [],
		init: function () { },
	}, SuroundMap.Maps.Map = function (e) {
		this.$el = $(e), this.init();
	}, SuroundMap.Maps.Map.prototype.init = function () {

			if ( typeof L !== "object" || !L.hasOwnProperty('map') ) {
				return;
			}

			this.options = $.extend({}, SuroundMap.Maps.options, this.$el.data('options'));

			map = L.map(this.$el[0], {
				scrollWheelZoom: this.options.scrollWheelZoom,
				gestureHandling: this.options.gestureHandling,
				zoomControl: this.options.zoomControl,
				maxZoom: this.options.maxZoom,
				fullscreenControl: this.options.fullscreenControl
			});

			L.mapboxGL({
				accessToken: SuroundMap.MapConfig.AccessToken,
				style: this.options.skin == 'custom' ? SuroundMap.MapConfig.CustomSkin : SuroundMap.Maps.skins[this.options.skin] ? SuroundMap.Maps.skins[this.options.skin] : SuroundMap.Maps.skins.skin1
			}).addTo(map);

			markers = new L.markerClusterGroup({
				spiderfyOnMaxZoom: true,
				showCoverageOnHover: true
			});

			custom_html_icon = L.HtmlIcon.extend({
				options: {
					iconSize: [37, 42],
					iconAnchor: [25, 58],
					popupAnchor: [3, -3]
				}
			});

			var $listings = $('.suround-post-hidden-map'),
				$listing = $('.entry-col', $listings),
				listingWithLocation = 0;

			if ( !$listing.length ) {
				return;
			}

			$listing.each(function (i, obj) {

				var cardHasLocation = addPinToMap(obj);

				// marker.openPopup();

				if ( cardHasLocation ) {
					listingWithLocation += 1;
				}

			});

			if ( listingWithLocation != 0 ) {

				map.fitBounds(markers.getBounds(), {
					padding: [50, 50, 50, 50],
					easing: function (t) {
						return t * (2 - t);
					}
				});

				map.addLayer(markers);

				if ( this.options.single ) {
					marker.openPopup();
				}

			}

			map._onResize();

			$window.on('pxg:refreshmap', function () {
				map._onResize();
			});

			map.on('popupopen', function (el) {
				if ( el.popup.section_id ) {
					Suround.modules.scrollSideMapSidebar(el.popup.section_id);
				}
			});

		}, SuroundMap.Maps.skins = {
		skin1: "mapbox://styles/mapbox/streets-v10",
		skin2: "mapbox://styles/mapbox/outdoors-v10",
		skin3: "mapbox://styles/mapbox/light-v9",
		skin4: "mapbox://styles/mapbox/dark-v9",
		skin5: "mapbox://styles/mapbox/satellite-streets-v10",
		skin6: "mapbox://styles/mapbox/navigation-preview-day-v4",
		skin7: "mapbox://styles/mapbox/navigation-preview-night-v4",
		skin8: "mapbox://styles/mapbox/navigation-guidance-day-v4",
		skin9: "mapbox://styles/mapbox/navigation-guidance-night-v4"
	}, SuroundMap.Maps.init = function () {

		if ( !$('.suround-post-gmap').length ) return;

		$window.on('load', function () {
			$('.suround-post-gmap').each(function (i, el) {
				new SuroundMap.Maps.Map(el);
			})
		});

	}, SuroundMap.Maps.init();

})(jQuery);