<?php
/**
 * The template for displaying all single posts
 *
 * @package WordPress
 * @subpackage Suround
 */
get_header(); ?>

<?php if ( have_posts() ): ?>

	<?php global $suround_config, $SuroundLayout, $suround_settings;

	global $Suround;
	$post_id = suround_post_id();

	$layouts = array(
		'none',
		'cover-map',
		'cover-street-view',
		'cover-carousel',
		'cover-slider',
		'cover-video'
	);

	$show_info   = get_post_meta( $post_id, 'suround_single_post_info', true );
	$info_layout   = get_post_meta( $post_id, 'suround_single_post_info_layout', true );

	$cover_layout = $SuroundLayout->getPostCoverArea();

	$pagination = $SuroundLayout->getOption('current_single_pagination');

	$info_position = $Suround->getThemeOption('post-info-position', 'left', array(
		'overriden_by' => 'suround_single_post_info_position',
	));

	$related_position = $Suround->getThemeOption('post-related-position', 'after', array(
		'overriden_by' => 'suround_single_post_related_position',
		'depend_on' => array('key' => 'suround_single_post_related_state', 'value' => '0')
	));

	$show_author = $Suround->getThemeOption('post-author', false, array(
		'overriden_by' => 'suround_single_post_author'
	));

	$show_subscribe = $Suround->getThemeOption('post-subscribe', false, array(
		'overriden_by' => 'suround_single_post_subscribe'
	));

	$subscribe_form = $Suround->getThemeOption('post-subscribe-select-form', false, array(
		'overriden_by' => 'suround_single_post_subscribe_form'
	));

	$share_align_class = $Suround->getThemeOption('post-social-share-buttons-align', 'position-left', array(
		'overriden_by' => 'suround_single_post_share_buttons_align',
		'depend_on' => array('key' => 'suround_single_post_share_buttons_state', 'value' => '0')
	));

	$share_buttons_state = $Suround->getThemeOption('post-social-share-buttons', 'hide', array(
		'overriden_by' => 'suround_single_post_share_buttons_show',
		'depend_on' => array( 'key' => 'suround_single_post_share_buttons_state', 'value' => '0' )
	));

	$media = new Suround_Media_Grabber(
		array(
			'type'        => 'video',
			'split_media' => true
		)
	);
	?>

	<article id="post-<?php the_ID(); ?>" <?php post_class( array('entry', 'single') ); ?>>

		<?php if ( !empty($cover_layout) && in_array($cover_layout, $layouts) ): ?>

			<div class="entry-body">

				<?php if ( suround_get_option('lay_single_cat') ) : ?>
					<?php echo suround_get_category_list() ?>
				<?php endif; ?>

				<h2 class="entry-title"><?php the_title() ?></h2>

				<?php if ( $meta = suround_blog_post_meta( 'single' ) ) : ?>
					<div class="entry-meta"><?php echo wp_kses_post($meta); ?></div>
				<?php endif; ?>

			</div><!--/ .entry-body-->

		<?php endif; ?>

		<?php if ( !empty($media->get_media()) ): ?>
			<div class="entry-cover-video">
				<?php echo suround_media_grabber(array( 'type' => 'video', 'split_media' => true )); ?>
			</div>
		<?php endif; ?>

		<?php if ( $cover_layout == 'cover-video' ): ?>

			<?php if ( has_post_thumbnail( $id ) ): ?>
				<div class="entry-post-featured-photo">
					<?php echo get_the_post_thumbnail( $id, '' ); ?>
				</div>
			<?php endif; ?>

		<?php endif; ?>

		<div class="entry-content">

			<?php if ( $show_info ): ?>

				<?php ob_start(); ?>

				<?php if ( $info_layout == 'layout-1' ): ?>

					<?php
					$address          = get_post_meta( $post_id, 'suround_single_post_location', true );
					$geolocation_lat  = get_post_meta( $post_id, 'geolocation_lat', true );
					$geolocation_long = get_post_meta( $post_id, 'geolocation_long', true );

					$phone = get_post_meta( $post_id, 'suround_single_post_phone', true );
					$mobile_phone = get_post_meta( $post_id, 'suround_single_post_mobile_phone', true );
					$email = get_post_meta( $post_id, 'suround_single_post_email', true );
					$website = get_post_meta( $post_id, 'suround_single_post_website', true );
					$price_level = get_post_meta( $post_id, 'suround_single_post_price_level', true );
					$opening_times = get_post_meta( $post_id, 'suround_single_post_opening_times', true );

					if ( ! empty( $geolocation_lat ) && ! empty( $geolocation_long ) && is_numeric( $geolocation_lat ) && is_numeric( $geolocation_long ) ) {
						$get_directions_link = '//maps.google.com/maps?daddr=' . $geolocation_lat . ',' . $geolocation_long;
					}
					?>

					<div class="post-info">

						<?php if ( !empty($address) ): ?>
							<p class="post-info-item">
										<span class="post-info-title"><span class="licon-map-marker"></span>
											<?php esc_html_e( 'Address', 'surround' ) ?>:
										</span>

								<span class="post-info-address"><?php echo implode('</span><span class="post-info-address">', array_unique(array_map('trim', explode(',', $address)))); ?></span>

								<?php if ( ! empty( $get_directions_link ) ) { ?>
									<a href="<?php echo esc_url($get_directions_link); ?>" class="post-link-text" target="_blank">
										<?php esc_html_e( 'Get Direction', 'surround' ); ?>
										<i class="licon-chevron-right-circle"></i>
									</a>
								<?php } ?>
							</p>
						<?php endif; ?>

						<?php if ( !empty($phone) ): ?>
							<p class="post-info-item">
										<span class="post-info-title"><span class="licon-telephone"></span>
											<?php esc_html_e('Phone', 'surround') ?>:</span>
								<span content="telephone=no"><?php echo wp_kses_post($phone) ?></span>
							</p>
						<?php endif; ?>

						<?php if ( !empty($mobile_phone) ): ?>
							<p class="post-info-item">
										<span class="post-info-title"><span class="licon-phone"></span>
											<?php esc_html_e('Mobile', 'surround') ?>:</span>
								<span content="telephone=no"><?php echo wp_kses_post($mobile_phone) ?></span>
							</p>
						<?php endif; ?>

						<?php if ( !empty($email) ): ?>
							<p class="post-info-item">
										<span class="post-info-title"><span class="licon-at-sign"></span>
											<?php esc_html_e('E-Mail', 'surround') ?>:</span>
								<a href="mailto:<?php echo antispambot($email, 1) ?>"><?php echo wp_kses_post($email) ?></a>
							</p>
						<?php endif; ?>

						<?php if ( !empty($website) ): ?>
							<p class="post-info-item">
										<span class="post-info-title"><span class="licon-earth"></span>
											<?php esc_html_e('Website', 'surround') ?>:</span>
								<a href="<?php echo esc_url($website) ?>"><?php echo wp_kses_post($website) ?></a>
							</p>
						<?php endif; ?>

						<?php if ( !empty($price_level) && $price_level !== 'none' ): ?>
							<div class="post-info-item">

								<span class="post-info-title"><span class="licon-tag"></span><?php esc_html_e('Price Level', 'surround') ?>:</span>

								<?php $price_level = absint($price_level); ?>

								<ul class="price-level">

									<?php for ( $i = 1; $i <= 5; $i++ ): ?>
										<li class="<?php if ( $i <= $price_level ): ?>active<?php endif; ?>"><span class="licon-coin-dollar"></span></li>
									<?php endfor ?>

								</ul>

							</div>
						<?php endif; ?>

						<?php if ( !empty($opening_times) ): ?>
							<p class="post-info-item">
										<span class="post-info-title"><span class="licon-clock3"></span>
											<?php esc_html_e('Opening Times', 'surround') ?>:</span>
								<?php echo wp_kses_post($opening_times) ?>
							</p>
						<?php endif; ?>

					</div>

				<?php elseif ( $info_layout == 'layout-2' ): ?>

					<?php
					$user_id     = get_the_author_meta( 'ID' );
					$name        = get_the_author_meta( 'display_name', $user_id );
					$email       = get_the_author_meta( 'email', $user_id );
					?>

					<div class="team-holder">

						<?php $user_profile = new suround_admin_user_profile(); ?>

						<div class="team-item">

							<a href="<?php echo get_author_posts_url( $user_id ); ?>" class="member-photo">
								<?php echo get_avatar( $email, '315' ); ?>
							</a>

							<div class="team-desc">

								<div class="member-info">

									<div class="member-name">
										<a href="<?php echo get_author_posts_url( $user_id ); ?>">
											<?php echo wp_kses_post( $name ) ?>
										</a>
									</div>

									<?php echo wp_kses_post( $user_profile->output_position( $user_id ) ); ?>

								</div><!--/ .member-info-->

							</div><!--/ .team-desc-->

						</div><!--/ .team-item-->

					</div><!--/ .team-holder-->

					<?php if ( function_exists('suround_single_social_share') ): ?>
						<div class="social-side-holder">
							<?php suround_single_social_share( false ); ?>
						</div>
					<?php endif; ?>

					<?php if ( $suround_settings['post-pag'] ): ?>

						<?php if ( $pagination == 'prev-next' ): ?>

							<?php
							$prev_post = get_previous_post();
							$next_post = get_next_post();
							$prev_post_url = $next_post_url = "";
							$prev_post_title = $next_post_title = "";
							$prev = false;
							$next = false;

							if ( is_object($prev_post) ) {
								$prev_post_url = get_permalink($prev_post->ID);
								$prev_post_title = $prev_post->post_title;
								$prev = true;
							}

							if ( is_object($next_post) ) {
								$next_post_url = get_permalink($next_post->ID);
								$next_post_title = $next_post->post_title;
								$next = true;
							}
							?>

							<?php if ( $prev || $next ): ?>

								<div class="prev-next-post">

									<?php if ( $prev ): ?>
										<div class="prev-post">
											<span class="prev-post-link"><?php esc_html_e('Previous Article', 'surround') ?></span>
											<h5><a href="<?php echo esc_url($prev_post_url) ?>"><?php echo wp_kses_post($prev_post_title) ?></a></h5>
										</div>
									<?php endif; ?>

									<?php if ( $next ): ?>
										<div class="next-post">
											<span class="next-post-link"><?php esc_html_e('Next Article', 'surround') ?></span>
											<h5><a href="<?php echo esc_url($next_post_url) ?>"><?php echo wp_kses_post($next_post_title) ?></a></h5>
										</div>
									<?php endif; ?>

								</div><!--/ .prev-next-post-->

							<?php endif; ?>

						<?php endif; ?>

					<?php endif; ?>

				<?php endif; ?>

				<?php $end = ob_get_clean(); ?>

				<div class="row">

					<?php if ( $info_position == 'left' ): ?>

						<div class="post-info-items <?php if ( $info_layout == 'layout-1' ): ?>col-lg-4<?php else: ?>col-lg-3<?php endif; ?>">
							<?php echo wp_kses_post($end) ?>
						</div>

						<div class="<?php if ( $info_layout == 'layout-1' ): ?>col-lg-8<?php else: ?>col-lg-9<?php endif; ?>">

							<?php
							the_content(
								sprintf(
									esc_html__( 'Continue reading %s', 'surround' ),
									'<span class="screen-reader-text">' . get_the_title() . '</span>'
								)
							);

							wp_link_pages(
								array(
									'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'surround' ),
									'after'  => '</div>'
								)
							);
							?>
							<div class="clear"></div>

						</div>

					<?php else: ?>

						<div class="<?php if ( $info_layout == 'layout-1' ): ?>col-lg-8<?php else: ?>col-lg-9<?php endif; ?>">

							<?php
							the_content(
								sprintf(
									esc_html__( 'Continue reading %s', 'surround' ),
									'<span class="screen-reader-text">' . get_the_title() . '</span>'
								)
							);

							wp_link_pages(
								array(
									'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'surround' ),
									'after'  => '</div>'
								)
							);
							?>
							<div class="clear"></div>

						</div>

						<div class="post-info-items <?php if ( $info_layout == 'layout-1' ): ?>col-lg-4<?php else: ?>col-lg-3<?php endif; ?>">
							<?php echo wp_kses_post($end) ?>
						</div>

					<?php endif; ?>

				</div><!--/ .row-->

			<?php else: ?>

				<?php
				the_content(
					sprintf(
						esc_html__( 'Continue reading %s', 'surround' ),
						'<span class="screen-reader-text">' . get_the_title() . '</span>'
					)
				);

				wp_link_pages(
					array(
						'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'surround' ),
						'after'  => '</div>'
					)
				);
				?>
				<div class="clear"></div>

			<?php endif; ?>

			<?php if ( function_exists('suround_single_social_share') ): ?>
				<?php if ( $share_buttons_state == 'show' ): ?>
					<div id="social-fixed" class="social-side-holder fixed <?php echo sanitize_html_class($share_align_class) ?>">
						<?php suround_single_social_share(); ?>
					</div>
				<?php endif; ?>
			<?php endif; ?>

			<?php if ( class_exists('RWP_Reviewer') ): ?>
				<?php if ( $suround_settings['post-reviewer']): ?>
					<?php suround_post_single_reviewer(); ?>
				<?php endif; ?>
			<?php endif; ?>

			<footer class="entry-footer">

				<?php if ( $suround_settings['post-tag'] ): ?>
					<?php
					$tags_list = get_the_tag_list( '', '', '' );
					if ( $tags_list ) {
						echo '<div class="tag-wrap">';
						echo '<span class="tag-title">' . esc_html__( 'Tags', 'surround' ) . ':</span>';
						echo '<div class="tagcloud">' . $tags_list . '</div>';
						echo '</div>';
					}
					?>
				<?php endif; ?>

				<?php if ( $suround_settings['post-link-bookmark']): ?>
					<?php echo suround_get_link_bookmark(); ?>
				<?php endif; ?>

			</footer>

		</div><!-- .entry-content -->

		<?php if ( $show_author ): ?>
			<?php get_template_part( 'template-parts/single/post', 'author-box' ); ?>
		<?php endif; ?>

		<?php if ( $suround_settings['post-related-posts'] ): ?>
			<?php if ( $related_position == 'before' ): ?>
				<?php get_template_part( 'template-parts/single/post', 'related' ); ?>
			<?php endif; ?>
		<?php endif; ?>

		<?php if ( $show_subscribe && $subscribe_form ): ?>

			<div class="entry-newsletter">
				<?php echo do_shortcode('[vc_mad_mailpoet style="style-3" select_form="'. $subscribe_form.'"]'); ?>
			</div>

		<?php endif; ?>

		<?php if ( $suround_settings['post-related-posts'] ): ?>
			<?php if ( $related_position == 'after' || $related_position == 'bottom-fixed' ): ?>
				<?php if ( $related_position == 'bottom-fixed' ): ?>
					<?php get_template_part( 'template-parts/single/post', 'related-articles-popup' ); ?>
				<?php else: ?>
					<?php get_template_part( 'template-parts/single/post', 'related' ); ?>
				<?php endif; ?>
			<?php endif; ?>
		<?php endif; ?>

		<?php if ( $suround_settings['post-comments'] ): ?>
			<?php if ( comments_open() || get_comments_number() ): ?>
				<div class="entry-comments">
					<?php comments_template(); ?>
				</div>
			<?php endif; ?>
		<?php endif; ?>

		<?php if ( $suround_settings['post-pag'] ): ?>
			<?php get_template_part( 'template-parts/single/post', 'pag' ); ?>
		<?php endif; ?>

	</article><!-- #post-## -->

<?php endif; ?>

<?php get_footer(); ?>