
<?php
global $suround_settings;

if ( !defined('MAILPOET_VERSION') ) return;

use MailPoet\API\JSON\API;
use MailPoet\Config\RendererFactory;
use MailPoet\DI\ContainerWrapper;
use MailPoet\Entities\FormEntity;
use MailPoet\Form\Renderer as FormRenderer;
use MailPoet\Form\FormsRepository as FormsRepository;
use MailPoet\WP\Functions as WPFunctions;
?>

<div class="call-out newsletter">

	<div class="container wide">

		<div class="row align-items-center">
			<div class="col-lg-7 offset-lg-1">

				<?php if ( $suround_settings['footer-newsletter-title'] ): ?>
					<h4 class="call-title f-left"><?php echo esc_html($suround_settings['footer-newsletter-title']) ?></h4>
				<?php endif; ?>

				<?php

                $form = '';

                if ( defined('MAILPOET_VERSION') ) {

                    $wp = new WPFunctions;
                    $formsRepository = ContainerWrapper::getInstance()->get(FormsRepository::class);
                    $formRenderer = ContainerWrapper::getInstance()->get(FormRenderer::class);

                    wp_enqueue_script( 'mailpoet_vendor' );
                    wp_enqueue_script( 'mailpoet_public' );

                    $form_id = $churhius_settings['footer-select-form'];

                    if (!empty($form_id)) {
                        $form = $formsRepository->findOneById($form_id);
                    } else {
                        // Backwards compatibility for MAILPOET-3847
                        // Get first non deleted form
                        $forms = $formsRepository->findBy(['deletedAt' => null], ['name' => 'asc']);
                        if (empty($forms)) return '';
                        $form = $forms[0];
                    }

                    $body = (!empty($form->getBody()) ? $form->getBody() : []);
                    $output = '';
                    $settings = $form->getSettings();

                    if (!empty($body) && is_array($settings)) {
                        $formId = 'w_' . $form->getId();
                        $data = [
                            'form_html_id' => $formId,
                            'form_id' => $form->getId(),
                            'form_type' => 'shortcode',
                            'form_success_message' => $settings['success_message'],
                            'title' => '',
                            'styles' => '',
                            'html' => $formRenderer->renderHTML($form),
                        ];

                        // (POST) non ajax success/error variables
                        $data['success'] = (
                            (isset($_GET['mailpoet_success']))
                            &&
                            ((int)$_GET['mailpoet_success'] === $form->getId())
                        );
                        $data['error'] = (
                            (isset($_GET['mailpoet_error']))
                            &&
                            ((int)$_GET['mailpoet_error'] === $form->getId())
                        );

                        // generate security token
                        $data['token'] = $wp->wpCreateNonce('mailpoet_token');

                        // add API version
                        $data['api_version'] = API::CURRENT_VERSION;

                        // render form
                        $renderer = (new RendererFactory())->getRenderer();
                        try {
                            $output = $renderer->render('form/front_end_form.html', $data);
                            $output = WPFunctions::get()->doShortcode($output);
                            $output = $wp->applyFilters('mailpoet_form_widget_post_process', $output);
                        } catch (\Exception $e) {
                            $output = $e->getMessage();
                        }
                    }

                    $form = $output;

                } else {
                    $form = '<h6>'. esc_html__( 'Please install required plugin - MailPoet', 'churhius' ) .'</h6>';
                }

				echo $form; ?>

			</div>

			<div class="col-lg-4">

				<?php if ( $suround_settings['show-footer-social-links']): ?>

					<ul class="social-icons hr-type">

						<?php if ( $suround_settings['footer-social-facebook']): ?>
							<li><a title="<?php echo esc_html__('Facebook', 'surround' ) ?>" href="<?php echo esc_url($suround_settings['footer-social-facebook']) ?>"><i class="icon-facebook"></i></a></li>
						<?php endif; ?>

						<?php if ( $suround_settings['footer-social-twitter']): ?>
							<li><a title="<?php echo esc_html__('Twitter', 'surround' ) ?>" href="<?php echo esc_url($suround_settings['footer-social-twitter']) ?>"><i class="icon-twitter"></i></a></li>
						<?php endif; ?>

						<?php if ( $suround_settings['footer-social-googleplus']): ?>
							<li><a title="<?php echo esc_html__('Tumblr', 'surround' ) ?>" href="<?php echo esc_url($suround_settings['footer-social-googleplus']) ?>"><i class="icon-gplus-3"></i></a></li>
						<?php endif; ?>

						<?php if ( $suround_settings['footer-social-youtube']): ?>
							<li><a title="<?php echo esc_html__('Youtube', 'surround' ) ?>" href="<?php echo esc_url($suround_settings['footer-social-youtube']) ?>"><i class="icon-youtube-play"></i></a></li>
						<?php endif; ?>

						<?php if ( $suround_settings['footer-social-instagram']): ?>
							<li><a title="<?php echo esc_html__('Instagram', 'surround' ) ?>" href="<?php echo esc_url($suround_settings['footer-social-instagram']) ?>"><i class="icon-instagram-5"></i></a></li>
						<?php endif; ?>

					</ul>

				<?php endif; ?>

			</div>

		</div>

	</div><!--/ .container-->

</div><!--/ .call-out-->